/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<attendeesmodel.h>)
#  include <attendeesmodel.h>
#endif
#if __has_include(<calendarapplication.h>)
#  include <calendarapplication.h>
#endif
#if __has_include(<calendarmanager.h>)
#  include <calendarmanager.h>
#endif
#if __has_include(<datetimestate.h>)
#  include <datetimestate.h>
#endif
#if __has_include(<filter.h>)
#  include <filter.h>
#endif
#if __has_include(<foreigntypes.h>)
#  include <foreigntypes.h>
#endif
#if __has_include(<holidaymodel.h>)
#  include <holidaymodel.h>
#endif
#if __has_include(<holidayregionmodel.h>)
#  include <holidayregionmodel.h>
#endif
#if __has_include(<hourlyincidencemodel.h>)
#  include <hourlyincidencemodel.h>
#endif
#if __has_include(<importer.h>)
#  include <importer.h>
#endif
#if __has_include(<incidenceoccurrencemodel.h>)
#  include <incidenceoccurrencemodel.h>
#endif
#if __has_include(<incidencewrapper.h>)
#  include <incidencewrapper.h>
#endif
#if __has_include(<infinitemerkurocalendarviewmodel.h>)
#  include <infinitemerkurocalendarviewmodel.h>
#endif
#if __has_include(<itemtagsmodel.h>)
#  include <itemtagsmodel.h>
#endif
#if __has_include(<monthmodel.h>)
#  include <monthmodel.h>
#endif
#if __has_include(<mousetracker.h>)
#  include <mousetracker.h>
#endif
#if __has_include(<multidayincidencemodel.h>)
#  include <multidayincidencemodel.h>
#endif
#if __has_include(<remindersmodel.h>)
#  include <remindersmodel.h>
#endif
#if __has_include(<timezonelistmodel.h>)
#  include <timezonelistmodel.h>
#endif
#if __has_include(<todosortfilterproxymodel.h>)
#  include <todosortfilterproxymodel.h>
#endif
#if __has_include(<utils.h>)
#  include <utils.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_merkuro_calendar()
{
    qmlRegisterModule("org.kde.merkuro.calendar", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AttendeesModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<AttendeesModel::Roles>("AttendeesModel::Roles");
    qmlRegisterTypesAndRevisions<CalendarApplication>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<CalendarApplication::Mode>("CalendarApplication::Mode");
    qmlRegisterTypesAndRevisions<CalendarManager>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<CalendarSettingsForeign>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<CalendarUtils>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<ConfigForeign>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<CalendarConfig::EnumLocationMarker>("CalendarConfig::EnumLocationMarker");
    qmlRegisterEnum<CalendarConfig::EnumLastOpenedView>("CalendarConfig::EnumLastOpenedView");
    qmlRegisterEnum<CalendarConfig::EnumMonthGridMode>("CalendarConfig::EnumMonthGridMode");
    qmlRegisterEnum<CalendarConfig::EnumWeekdayLabelAlignment>("CalendarConfig::EnumWeekdayLabelAlignment");
    qmlRegisterEnum<CalendarConfig::EnumWeekdayLabelLength>("CalendarConfig::EnumWeekdayLabelLength");
    qmlRegisterEnum<CalendarConfig::EnumHourlyViewMode>("CalendarConfig::EnumHourlyViewMode");
    qmlRegisterEnum<CalendarConfig::EnumMonthListMode>("CalendarConfig::EnumMonthListMode");
    qmlRegisterEnum<CalendarConfig::EnumSort>("CalendarConfig::EnumSort");
    qmlRegisterTypesAndRevisions<DateTimeState>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<Filter>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<FreeBusyManagerForeign>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<HolidayModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<HolidayRegionModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<HourlyIncidenceModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<HourlyIncidenceModel::Filters>("HourlyIncidenceModel::Filters");
    qmlRegisterEnum<HourlyIncidenceModel::Filter>("HourlyIncidenceModel::Filter");
    qmlRegisterTypesAndRevisions<Importer>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<IncidenceData>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<IncidenceOccurrenceModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<IncidenceOccurrenceModel::Roles>("IncidenceOccurrenceModel::Roles");
    qmlRegisterTypesAndRevisions<IncidenceWrapper>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<IncidenceWrapper::RecurrenceIntervals>("IncidenceWrapper::RecurrenceIntervals");
    qmlRegisterEnum<IncidenceWrapper::IncidenceTypes>("IncidenceWrapper::IncidenceTypes");
    qmlRegisterEnum<IncidenceWrapper::RecurrenceActions>("IncidenceWrapper::RecurrenceActions");
    qmlRegisterTypesAndRevisions<InfiniteMerkuroCalendarViewModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<InfiniteMerkuroCalendarViewModel::Scale>("InfiniteMerkuroCalendarViewModel::Scale");
    qmlRegisterEnum<InfiniteMerkuroCalendarViewModel::Roles>("InfiniteMerkuroCalendarViewModel::Roles");
    qmlRegisterTypesAndRevisions<ItemTagsModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<ItemTagsModel::Roles>("ItemTagsModel::Roles");
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    qmlRegisterTypesAndRevisions<MonthModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<MouseTracker>("org.kde.merkuro.calendar", 254);
    qmlRegisterTypesAndRevisions<MultiDayIncidenceModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<MultiDayIncidenceModel::Filters>("MultiDayIncidenceModel::Filters");
    qmlRegisterEnum<MultiDayIncidenceModel::Filter>("MultiDayIncidenceModel::Filter");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<RemindersModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<RemindersModel::Roles>("RemindersModel::Roles");
    qmlRegisterTypesAndRevisions<TimeZoneListModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<TimeZoneListModel::Roles>("TimeZoneListModel::Roles");
    qmlRegisterTypesAndRevisions<TodoSortFilterProxyModel>("org.kde.merkuro.calendar", 254);
    qmlRegisterEnum<TodoSortFilterProxyModel::Roles>("TodoSortFilterProxyModel::Roles");
    qmlRegisterEnum<TodoSortFilterProxyModel::BaseTodoModelColumns>("TodoSortFilterProxyModel::BaseTodoModelColumns");
    qmlRegisterEnum<TodoSortFilterProxyModel::ShowComplete>("TodoSortFilterProxyModel::ShowComplete");
    qmlRegisterEnum<TodoSortFilterProxyModel::DueDateDisplayFormat>("TodoSortFilterProxyModel::DueDateDisplayFormat");
    qmlRegisterTypesAndRevisions<UndoRedoData>("org.kde.merkuro.calendar", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.merkuro.calendar", 254, 254);
}

static const QQmlModuleRegistration orgkdemerkurocalendarRegistration("org.kde.merkuro.calendar", qml_register_types_org_kde_merkuro_calendar);
