/****************************************************************************
** Meta object code from reading C++ file 'mailactions.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/mail/mailactions.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mailactions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MailActionsE_t {};
} // unnamed namespace

template <> constexpr inline auto MailActions::qt_create_metaobjectdata<qt_meta_tag_ZN11MailActionsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailActions",
        "QML.Element",
        "auto",
        "selectionModelChanged",
        "",
        "mailApplicationChanged",
        "itemChanged",
        "mailSaveAs",
        "Akonadi::Item",
        "item",
        "moveToRequested",
        "Akonadi::Item::List",
        "items",
        "copyToRequested",
        "setReadState",
        "isRead",
        "setImportantState",
        "isImportant",
        "setActionState",
        "moveTo",
        "Akonadi::Collection",
        "destination",
        "copyTo",
        "selectionToItems",
        "selectionModel",
        "QItemSelectionModel*",
        "mailApplication",
        "MailApplication*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionModelChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mailApplicationChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mailSaveAs'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'moveToRequested'
        QtMocHelpers::SignalData<void(const Akonadi::Item::List &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'copyToRequested'
        QtMocHelpers::SignalData<void(const Akonadi::Item::List &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'setReadState'
        QtMocHelpers::MethodData<void(bool)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Method 'setImportantState'
        QtMocHelpers::MethodData<void(bool)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Method 'setActionState'
        QtMocHelpers::MethodData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'moveTo'
        QtMocHelpers::MethodData<void(const Akonadi::Item::List &, const Akonadi::Collection &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 20, 21 },
        }}),
        // Method 'copyTo'
        QtMocHelpers::MethodData<void(const Akonadi::Item::List &, const Akonadi::Collection &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 20, 21 },
        }}),
        // Method 'selectionToItems'
        QtMocHelpers::MethodData<Akonadi::Item::List() const>(23, 4, QMC::AccessPublic, 0x80000000 | 11),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'selectionModel'
        QtMocHelpers::PropertyData<QItemSelectionModel*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'item'
        QtMocHelpers::PropertyData<Akonadi::Item>(9, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'mailApplication'
        QtMocHelpers::PropertyData<MailApplication*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MailActions, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MailActions::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MailActionsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MailActionsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MailActionsE_t>.metaTypes,
    nullptr
} };

void MailActions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MailActions *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionModelChanged(); break;
        case 1: _t->mailApplicationChanged(); break;
        case 2: _t->itemChanged(); break;
        case 3: _t->mailSaveAs((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 4: _t->moveToRequested((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 5: _t->copyToRequested((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 6: _t->setReadState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->setImportantState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->setActionState(); break;
        case 9: _t->moveTo((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 10: _t->copyTo((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 11: { Akonadi::Item::List _r = _t->selectionToItems();
            if (_a[0]) *reinterpret_cast<Akonadi::Item::List*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MailActions::*)()>(_a, &MailActions::selectionModelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MailActions::*)()>(_a, &MailActions::mailApplicationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MailActions::*)()>(_a, &MailActions::itemChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MailActions::*)(const Akonadi::Item & )>(_a, &MailActions::mailSaveAs, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MailActions::*)(const Akonadi::Item::List & )>(_a, &MailActions::moveToRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MailActions::*)(const Akonadi::Item::List & )>(_a, &MailActions::copyToRequested, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MailApplication* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelectionModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QItemSelectionModel**>(_v) = _t->selectionModel(); break;
        case 1: *reinterpret_cast<Akonadi::Item*>(_v) = _t->item(); break;
        case 2: *reinterpret_cast<MailApplication**>(_v) = _t->mailApplication(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSelectionModel(*reinterpret_cast<QItemSelectionModel**>(_v)); break;
        case 1: _t->setItem(*reinterpret_cast<Akonadi::Item*>(_v)); break;
        case 2: _t->setMailApplication(*reinterpret_cast<MailApplication**>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 1: _t->unsetItem(); break;
        default: break;
        }
    }
}

const QMetaObject *MailActions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailActions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MailActionsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MailActions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void MailActions::selectionModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MailActions::mailApplicationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MailActions::itemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MailActions::mailSaveAs(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MailActions::moveToRequested(const Akonadi::Item::List & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MailActions::copyToRequested(const Akonadi::Item::List & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
