/****************************************************************************
** Meta object code from reading C++ file 'attendeesmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/models/attendeesmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'attendeesmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19AttendeeStatusModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AttendeeStatusModel::qt_create_metaobjectdata<qt_meta_tag_ZN19AttendeeStatusModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AttendeeStatusModel",
        "Roles",
        "DisplayNameRole",
        "ValueRole"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(1, 1, QMC::EnumFlags{}).add({
            {    2, Roles::DisplayNameRole },
            {    3, Roles::ValueRole },
        }),
    };
    return QtMocHelpers::metaObjectData<AttendeeStatusModel, qt_meta_tag_ZN19AttendeeStatusModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AttendeeStatusModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AttendeeStatusModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AttendeeStatusModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19AttendeeStatusModelE_t>.metaTypes,
    nullptr
} };

void AttendeeStatusModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AttendeeStatusModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *AttendeeStatusModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AttendeeStatusModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AttendeeStatusModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AttendeeStatusModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14AttendeesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AttendeesModel::qt_create_metaobjectdata<qt_meta_tag_ZN14AttendeesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AttendeesModel",
        "QML.Element",
        "auto",
        "incidencePtrChanged",
        "",
        "attendeesChanged",
        "attendeeDeleted",
        "Akonadi::Item::Id",
        "id",
        "attendeeStatusModelChanged",
        "attendeesAkonadiIdsChanged",
        "addAttendee",
        "itemId",
        "email",
        "deleteAttendee",
        "row",
        "deleteAttendeeFromAkonadiId",
        "incidencePtr",
        "KCalendarCore::Incidence::Ptr",
        "attendees",
        "KCalendarCore::Attendee::List",
        "attendeeStatusModel",
        "AttendeeStatusModel*",
        "attendeesAkonadiIds",
        "QList<qint64>",
        "Roles",
        "CuTypeRole",
        "DelegateRole",
        "DelegatorRole",
        "EmailRole",
        "FullNameRole",
        "IsNullRole",
        "NameRole",
        "RoleRole",
        "RSVPRole",
        "StatusRole",
        "UidRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'incidencePtrChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attendeesChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attendeeDeleted'
        QtMocHelpers::SignalData<void(Akonadi::Item::Id)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'attendeeStatusModelChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attendeesAkonadiIdsChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'addAttendee'
        QtMocHelpers::MethodData<void(qint64, const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 12 }, { QMetaType::QString, 13 },
        }}),
        // Method 'addAttendee'
        QtMocHelpers::MethodData<void(qint64)>(11, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::LongLong, 12 },
        }}),
        // Method 'addAttendee'
        QtMocHelpers::MethodData<void()>(11, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'deleteAttendee'
        QtMocHelpers::MethodData<void(int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Method 'deleteAttendeeFromAkonadiId'
        QtMocHelpers::MethodData<void(qint64)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'incidencePtr'
        QtMocHelpers::PropertyData<KCalendarCore::Incidence::Ptr>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'attendees'
        QtMocHelpers::PropertyData<KCalendarCore::Attendee::List>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'attendeeStatusModel'
        QtMocHelpers::PropertyData<AttendeeStatusModel*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'attendeesAkonadiIds'
        QtMocHelpers::PropertyData<QList<qint64>>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(25, 25, QMC::EnumFlags{}).add({
            {   26, Roles::CuTypeRole },
            {   27, Roles::DelegateRole },
            {   28, Roles::DelegatorRole },
            {   29, Roles::EmailRole },
            {   30, Roles::FullNameRole },
            {   31, Roles::IsNullRole },
            {   32, Roles::NameRole },
            {   33, Roles::RoleRole },
            {   34, Roles::RSVPRole },
            {   35, Roles::StatusRole },
            {   36, Roles::UidRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AttendeesModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN14AttendeesModelE[] = {
    QMetaObject::SuperData::link<KCalendarCore::Incidence::staticMetaObject>(),
    QMetaObject::SuperData::link<KCalendarCore::Attendee::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject AttendeesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AttendeesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AttendeesModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN14AttendeesModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AttendeesModelE_t>.metaTypes,
    nullptr
} };

void AttendeesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AttendeesModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->incidencePtrChanged(); break;
        case 1: _t->attendeesChanged(); break;
        case 2: _t->attendeeDeleted((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::Id>>(_a[1]))); break;
        case 3: _t->attendeeStatusModelChanged(); break;
        case 4: _t->attendeesAkonadiIdsChanged(); break;
        case 5: _t->addAttendee((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->addAttendee((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 7: _t->addAttendee(); break;
        case 8: _t->deleteAttendee((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->deleteAttendeeFromAkonadiId((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AttendeesModel::*)()>(_a, &AttendeesModel::incidencePtrChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeesModel::*)()>(_a, &AttendeesModel::attendeesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeesModel::*)(Akonadi::Item::Id )>(_a, &AttendeesModel::attendeeDeleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeesModel::*)()>(_a, &AttendeesModel::attendeeStatusModelChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeesModel::*)()>(_a, &AttendeesModel::attendeesAkonadiIdsChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AttendeeStatusModel* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<qint64> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KCalendarCore::Incidence::Ptr*>(_v) = _t->incidencePtr(); break;
        case 1: *reinterpret_cast<KCalendarCore::Attendee::List*>(_v) = _t->attendees(); break;
        case 2: *reinterpret_cast<AttendeeStatusModel**>(_v) = _t->attendeeStatusModel(); break;
        case 3: *reinterpret_cast<QList<qint64>*>(_v) = _t->attendeesAkonadiIds(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIncidencePtr(*reinterpret_cast<KCalendarCore::Incidence::Ptr*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AttendeesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AttendeesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AttendeesModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AttendeesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void AttendeesModel::incidencePtrChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AttendeesModel::attendeesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AttendeesModel::attendeeDeleted(Akonadi::Item::Id _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AttendeesModel::attendeeStatusModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AttendeesModel::attendeesAkonadiIdsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
