#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_merkuro_calendar_qml_incidenceeditor_ReminderDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_incidenceeditor_PriorityComboBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_BottomToolBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Menus_MenuBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_DatePopupSingleton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Menus_GlobalMenuBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Drawers_MainDrawer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Drawers_IncidenceInfoDrawer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Bars_FilterHeaderBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Bars_DayLabelsBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Delegates_IncidenceDelegateBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Delegates_DayGridViewIncidenceDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Delegates_ViewTitleDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Delegates_RelatedIncidenceDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Delegates_MonthListViewIncidenceDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_DayGridViewBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_DayGridViewForeground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_DayGridView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_SwipeableMonthGridView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_MonthView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_SwipeableMonthListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_BasicMonthListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_ScheduleView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_TodoTreeView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_TodoView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_SwipeableInternalHourlyView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_BasicInternalHourlyView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_WeekViewHolidayRow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_MainViews_HourlyView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_CalendarUtils_DateUtils_js { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_CalendarUtils_LabelUtils_js { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_CalendarUtils_CalendarUiUtils_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_IncidenceEditorManager_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Dialogs_IncidenceEditorPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Dialogs_IncidenceEditorDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Dialogs_DeleteIncidenceDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Dialogs_DeleteCalendarDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Dialogs_CollectionPickerPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Dialogs_RecurringIncidenceChangePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_DateControls_TimePicker_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_DateControls_TimeCombo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_DateControls_DateCombo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_TitleDateButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_IncidenceMouseArea_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_KBMNavigationMouseArea_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_DayTapHandler_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_ResizerSeparator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_CalendarItemTapHandler_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_TodoCheckBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_IncidenceInfoContents_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_IncidenceInfoPopup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_CheckableCollectionNavigationView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_MainDrawerToggleButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_ImportHandler_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Location_LocationMap_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Settings_ConfigurationsView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Settings_FreeBusySettingsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Settings_ViewSettingsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Settings_SourceSettingsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_merkuro_calendar_qml_Menus_CalendarItemMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/incidenceeditor/ReminderDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_incidenceeditor_ReminderDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/incidenceeditor/PriorityComboBox.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_incidenceeditor_PriorityComboBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/BottomToolBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_BottomToolBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Menus/MenuBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Menus_MenuBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/DatePopupSingleton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_DatePopupSingleton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Main.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Menus/GlobalMenuBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Menus_GlobalMenuBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Drawers/MainDrawer.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Drawers_MainDrawer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Drawers/IncidenceInfoDrawer.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Drawers_IncidenceInfoDrawer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Bars/FilterHeaderBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Bars_FilterHeaderBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Bars/DayLabelsBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Bars_DayLabelsBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Delegates/IncidenceDelegateBackground.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Delegates_IncidenceDelegateBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Delegates/DayGridViewIncidenceDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Delegates_DayGridViewIncidenceDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Delegates/ViewTitleDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Delegates_ViewTitleDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Delegates/RelatedIncidenceDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Delegates_RelatedIncidenceDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Delegates/MonthListViewIncidenceDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Delegates_MonthListViewIncidenceDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/DayGridViewBackground.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_DayGridViewBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/DayGridViewForeground.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_DayGridViewForeground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/DayGridView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_DayGridView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/SwipeableMonthGridView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_SwipeableMonthGridView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/MonthView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_MonthView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/SwipeableMonthListView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_SwipeableMonthListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/BasicMonthListView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_BasicMonthListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/ScheduleView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_ScheduleView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/TodoTreeView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_TodoTreeView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/TodoView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_TodoView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/SwipeableInternalHourlyView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_SwipeableInternalHourlyView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/BasicInternalHourlyView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_BasicInternalHourlyView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/WeekViewHolidayRow.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_WeekViewHolidayRow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/MainViews/HourlyView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_MainViews_HourlyView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/CalendarUtils/DateUtils.js"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_CalendarUtils_DateUtils_js::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/CalendarUtils/LabelUtils.js"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_CalendarUtils_LabelUtils_js::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/CalendarUtils/CalendarUiUtils.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_CalendarUtils_CalendarUiUtils_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/IncidenceEditorManager.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_IncidenceEditorManager_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Dialogs/IncidenceEditorPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Dialogs_IncidenceEditorPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Dialogs/IncidenceEditorDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Dialogs_IncidenceEditorDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Dialogs/DeleteIncidenceDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Dialogs_DeleteIncidenceDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Dialogs/DeleteCalendarDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Dialogs_DeleteCalendarDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Dialogs/CollectionPickerPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Dialogs_CollectionPickerPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Dialogs/RecurringIncidenceChangePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Dialogs_RecurringIncidenceChangePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/DateControls/TimePicker.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_DateControls_TimePicker_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/DateControls/TimeCombo.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_DateControls_TimeCombo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/DateControls/DateCombo.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_DateControls_DateCombo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/TitleDateButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_TitleDateButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/IncidenceMouseArea.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_IncidenceMouseArea_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/KBMNavigationMouseArea.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_KBMNavigationMouseArea_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/DayTapHandler.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_DayTapHandler_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/ResizerSeparator.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_ResizerSeparator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/CalendarItemTapHandler.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_CalendarItemTapHandler_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/TodoCheckBox.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_TodoCheckBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/IncidenceInfoContents.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_IncidenceInfoContents_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/IncidenceInfoPopup.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_IncidenceInfoPopup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/CheckableCollectionNavigationView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_CheckableCollectionNavigationView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/MainDrawerToggleButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_MainDrawerToggleButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Controls/ImportHandler.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Controls_ImportHandler_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Location/LocationMap.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Location_LocationMap_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Settings/ConfigurationsView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Settings_ConfigurationsView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Settings/FreeBusySettingsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Settings_FreeBusySettingsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Settings/ViewSettingsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Settings_ViewSettingsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Settings/SourceSettingsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Settings_SourceSettingsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/merkuro/calendar/qml/Menus/CalendarItemMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_merkuro_calendar_qml_Menus_CalendarItemMenu_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_merkuro_calendar_static)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_merkuro_calendar_static))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_merkuro_calendar_static)() {
    return 1;
}
