/****************************************************************************
** Meta object code from reading C++ file 'infinitemerkurocalendarviewmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/models/infinitemerkurocalendarviewmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'infinitemerkurocalendarviewmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32InfiniteMerkuroCalendarViewModelE_t {};
} // unnamed namespace

template <> constexpr inline auto InfiniteMerkuroCalendarViewModel::qt_create_metaobjectdata<qt_meta_tag_ZN32InfiniteMerkuroCalendarViewModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InfiniteMerkuroCalendarViewModel",
        "QML.Element",
        "auto",
        "datesToAddChanged",
        "",
        "scaleChanged",
        "moveToDate",
        "selectedDate",
        "currentDate",
        "currentIndex",
        "addDates",
        "atEnd",
        "startFrom",
        "datesToAdd",
        "scale",
        "Scale",
        "DayScale",
        "ThreeDayScale",
        "WeekScale",
        "WorkWeekScale",
        "MonthScale",
        "YearScale",
        "DecadeScale",
        "InvalidScale",
        "Roles",
        "StartDateRole",
        "FirstDayOfMonthRole",
        "SelectedMonthRole",
        "SelectedYearRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'datesToAddChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'moveToDate'
        QtMocHelpers::MethodData<int(const QDate &, const QDate &, const int)>(6, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QDate, 7 }, { QMetaType::QDate, 8 }, { QMetaType::Int, 9 },
        }}),
        // Method 'addDates'
        QtMocHelpers::MethodData<void(const bool, const QDate)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { QMetaType::QDate, 12 },
        }}),
        // Method 'addDates'
        QtMocHelpers::MethodData<void(const bool)>(10, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'datesToAdd'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'scale'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Scale'
        QtMocHelpers::EnumData<enum Scale>(15, 15, QMC::EnumFlags{}).add({
            {   16, Scale::DayScale },
            {   17, Scale::ThreeDayScale },
            {   18, Scale::WeekScale },
            {   19, Scale::WorkWeekScale },
            {   20, Scale::MonthScale },
            {   21, Scale::YearScale },
            {   22, Scale::DecadeScale },
            {   23, Scale::InvalidScale },
        }),
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(24, 24, QMC::EnumFlags{}).add({
            {   25, Roles::StartDateRole },
            {   26, Roles::FirstDayOfMonthRole },
            {   27, Roles::SelectedMonthRole },
            {   28, Roles::SelectedYearRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<InfiniteMerkuroCalendarViewModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject InfiniteMerkuroCalendarViewModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32InfiniteMerkuroCalendarViewModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32InfiniteMerkuroCalendarViewModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32InfiniteMerkuroCalendarViewModelE_t>.metaTypes,
    nullptr
} };

void InfiniteMerkuroCalendarViewModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InfiniteMerkuroCalendarViewModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->datesToAddChanged(); break;
        case 1: _t->scaleChanged(); break;
        case 2: { int _r = _t->moveToDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->addDates((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 4: _t->addDates((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InfiniteMerkuroCalendarViewModel::*)()>(_a, &InfiniteMerkuroCalendarViewModel::datesToAddChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InfiniteMerkuroCalendarViewModel::*)()>(_a, &InfiniteMerkuroCalendarViewModel::scaleChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->datesToAdd(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->scale(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDatesToAdd(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setScale(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *InfiniteMerkuroCalendarViewModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InfiniteMerkuroCalendarViewModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32InfiniteMerkuroCalendarViewModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int InfiniteMerkuroCalendarViewModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void InfiniteMerkuroCalendarViewModel::datesToAddChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void InfiniteMerkuroCalendarViewModel::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
