// This file is generated by kconfig_compiler_kf6 from calendarconfig.kcfg.
// All changes you do to this file will be lost.

#include "calendarconfig.h"

CalendarConfig::CalendarConfig( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kalendarrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&CalendarConfig::itemChanged);

  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigCompilerSignallingItem  *itemShowMenubar;
  KConfigSkeleton::ItemBool  *innerItemShowMenubar;
  innerItemShowMenubar = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showMenubar" ), mShowMenubar, false );
  itemShowMenubar = new KConfigCompilerSignallingItem(innerItemShowMenubar, this, notifyFunction, signalShowMenubarChanged);
  addItem( itemShowMenubar, QStringLiteral( "showMenubar" ) );
  KConfigCompilerSignallingItem  *itemForceCollapsedMainDrawer;
  KConfigSkeleton::ItemBool  *innerItemForceCollapsedMainDrawer;
  innerItemForceCollapsedMainDrawer = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "forceCollapsedMainDrawer" ), mForceCollapsedMainDrawer, false );
  itemForceCollapsedMainDrawer = new KConfigCompilerSignallingItem(innerItemForceCollapsedMainDrawer, this, notifyFunction, signalForceCollapsedMainDrawerChanged);
  addItem( itemForceCollapsedMainDrawer, QStringLiteral( "forceCollapsedMainDrawer" ) );
  KConfigCompilerSignallingItem  *itemEnableMaps;
  KConfigSkeleton::ItemBool  *innerItemEnableMaps;
  innerItemEnableMaps = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "enableMaps" ), mEnableMaps, false );
  itemEnableMaps = new KConfigCompilerSignallingItem(innerItemEnableMaps, this, notifyFunction, signalEnableMapsChanged);
  addItem( itemEnableMaps, QStringLiteral( "enableMaps" ) );
  KConfigCompilerSignallingItem  *itemEnableMailIntegration;
  KConfigSkeleton::ItemBool  *innerItemEnableMailIntegration;
  innerItemEnableMailIntegration = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "enableMailIntegration" ), mEnableMailIntegration, false );
  itemEnableMailIntegration = new KConfigCompilerSignallingItem(innerItemEnableMailIntegration, this, notifyFunction, signalEnableMailIntegrationChanged);
  addItem( itemEnableMailIntegration, QStringLiteral( "enableMailIntegration" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valueslocationMarker;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Circle");
    valueslocationMarker.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Pin");
    valueslocationMarker.append( choice );
  }
  KConfigCompilerSignallingItem  *itemLocationMarker;
  KConfigSkeleton::ItemEnum  *innerItemLocationMarker;
  innerItemLocationMarker = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "locationMarker" ), mLocationMarker, valueslocationMarker, int(Pin) );
  itemLocationMarker = new KConfigCompilerSignallingItem(innerItemLocationMarker, this, notifyFunction, signalLocationMarkerChanged);
  addItem( itemLocationMarker, QStringLiteral( "locationMarker" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valueslastOpenedView;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MonthView");
    valueslastOpenedView.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ScheduleView");
    valueslastOpenedView.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TodoView");
    valueslastOpenedView.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("WeekView");
    valueslastOpenedView.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("WorkWeekView");
    valueslastOpenedView.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ThreeDayView");
    valueslastOpenedView.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("DayView");
    valueslastOpenedView.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ContactView");
    valueslastOpenedView.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MailView");
    valueslastOpenedView.append( choice );
  }
  KConfigCompilerSignallingItem  *itemLastOpenedView;
  KConfigSkeleton::ItemEnum  *innerItemLastOpenedView;
  innerItemLastOpenedView = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "lastOpenedView" ), mLastOpenedView, valueslastOpenedView, int(-1) );
  itemLastOpenedView = new KConfigCompilerSignallingItem(innerItemLastOpenedView, this, notifyFunction, signalLastOpenedViewChanged);
  addItem( itemLastOpenedView, QStringLiteral( "lastOpenedView" ) );
  KConfigCompilerSignallingItem  *itemIncidenceInfoDrawerDrawerWidth;
  KConfigSkeleton::ItemInt  *innerItemIncidenceInfoDrawerDrawerWidth;
  innerItemIncidenceInfoDrawerDrawerWidth = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "incidenceInfoDrawerDrawerWidth" ), mIncidenceInfoDrawerDrawerWidth, -1 );
  itemIncidenceInfoDrawerDrawerWidth = new KConfigCompilerSignallingItem(innerItemIncidenceInfoDrawerDrawerWidth, this, notifyFunction, signalIncidenceInfoDrawerDrawerWidthChanged);
  addItem( itemIncidenceInfoDrawerDrawerWidth, QStringLiteral( "incidenceInfoDrawerDrawerWidth" ) );

  setCurrentGroup( QStringLiteral( "MainDrawer" ) );

  KConfigCompilerSignallingItem  *itemTagsSectionExpanded;
  KConfigSkeleton::ItemBool  *innerItemTagsSectionExpanded;
  innerItemTagsSectionExpanded = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "tagsSectionExpanded" ), mTagsSectionExpanded, true );
  itemTagsSectionExpanded = new KConfigCompilerSignallingItem(innerItemTagsSectionExpanded, this, notifyFunction, signalTagsSectionExpandedChanged);
  addItem( itemTagsSectionExpanded, QStringLiteral( "tagsSectionExpanded" ) );
  KConfigCompilerSignallingItem  *itemCollectionsSectionExpanded;
  KConfigSkeleton::ItemBool  *innerItemCollectionsSectionExpanded;
  innerItemCollectionsSectionExpanded = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "collectionsSectionExpanded" ), mCollectionsSectionExpanded, true );
  itemCollectionsSectionExpanded = new KConfigCompilerSignallingItem(innerItemCollectionsSectionExpanded, this, notifyFunction, signalCollectionsSectionExpandedChanged);
  addItem( itemCollectionsSectionExpanded, QStringLiteral( "collectionsSectionExpanded" ) );

  setCurrentGroup( QStringLiteral( "Editor" ) );

  KConfigCompilerSignallingItem  *itemLastUsedEventCollection;
  KConfigSkeleton::ItemInt  *innerItemLastUsedEventCollection;
  innerItemLastUsedEventCollection = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "lastUsedEventCollection" ), mLastUsedEventCollection, -1 );
  itemLastUsedEventCollection = new KConfigCompilerSignallingItem(innerItemLastUsedEventCollection, this, notifyFunction, signalLastUsedEventCollectionChanged);
  addItem( itemLastUsedEventCollection, QStringLiteral( "lastUsedEventCollection" ) );
  KConfigCompilerSignallingItem  *itemLastUsedTodoCollection;
  KConfigSkeleton::ItemInt  *innerItemLastUsedTodoCollection;
  innerItemLastUsedTodoCollection = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "lastUsedTodoCollection" ), mLastUsedTodoCollection, -1 );
  itemLastUsedTodoCollection = new KConfigCompilerSignallingItem(innerItemLastUsedTodoCollection, this, notifyFunction, signalLastUsedTodoCollectionChanged);
  addItem( itemLastUsedTodoCollection, QStringLiteral( "lastUsedTodoCollection" ) );

  setCurrentGroup( QStringLiteral( "GeneralView" ) );

  KConfigCompilerSignallingItem  *itemUseIncidenceInfoPopup;
  KConfigSkeleton::ItemBool  *innerItemUseIncidenceInfoPopup;
  innerItemUseIncidenceInfoPopup = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useIncidenceInfoPopup" ), mUseIncidenceInfoPopup, true );
  itemUseIncidenceInfoPopup = new KConfigCompilerSignallingItem(innerItemUseIncidenceInfoPopup, this, notifyFunction, signalUseIncidenceInfoPopupChanged);
  addItem( itemUseIncidenceInfoPopup, QStringLiteral( "useIncidenceInfoPopup" ) );
  KConfigCompilerSignallingItem  *itemShowHolidaysInCalendarViews;
  KConfigSkeleton::ItemBool  *innerItemShowHolidaysInCalendarViews;
  innerItemShowHolidaysInCalendarViews = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showHolidaysInCalendarViews" ), mShowHolidaysInCalendarViews, true );
  itemShowHolidaysInCalendarViews = new KConfigCompilerSignallingItem(innerItemShowHolidaysInCalendarViews, this, notifyFunction, signalShowHolidaysInCalendarViewsChanged);
  addItem( itemShowHolidaysInCalendarViews, QStringLiteral( "showHolidaysInCalendarViews" ) );
  KConfigCompilerSignallingItem  *itemHolidayRegions;
  KConfigSkeleton::ItemStringList  *innerItemHolidayRegions;
  innerItemHolidayRegions = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "holidayRegions" ), mHolidayRegions );
  itemHolidayRegions = new KConfigCompilerSignallingItem(innerItemHolidayRegions, this, notifyFunction, signalHolidayRegionsChanged);
  addItem( itemHolidayRegions, QStringLiteral( "holidayRegions" ) );
  KConfigCompilerSignallingItem  *itemShowTodosInCalendarViews;
  KConfigSkeleton::ItemBool  *innerItemShowTodosInCalendarViews;
  innerItemShowTodosInCalendarViews = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showTodosInCalendarViews" ), mShowTodosInCalendarViews, true );
  itemShowTodosInCalendarViews = new KConfigCompilerSignallingItem(innerItemShowTodosInCalendarViews, this, notifyFunction, signalShowTodosInCalendarViewsChanged);
  addItem( itemShowTodosInCalendarViews, QStringLiteral( "showTodosInCalendarViews" ) );
  KConfigCompilerSignallingItem  *itemShowSubtodosInCalendarViews;
  KConfigSkeleton::ItemBool  *innerItemShowSubtodosInCalendarViews;
  innerItemShowSubtodosInCalendarViews = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showSubtodosInCalendarViews" ), mShowSubtodosInCalendarViews, true );
  itemShowSubtodosInCalendarViews = new KConfigCompilerSignallingItem(innerItemShowSubtodosInCalendarViews, this, notifyFunction, signalShowSubtodosInCalendarViewsChanged);
  addItem( itemShowSubtodosInCalendarViews, QStringLiteral( "showSubtodosInCalendarViews" ) );

  setCurrentGroup( QStringLiteral( "MonthView" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuesmonthGridMode;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("SwipeableMonthGrid");
    valuesmonthGridMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BasicMonthGrid");
    valuesmonthGridMode.append( choice );
  }
  KConfigCompilerSignallingItem  *itemMonthGridMode;
  KConfigSkeleton::ItemEnum  *innerItemMonthGridMode;
  innerItemMonthGridMode = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "monthGridMode" ), mMonthGridMode, valuesmonthGridMode, int(SwipeableMonthGrid) );
  itemMonthGridMode = new KConfigCompilerSignallingItem(innerItemMonthGridMode, this, notifyFunction, signalMonthGridModeChanged);
  addItem( itemMonthGridMode, QStringLiteral( "monthGridMode" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesweekdayLabelAlignment;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Left");
    valuesweekdayLabelAlignment.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Center");
    valuesweekdayLabelAlignment.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Right");
    valuesweekdayLabelAlignment.append( choice );
  }
  KConfigCompilerSignallingItem  *itemWeekdayLabelAlignment;
  KConfigSkeleton::ItemEnum  *innerItemWeekdayLabelAlignment;
  innerItemWeekdayLabelAlignment = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "weekdayLabelAlignment" ), mWeekdayLabelAlignment, valuesweekdayLabelAlignment, int(Right) );
  itemWeekdayLabelAlignment = new KConfigCompilerSignallingItem(innerItemWeekdayLabelAlignment, this, notifyFunction, signalWeekdayLabelAlignmentChanged);
  addItem( itemWeekdayLabelAlignment, QStringLiteral( "weekdayLabelAlignment" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesweekdayLabelLength;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Full");
    valuesweekdayLabelLength.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Abbreviated");
    valuesweekdayLabelLength.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Letter");
    valuesweekdayLabelLength.append( choice );
  }
  KConfigCompilerSignallingItem  *itemWeekdayLabelLength;
  KConfigSkeleton::ItemEnum  *innerItemWeekdayLabelLength;
  innerItemWeekdayLabelLength = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "weekdayLabelLength" ), mWeekdayLabelLength, valuesweekdayLabelLength, int(Full) );
  itemWeekdayLabelLength = new KConfigCompilerSignallingItem(innerItemWeekdayLabelLength, this, notifyFunction, signalWeekdayLabelLengthChanged);
  addItem( itemWeekdayLabelLength, QStringLiteral( "weekdayLabelLength" ) );
  KConfigCompilerSignallingItem  *itemShowWeekNumbers;
  KConfigSkeleton::ItemBool  *innerItemShowWeekNumbers;
  innerItemShowWeekNumbers = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showWeekNumbers" ), mShowWeekNumbers, false );
  itemShowWeekNumbers = new KConfigCompilerSignallingItem(innerItemShowWeekNumbers, this, notifyFunction, signalShowWeekNumbersChanged);
  addItem( itemShowWeekNumbers, QStringLiteral( "showWeekNumbers" ) );
  KConfigCompilerSignallingItem  *itemMonthGridBorderWidth;
  KConfigSkeleton::ItemInt  *innerItemMonthGridBorderWidth;
  innerItemMonthGridBorderWidth = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "monthGridBorderWidth" ), mMonthGridBorderWidth, 1 );
  itemMonthGridBorderWidth = new KConfigCompilerSignallingItem(innerItemMonthGridBorderWidth, this, notifyFunction, signalMonthGridBorderWidthChanged);
  addItem( itemMonthGridBorderWidth, QStringLiteral( "monthGridBorderWidth" ) );

  setCurrentGroup( QStringLiteral( "WeekView" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valueshourlyViewMode;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("SwipeableInternalHourlyView");
    valueshourlyViewMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BasicInternalHourlyView");
    valueshourlyViewMode.append( choice );
  }
  KConfigCompilerSignallingItem  *itemHourlyViewMode;
  KConfigSkeleton::ItemEnum  *innerItemHourlyViewMode;
  innerItemHourlyViewMode = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "hourlyViewMode" ), mHourlyViewMode, valueshourlyViewMode, int(SwipeableMonthGrid) );
  itemHourlyViewMode = new KConfigCompilerSignallingItem(innerItemHourlyViewMode, this, notifyFunction, signalHourlyViewModeChanged);
  addItem( itemHourlyViewMode, QStringLiteral( "hourlyViewMode" ) );
  KConfigCompilerSignallingItem  *itemWeekViewAllDayHeaderHeight;
  KConfigSkeleton::ItemInt  *innerItemWeekViewAllDayHeaderHeight;
  innerItemWeekViewAllDayHeaderHeight = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "weekViewAllDayHeaderHeight" ), mWeekViewAllDayHeaderHeight, -1 );
  itemWeekViewAllDayHeaderHeight = new KConfigCompilerSignallingItem(innerItemWeekViewAllDayHeaderHeight, this, notifyFunction, signalWeekViewAllDayHeaderHeightChanged);
  addItem( itemWeekViewAllDayHeaderHeight, QStringLiteral( "weekViewAllDayHeaderHeight" ) );

  setCurrentGroup( QStringLiteral( "ScheduleView" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuesmonthListMode;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("SwipeableMonthList");
    valuesmonthListMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BasicMonthList");
    valuesmonthListMode.append( choice );
  }
  KConfigCompilerSignallingItem  *itemMonthListMode;
  KConfigSkeleton::ItemEnum  *innerItemMonthListMode;
  innerItemMonthListMode = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "monthListMode" ), mMonthListMode, valuesmonthListMode, int(SwipeableMonthList) );
  itemMonthListMode = new KConfigCompilerSignallingItem(innerItemMonthListMode, this, notifyFunction, signalMonthListModeChanged);
  addItem( itemMonthListMode, QStringLiteral( "monthListMode" ) );
  KConfigCompilerSignallingItem  *itemShowWeekHeaders;
  KConfigSkeleton::ItemBool  *innerItemShowWeekHeaders;
  innerItemShowWeekHeaders = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showWeekHeaders" ), mShowWeekHeaders, true );
  itemShowWeekHeaders = new KConfigCompilerSignallingItem(innerItemShowWeekHeaders, this, notifyFunction, signalShowWeekHeadersChanged);
  addItem( itemShowWeekHeaders, QStringLiteral( "showWeekHeaders" ) );
  KConfigCompilerSignallingItem  *itemHideEmptyDays;
  KConfigSkeleton::ItemBool  *innerItemHideEmptyDays;
  innerItemHideEmptyDays = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "hideEmptyDays" ), mHideEmptyDays, false );
  itemHideEmptyDays = new KConfigCompilerSignallingItem(innerItemHideEmptyDays, this, notifyFunction, signalHideEmptyDaysChanged);
  addItem( itemHideEmptyDays, QStringLiteral( "hideEmptyDays" ) );

  setCurrentGroup( QStringLiteral( "TaskView" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuessort;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("DueTime");
    valuessort.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Alphabetically");
    valuessort.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Priority");
    valuessort.append( choice );
  }
  KConfigCompilerSignallingItem  *itemSort;
  KConfigSkeleton::ItemEnum  *innerItemSort;
  innerItemSort = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "sort" ), mSort, valuessort, int(DueTime) );
  itemSort = new KConfigCompilerSignallingItem(innerItemSort, this, notifyFunction, signalSortChanged);
  addItem( itemSort, QStringLiteral( "sort" ) );
  KConfigCompilerSignallingItem  *itemAscendingOrder;
  KConfigSkeleton::ItemBool  *innerItemAscendingOrder;
  innerItemAscendingOrder = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ascendingOrder" ), mAscendingOrder, true );
  itemAscendingOrder = new KConfigCompilerSignallingItem(innerItemAscendingOrder, this, notifyFunction, signalAscendingOrderChanged);
  addItem( itemAscendingOrder, QStringLiteral( "ascendingOrder" ) );
  KConfigCompilerSignallingItem  *itemShowCompletedSubtodos;
  KConfigSkeleton::ItemBool  *innerItemShowCompletedSubtodos;
  innerItemShowCompletedSubtodos = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showCompletedSubtodos" ), mShowCompletedSubtodos, true );
  itemShowCompletedSubtodos = new KConfigCompilerSignallingItem(innerItemShowCompletedSubtodos, this, notifyFunction, signalShowCompletedSubtodosChanged);
  addItem( itemShowCompletedSubtodos, QStringLiteral( "showCompletedSubtodos" ) );
  KConfigCompilerSignallingItem  *itemPastEventsTransparencyLevel;
  KConfigSkeleton::ItemDouble  *innerItemPastEventsTransparencyLevel;
  innerItemPastEventsTransparencyLevel = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "pastEventsTransparencyLevel" ), mPastEventsTransparencyLevel, 0 );
  itemPastEventsTransparencyLevel = new KConfigCompilerSignallingItem(innerItemPastEventsTransparencyLevel, this, notifyFunction, signalPastEventsTransparencyLevelChanged);
  addItem( itemPastEventsTransparencyLevel, QStringLiteral( "pastEventsTransparencyLevel" ) );
}

bool CalendarConfig::defaultShowMenubarValue_helper() const
{

  return false;
}

bool CalendarConfig::defaultForceCollapsedMainDrawerValue_helper() const
{

  return false;
}

bool CalendarConfig::defaultEnableMapsValue_helper() const
{

  return false;
}

bool CalendarConfig::defaultEnableMailIntegrationValue_helper() const
{

  return false;
}

int CalendarConfig::defaultLocationMarkerValue_helper() const
{

  return Pin;
}

int CalendarConfig::defaultLastOpenedViewValue_helper() const
{

  return -1;
}

int CalendarConfig::defaultIncidenceInfoDrawerDrawerWidthValue_helper() const
{

  return -1;
}

bool CalendarConfig::defaultTagsSectionExpandedValue_helper() const
{

  return true;
}

bool CalendarConfig::defaultCollectionsSectionExpandedValue_helper() const
{

  return true;
}

int CalendarConfig::defaultLastUsedEventCollectionValue_helper() const
{

  return -1;
}

int CalendarConfig::defaultLastUsedTodoCollectionValue_helper() const
{

  return -1;
}

bool CalendarConfig::defaultUseIncidenceInfoPopupValue_helper() const
{

  return true;
}

bool CalendarConfig::defaultShowHolidaysInCalendarViewsValue_helper() const
{

  return true;
}

bool CalendarConfig::defaultShowTodosInCalendarViewsValue_helper() const
{

  return true;
}

bool CalendarConfig::defaultShowSubtodosInCalendarViewsValue_helper() const
{

  return true;
}

int CalendarConfig::defaultMonthGridModeValue_helper() const
{

  return SwipeableMonthGrid;
}

int CalendarConfig::defaultWeekdayLabelAlignmentValue_helper() const
{

  return Right;
}

int CalendarConfig::defaultWeekdayLabelLengthValue_helper() const
{

  return Full;
}

bool CalendarConfig::defaultShowWeekNumbersValue_helper() const
{

  return false;
}

int CalendarConfig::defaultMonthGridBorderWidthValue_helper() const
{

  return 1;
}

int CalendarConfig::defaultHourlyViewModeValue_helper() const
{

  return SwipeableMonthGrid;
}

int CalendarConfig::defaultWeekViewAllDayHeaderHeightValue_helper() const
{

  return -1;
}

int CalendarConfig::defaultMonthListModeValue_helper() const
{

  return SwipeableMonthList;
}

bool CalendarConfig::defaultShowWeekHeadersValue_helper() const
{

  return true;
}

bool CalendarConfig::defaultHideEmptyDaysValue_helper() const
{

  return false;
}

int CalendarConfig::defaultSortValue_helper() const
{

  return DueTime;
}

bool CalendarConfig::defaultAscendingOrderValue_helper() const
{

  return true;
}

bool CalendarConfig::defaultShowCompletedSubtodosValue_helper() const
{

  return true;
}

double CalendarConfig::defaultPastEventsTransparencyLevelValue_helper() const
{

  return 0;
}

CalendarConfig::~CalendarConfig()
{
}


void CalendarConfig::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalShowMenubarChanged:
    Q_EMIT showMenubarChanged();
    break;
  case signalForceCollapsedMainDrawerChanged:
    Q_EMIT forceCollapsedMainDrawerChanged();
    break;
  case signalEnableMapsChanged:
    Q_EMIT enableMapsChanged();
    break;
  case signalEnableMailIntegrationChanged:
    Q_EMIT enableMailIntegrationChanged();
    break;
  case signalLocationMarkerChanged:
    Q_EMIT locationMarkerChanged();
    break;
  case signalLastOpenedViewChanged:
    Q_EMIT lastOpenedViewChanged();
    break;
  case signalIncidenceInfoDrawerDrawerWidthChanged:
    Q_EMIT incidenceInfoDrawerDrawerWidthChanged();
    break;
  case signalTagsSectionExpandedChanged:
    Q_EMIT tagsSectionExpandedChanged();
    break;
  case signalCollectionsSectionExpandedChanged:
    Q_EMIT collectionsSectionExpandedChanged();
    break;
  case signalLastUsedEventCollectionChanged:
    Q_EMIT lastUsedEventCollectionChanged();
    break;
  case signalLastUsedTodoCollectionChanged:
    Q_EMIT lastUsedTodoCollectionChanged();
    break;
  case signalUseIncidenceInfoPopupChanged:
    Q_EMIT useIncidenceInfoPopupChanged();
    break;
  case signalShowHolidaysInCalendarViewsChanged:
    Q_EMIT showHolidaysInCalendarViewsChanged();
    break;
  case signalHolidayRegionsChanged:
    Q_EMIT holidayRegionsChanged();
    break;
  case signalShowTodosInCalendarViewsChanged:
    Q_EMIT showTodosInCalendarViewsChanged();
    break;
  case signalShowSubtodosInCalendarViewsChanged:
    Q_EMIT showSubtodosInCalendarViewsChanged();
    break;
  case signalMonthGridModeChanged:
    Q_EMIT monthGridModeChanged();
    break;
  case signalWeekdayLabelAlignmentChanged:
    Q_EMIT weekdayLabelAlignmentChanged();
    break;
  case signalWeekdayLabelLengthChanged:
    Q_EMIT weekdayLabelLengthChanged();
    break;
  case signalShowWeekNumbersChanged:
    Q_EMIT showWeekNumbersChanged();
    break;
  case signalMonthGridBorderWidthChanged:
    Q_EMIT monthGridBorderWidthChanged();
    break;
  case signalHourlyViewModeChanged:
    Q_EMIT hourlyViewModeChanged();
    break;
  case signalWeekViewAllDayHeaderHeightChanged:
    Q_EMIT weekViewAllDayHeaderHeightChanged();
    break;
  case signalMonthListModeChanged:
    Q_EMIT monthListModeChanged();
    break;
  case signalShowWeekHeadersChanged:
    Q_EMIT showWeekHeadersChanged();
    break;
  case signalHideEmptyDaysChanged:
    Q_EMIT hideEmptyDaysChanged();
    break;
  case signalSortChanged:
    Q_EMIT sortChanged();
    break;
  case signalAscendingOrderChanged:
    Q_EMIT ascendingOrderChanged();
    break;
  case signalShowCompletedSubtodosChanged:
    Q_EMIT showCompletedSubtodosChanged();
    break;
  case signalPastEventsTransparencyLevelChanged:
    Q_EMIT pastEventsTransparencyLevelChanged();
    break;
  }
}
