// /qt/qml/org/kde/merkuro/calendar/qml/Controls/KBMNavigationMouseArea.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_merkuro_calendar_qml_Controls_KBMNavigationMouseArea_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x4a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x64,0x8,0x0,0x0,0x67,0xa,0x85,0xda,
0x52,0x2,0xdf,0x84,0x8c,0xad,0xc3,0xb7,
0x29,0x6e,0x59,0x42,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0xe0,0x3,0x0,0x0,
0x6,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0xe8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0x7,0x0,0x0,
0x20,0x1,0x0,0x0,0x78,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x60,0x2,0x0,0x0,
0xd8,0x2,0x0,0x0,0x48,0x3,0x0,0x0,
0xc0,0x3,0x0,0x0,0xd0,0x3,0x0,0x0,
0xe3,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0xe3,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x13,0x1,0x0,0x0,0x13,0x1,0x0,0x0,
0x20,0x1,0x0,0x0,0x13,0x1,0x0,0x0,
0x34,0x1,0x0,0x0,0x97,0x0,0x0,0x0,
0x41,0x1,0x0,0x0,0x97,0x0,0x0,0x0,
0x41,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x9,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x18,0x7,0x2e,0x2,0x3c,0x3,0x84,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0xd,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xa,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x2e,0x4,0x50,0xf,
0x2e,0x5,0x3c,0x6,0x50,0x9,0x2e,0x7,
0x18,0x7,0xac,0x8,0x7,0x0,0x0,0xe,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x3,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x13,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x8,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xca,0x28,0x3,0x18,
0x6,0xd4,0x16,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x64,0x0,0x0,0x0,0xa,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x1,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x13,0x0,0xe0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x0,0x0,0x2,0x0,
0x15,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0xb4,0x9,0x0,0x0,
0xa,0x42,0xa,0x6,0xe,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x5,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x18,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x8,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xca,0x28,0x5,0x18,
0x6,0xd4,0x16,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x64,0x0,0x0,0x0,0xa,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x1,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x18,0x0,0x50,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x0,0x0,0x2,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0xb4,0xb,0x0,0x0,
0xa,0x42,0xc,0x6,0xe,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x40,0x4,0x0,0x0,0x48,0x4,0x0,0x0,
0x60,0x4,0x0,0x0,0x70,0x4,0x0,0x0,
0x98,0x4,0x0,0x0,0xb0,0x4,0x0,0x0,
0xd8,0x4,0x0,0x0,0x20,0x5,0x0,0x0,
0x58,0x5,0x0,0x0,0x78,0x5,0x0,0x0,
0xb0,0x5,0x0,0x0,0xc8,0x5,0x0,0x0,
0x0,0x6,0x0,0x0,0x28,0x6,0x0,0x0,
0x68,0x6,0x0,0x0,0x78,0x6,0x0,0x0,
0x98,0x6,0x0,0x0,0xb8,0x6,0x0,0x0,
0xe8,0x6,0x0,0x0,0x0,0x7,0x0,0x0,
0x20,0x7,0x0,0x0,0x38,0x7,0x0,0x0,
0x48,0x7,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x51,0x0,0x51,0x0,
0x43,0x0,0x32,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x2e,0x0,0x43,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,
0x6c,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x4d,0x0,0x6f,0x0,
0x75,0x0,0x73,0x0,0x65,0x0,0x41,0x0,
0x72,0x0,0x65,0x0,0x61,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x61,0x0,0x63,0x0,
0x63,0x0,0x65,0x0,0x70,0x0,0x74,0x0,
0x65,0x0,0x64,0x0,0x42,0x0,0x75,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6e,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x61,0x0,0x63,0x0,0x63,0x0,
0x65,0x0,0x70,0x0,0x74,0x0,0x65,0x0,
0x64,0x0,0x42,0x0,0x75,0x0,0x74,0x0,
0x74,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x70,0x0,0x72,0x0,
0x6f,0x0,0x70,0x0,0x61,0x0,0x67,0x0,
0x61,0x0,0x74,0x0,0x65,0x0,0x43,0x0,
0x6f,0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,
0x73,0x0,0x65,0x0,0x64,0x0,0x45,0x0,
0x76,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x68,0x0,0x6f,0x0,
0x76,0x0,0x65,0x0,0x72,0x0,0x45,0x0,
0x6e,0x0,0x61,0x0,0x62,0x0,0x6c,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x72,0x0,0x65,0x0,
0x70,0x0,0x6f,0x0,0x73,0x0,0x69,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x49,0x0,0x6e,0x0,0x63,0x0,0x69,0x0,
0x64,0x0,0x65,0x0,0x6e,0x0,0x63,0x0,
0x65,0x0,0x50,0x0,0x6f,0x0,0x70,0x0,
0x75,0x0,0x70,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x57,0x0,0x68,0x0,0x65,0x0,0x65,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x57,0x0,
0x68,0x0,0x65,0x0,0x65,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x50,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x41,0x0,0x6e,0x0,0x64,0x0,
0x48,0x0,0x6f,0x0,0x6c,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x50,0x0,
0x72,0x0,0x65,0x0,0x73,0x0,0x73,0x0,
0x41,0x0,0x6e,0x0,0x64,0x0,0x48,0x0,
0x6f,0x0,0x6c,0x0,0x64,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x42,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x42,0x0,0x75,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x46,0x0,0x6f,0x0,
0x72,0x0,0x77,0x0,0x61,0x0,0x72,0x0,
0x64,0x0,0x42,0x0,0x75,0x0,0x74,0x0,
0x74,0x0,0x6f,0x0,0x6e,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x69,0x0,0x6e,0x0,
0x63,0x0,0x69,0x0,0x64,0x0,0x65,0x0,
0x6e,0x0,0x63,0x0,0x65,0x0,0x49,0x0,
0x6e,0x0,0x66,0x0,0x6f,0x0,0x50,0x0,
0x6f,0x0,0x70,0x0,0x75,0x0,0x70,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x76,0x0,0x69,0x0,
0x73,0x0,0x69,0x0,0x62,0x0,0x6c,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x72,0x0,0x65,0x0,
0x70,0x0,0x6f,0x0,0x73,0x0,0x69,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x61,0x0,0x63,0x0,
0x63,0x0,0x65,0x0,0x70,0x0,0x74,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x68,0x0,
0x65,0x0,0x65,0x0,0x6c,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x6d,0x0,0x6f,0x0,
0x75,0x0,0x73,0x0,0x65,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x6,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x3c,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x1,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x0,0x0,0x5,0x0,0x58,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0x0,0x0,0x0,0x0,
0xd0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x0,0x2,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x50,0x0,
0x18,0x0,0x50,0x1,0xa,0x0,0x0,0x0,
0x0,0x2,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x50,0x0,
0x13,0x0,0xe0,0x0,0x8,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x50,0x0,
0xb,0x0,0x30,0x1,0x7,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xa,0x0,0x50,0x0,
0xa,0x0,0xe0,0x1,0x5,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9,0x0,0x50,0x0,
0x9,0x0,0x60,0x1
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("Qt::MouseButtons"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for acceptedButtons at line 9, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_10;
int v2_2;
int v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(1, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(1, []() { static const auto t = QMetaType::fromName("Qt"); return t; }().metaObject(), "MouseButton", "BackButton");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Qt::MouseButtons"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getEnumLookup(3, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetEnumLookup(3, []() { static const auto t = QMetaType::fromName("Qt"); return t; }().metaObject(), "MouseButton", "ForwardButton");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Qt::MouseButtons"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_BitOr
s.v2_10 = (s.v2_2 | s.v2_8);
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_10);
}
return;
}
 },{ 2, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickWheelEvent*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onWheel at line 19, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 3, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickWheelEvent*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
//  at line 19, column 14
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(a1, markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *a1 = (*static_cast<QObject **>(argv[1]));
QVariant v2_0;
bool v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CallQmlContextPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callQmlContextPropertyLookup(9, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallQmlContextPropertyLookup(9, 1);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_0 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_0);
}
{
}
// generate_LoadFalse
s.v2_4 = false;
{
}
// generate_SetLookup
{
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->setObjectLookup(10, s.a1, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initSetObjectLookup(10, s.a1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 4, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickMouseEvent*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onPressAndHold at line 24, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 5, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickMouseEvent*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
//  at line 24, column 21
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(a1, markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *a1 = (*static_cast<QObject **>(argv[1]));
QVariant v2_0;
bool v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CallQmlContextPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callQmlContextPropertyLookup(11, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallQmlContextPropertyLookup(11, 1);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_0 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_0);
}
{
}
// generate_LoadFalse
s.v2_4 = false;
{
}
// generate_SetLookup
{
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->setObjectLookup(12, s.a1, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initSetObjectLookup(12, s.a1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
