// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "merkuro_components_debug.h"


Q_LOGGING_CATEGORY(merkuro_components_LOG, "org.kde.merkuro.components", QtInfoMsg)

