// This file is autogenerated by CMake. Do not edit.

#include <QtCore/qtsymbolmacros.h>
#include <QtQml/qqmlextensionplugin.h>


QT_DECLARE_EXTERN_RESOURCE(qmlcache_merkuro_mail_static)
QT_DECLARE_EXTERN_RESOURCE(qmake_org_kde_merkuro_mail)
QT_DECLARE_EXTERN_RESOURCE(merkuro_mail_static_raw_qml_0)
QT_DECLARE_EXTERN_RESOURCE(merkuro_mail_static_raw_qml_1)
QT_DECLARE_EXTERN_RESOURCE(merkuro_mail_static_raw_qml_2)
QT_DECLARE_EXTERN_RESOURCE(merkuro_mail_static_raw_qml_3)
QT_DECLARE_EXTERN_RESOURCE(merkuro_mail_static_raw_qml_4)


QT_DECLARE_EXTERN_SYMBOL_VOID(qml_register_types_org_kde_merkuro_mail)

class org_kde_merkuro_mailPlugin : public QQmlEngineExtensionPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID QQmlEngineExtensionInterface_iid)

public:
    org_kde_merkuro_mailPlugin(QObject *parent = nullptr) : QQmlEngineExtensionPlugin(parent)
    {

QT_KEEP_SYMBOL(qml_register_types_org_kde_merkuro_mail)
QT_KEEP_RESOURCE(qmlcache_merkuro_mail_static)
QT_KEEP_RESOURCE(qmake_org_kde_merkuro_mail)
QT_KEEP_RESOURCE(merkuro_mail_static_raw_qml_0)
QT_KEEP_RESOURCE(merkuro_mail_static_raw_qml_1)
QT_KEEP_RESOURCE(merkuro_mail_static_raw_qml_2)
QT_KEEP_RESOURCE(merkuro_mail_static_raw_qml_3)
QT_KEEP_RESOURCE(merkuro_mail_static_raw_qml_4)
    }
};



#include "merkuro_mail_staticplugin_org_kde_merkuro_mailPlugin.moc"
