/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xbd,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x20,0x5,0x9d,0xd,0x0,0x36,0xd3,0x38,0x1e,0x40,0x8f,0xda,
  0x8c,0x4d,0xb6,0xd8,0x22,0xfb,0x4b,0x6c,0xd,0x7f,0xf,0x37,0x0,0xc2,0xd0,0x16,
  0xb3,0x8e,0x10,0xc6,0xf6,0x46,0x14,0x35,0xa8,0x71,0x1,0x30,0x0,0x33,0x0,0x2e,
  0x0,0x94,0x74,0xb7,0x32,0xfd,0x88,0xa2,0xa,0x93,0x19,0x9f,0xe4,0x3c,0x4c,0x75,
  0x6d,0x69,0x93,0x6e,0xba,0x9e,0x15,0x39,0xfd,0x69,0xb1,0xa9,0x74,0xaf,0x69,0x9,
  0x3b,0x55,0x7a,0x74,0x2f,0x6a,0x5f,0x3d,0x6f,0xd4,0x33,0xad,0x3a,0x7f,0x57,0xd3,
  0x2a,0x8b,0x66,0xc7,0x78,0x38,0xd1,0x97,0x98,0xbc,0xb9,0xc8,0xa2,0xe1,0xca,0x37,
  0x30,0x77,0x12,0x7,0xf0,0x8,0x6,0x1,0xe7,0x13,0x3e,0xf6,0xac,0x5a,0x81,0xa0,
  0x86,0x31,0xf6,0x46,0xb1,0x69,0x95,0xb1,0xb6,0x30,0x82,0xb3,0xa7,0x7c,0xad,0x86,
  0x5f,0x65,0x79,0x34,0x7,0x4a,0xd5,0xc0,0xfc,0x6d,0xad,0xf0,0xa6,0xd0,0x42,0x26,
  0x7d,0xe8,0xe,0xfb,0x49,0x75,0x39,0x9e,0x5a,0x79,0xec,0x1b,0x5e,0xc1,0x6c,0x5d,
  0xba,0x9,0xf6,0xc6,0x8b,0x5b,0xeb,0x61,0xee,0x3b,0x1d,0x4f,0xe9,0xba,0x9f,0xe,
  0xab,0x77,0x4d,0x43,0x49,0xee,0x82,0x34,0xc4,0xe1,0x96,0xb7,0xde,0xf6,0x53,0x9e,
  0xf9,0x8d,0x4e,0x6c,0xce,0x45,0x2b,0x25,0x17,0xf,0x53,0x79,0xff,0x1c,0x56,0x8,
  0xe6,0xa7,0xe3,0xcb,0xc0,0x1e,0xb5,0x45,0x68,0xb5,0x5d,0x43,0xbc,0xff,0x1e,0x60,
  0xa0,0x61,0x1e,0x11,0x19,0x92,0x92,0x94,0x14,0xb3,0x1b,0x30,0x44,0x40,0xa0,0x66,
  0x73,0x1d,0xa1,0xa6,0xdd,0x38,0x76,0xfe,0x92,0x29,0x6c,0xe8,0x2,0x89,0xec,0x61,
  0x51,0x39,0xe3,0x1c,0xa3,0x26,0x63,0x14,0xc4,0x89,0x8e,0x28,0x3b,0x2a,0x3b,0x4d,
  0x9e,0xb3,0xea,0x13,0xed,0x20,0xeb,0x24,0xf2,0xce,0x22,0x33,0xf1,0xb,0x32,0x17,
  0x62,0x50,0xec,0xd7,0xf4,0x1a,0xb2,0x63,0x2a,0x2f,0xec,0x37,0x1e,0xda,0x62,0x71,
  0xa0,0x0,0x6d,0xcd,0xf2,0x9f,0xf4,0x50,0xe7,0xaf,0x2c,0x46,0xbe,0xf4,0x73,0x15,
  0x70,0x69,0xc0,0x29,0x99,0xc1,0xca,0x70,0xe4,0xc8,0x9b,0xb9,0xc6,0x1a,0x23,0x29,
  0xb1,0x64,0xa,0xc8,0xbc,0xb3,0x69,0x5a,0x8b,0x67,0xaf,0xf2,0xc0,0xfe,0xb8,0x60,
  0x16,0x74,0x17,0x8a,0xfc,0xb7,0x80,0x64,0x1b,0x79,0x80,0x8c,0x7,0x58,0x50,0x76,
  0xd8,0x20,0x77,0x5b,0xcc,0xfc,0x70,0xf7,0x88,0xdd,0xa5,0x73,0x27,0xe0,0xa5,0x79,
  0xc7,0xbc,0x4,0xb9,0xb4,0xd5,0x8,0x33,0xee,0xec,0x87,0xad,0x2f,0xc6,0x5e,0x65,
  0xd,0x92,0x1b,0x4a,0x86,0xe2,0x90,0x3e,0x82,0x57,0x2,0xe9,0xe1,0xd6,0x74,0x6,
  0x86,0xf5,0x92,0xae,0xcb,0x18,0x7e,0xb2,0x23,0xcf,0x4c,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // merkuro
  0x0,0x7,
  0x3,0xc9,0x2c,0x6f,
  0x0,0x6d,
  0x0,0x65,0x0,0x72,0x0,0x6b,0x0,0x75,0x0,0x72,0x0,0x6f,
    // contact
  0x0,0x7,
  0xa,0x65,0xa7,0x64,
  0x0,0x63,
  0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x61,0x0,0x63,0x0,0x74,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x1a,0xee,0x1a,0x18,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x1a,0xee,0x1a,0x18,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x1a,0xee,0x1a,0x18,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0xa0,0x1a,0xee,0x1a,0x18,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0xa0,0x1a,0xee,0x1a,0x18,
  // :/qt/qml/org/kde/merkuro
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0xa0,0x1a,0xee,0x1a,0x18,
  // :/qt/qml/org/kde/merkuro/contact
  0x0,0x0,0x0,0x42,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0xa0,0x1a,0xee,0x1a,0x18,
  // :/qt/qml/org/kde/merkuro/contact/qmldir
  0x0,0x0,0x0,0x56,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x1a,0xee,0x1a,0x18,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_merkuro_contact)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_merkuro_contact)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_merkuro_contact)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_merkuro_contact)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_merkuro_contact)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_merkuro_contact)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
