/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<addresseewrapper.h>)
#  include <addresseewrapper.h>
#endif
#if __has_include(<avatarimageprovider.h>)
#  include <avatarimageprovider.h>
#endif
#if __has_include(<certificatesmodel.h>)
#  include <certificatesmodel.h>
#endif
#if __has_include(<contactactions.h>)
#  include <contactactions.h>
#endif
#if __has_include(<contactapplication.h>)
#  include <contactapplication.h>
#endif
#if __has_include(<contactconfig.h>)
#  include <contactconfig.h>
#endif
#if __has_include(<contacteditorbackend.h>)
#  include <contacteditorbackend.h>
#endif
#if __has_include(<contactgroupeditor.h>)
#  include <contactgroupeditor.h>
#endif
#if __has_include(<contactgroupwrapper.h>)
#  include <contactgroupwrapper.h>
#endif
#if __has_include(<contactmanager.h>)
#  include <contactmanager.h>
#endif
#if __has_include(<contactsmodel.h>)
#  include <contactsmodel.h>
#endif
#if __has_include(<emailmodel.h>)
#  include <emailmodel.h>
#endif
#if __has_include(<imppservicelistmodel.h>)
#  include <imppservicelistmodel.h>
#endif
#if __has_include(<phonemodel.h>)
#  include <phonemodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_merkuro_contact()
{
    qmlRegisterModule("org.kde.merkuro.contact", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AddresseeWrapper>("org.kde.merkuro.contact", 254);
    qmlRegisterEnum<AddresseeWrapper::DisplayType>("AddresseeWrapper::DisplayType");
    qmlRegisterTypesAndRevisions<AvatarImageProvider>("org.kde.merkuro.contact", 254);
    qmlRegisterTypesAndRevisions<CertificatesModel>("org.kde.merkuro.contact", 254);
    qmlRegisterTypesAndRevisions<ContactActions>("org.kde.merkuro.contact", 254);
    qmlRegisterTypesAndRevisions<ContactApplication>("org.kde.merkuro.contact", 254);
    qmlRegisterTypesAndRevisions<ContactConfig>("org.kde.merkuro.contact", 254);
    qmlRegisterTypesAndRevisions<ContactEditorBackend>("org.kde.merkuro.contact", 254);
    qmlRegisterEnum<ContactEditorBackend::Mode>("ContactEditorBackend::Mode");
    qmlRegisterTypesAndRevisions<ContactGroupEditor>("org.kde.merkuro.contact", 254);
    qmlRegisterEnum<ContactGroupEditor::Mode>("ContactGroupEditor::Mode");
    qmlRegisterTypesAndRevisions<ContactGroupWrapper>("org.kde.merkuro.contact", 254);
    qmlRegisterTypesAndRevisions<ContactManager>("org.kde.merkuro.contact", 254);
    qmlRegisterTypesAndRevisions<ContactsModel>("org.kde.merkuro.contact", 254);
    qmlRegisterEnum<ContactsModel::ExtraRoles>("ContactsModel::ExtraRoles");
    qmlRegisterTypesAndRevisions<EmailModel>("org.kde.merkuro.contact", 254);
    qmlRegisterEnum<EmailModel::Type>("EmailModel::Type");
    qmlRegisterTypesAndRevisions<ImppServiceListModel>("org.kde.merkuro.contact", 254);
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    qmlRegisterTypesAndRevisions<PhoneModel>("org.kde.merkuro.contact", 254);
    qmlRegisterEnum<PhoneModel::Type>("PhoneModel::Type");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.merkuro.contact", 254, 254);
}

static const QQmlModuleRegistration orgkdemerkurocontactRegistration("org.kde.merkuro.contact", qml_register_types_org_kde_merkuro_contact);
