/****************************************************************************
** Meta object code from reading C++ file 'calendarconfig.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../calendarconfig.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendarconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14CalendarConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarConfig::qt_create_metaobjectdata<qt_meta_tag_ZN14CalendarConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarConfig",
        "showMenubarChanged",
        "",
        "forceCollapsedMainDrawerChanged",
        "enableMapsChanged",
        "enableMailIntegrationChanged",
        "locationMarkerChanged",
        "lastOpenedViewChanged",
        "incidenceInfoDrawerDrawerWidthChanged",
        "tagsSectionExpandedChanged",
        "collectionsSectionExpandedChanged",
        "lastUsedEventCollectionChanged",
        "lastUsedTodoCollectionChanged",
        "useIncidenceInfoPopupChanged",
        "showHolidaysInCalendarViewsChanged",
        "holidayRegionsChanged",
        "showTodosInCalendarViewsChanged",
        "showSubtodosInCalendarViewsChanged",
        "monthGridModeChanged",
        "weekdayLabelAlignmentChanged",
        "weekdayLabelLengthChanged",
        "showWeekNumbersChanged",
        "monthGridBorderWidthChanged",
        "hourlyViewModeChanged",
        "weekViewAllDayHeaderHeightChanged",
        "monthListModeChanged",
        "showWeekHeadersChanged",
        "hideEmptyDaysChanged",
        "sortChanged",
        "ascendingOrderChanged",
        "showCompletedSubtodosChanged",
        "pastEventsTransparencyLevelChanged",
        "showMenubar",
        "isShowMenubarImmutable",
        "defaultShowMenubarValue",
        "forceCollapsedMainDrawer",
        "isForceCollapsedMainDrawerImmutable",
        "defaultForceCollapsedMainDrawerValue",
        "enableMaps",
        "isEnableMapsImmutable",
        "defaultEnableMapsValue",
        "enableMailIntegration",
        "isEnableMailIntegrationImmutable",
        "defaultEnableMailIntegrationValue",
        "locationMarker",
        "EnumLocationMarker",
        "isLocationMarkerImmutable",
        "defaultLocationMarkerValue",
        "lastOpenedView",
        "EnumLastOpenedView",
        "isLastOpenedViewImmutable",
        "defaultLastOpenedViewValue",
        "incidenceInfoDrawerDrawerWidth",
        "isIncidenceInfoDrawerDrawerWidthImmutable",
        "defaultIncidenceInfoDrawerDrawerWidthValue",
        "tagsSectionExpanded",
        "isTagsSectionExpandedImmutable",
        "defaultTagsSectionExpandedValue",
        "collectionsSectionExpanded",
        "isCollectionsSectionExpandedImmutable",
        "defaultCollectionsSectionExpandedValue",
        "lastUsedEventCollection",
        "isLastUsedEventCollectionImmutable",
        "defaultLastUsedEventCollectionValue",
        "lastUsedTodoCollection",
        "isLastUsedTodoCollectionImmutable",
        "defaultLastUsedTodoCollectionValue",
        "useIncidenceInfoPopup",
        "isUseIncidenceInfoPopupImmutable",
        "defaultUseIncidenceInfoPopupValue",
        "showHolidaysInCalendarViews",
        "isShowHolidaysInCalendarViewsImmutable",
        "defaultShowHolidaysInCalendarViewsValue",
        "holidayRegions",
        "isHolidayRegionsImmutable",
        "showTodosInCalendarViews",
        "isShowTodosInCalendarViewsImmutable",
        "defaultShowTodosInCalendarViewsValue",
        "showSubtodosInCalendarViews",
        "isShowSubtodosInCalendarViewsImmutable",
        "defaultShowSubtodosInCalendarViewsValue",
        "monthGridMode",
        "EnumMonthGridMode",
        "isMonthGridModeImmutable",
        "defaultMonthGridModeValue",
        "weekdayLabelAlignment",
        "EnumWeekdayLabelAlignment",
        "isWeekdayLabelAlignmentImmutable",
        "defaultWeekdayLabelAlignmentValue",
        "weekdayLabelLength",
        "EnumWeekdayLabelLength",
        "isWeekdayLabelLengthImmutable",
        "defaultWeekdayLabelLengthValue",
        "showWeekNumbers",
        "isShowWeekNumbersImmutable",
        "defaultShowWeekNumbersValue",
        "monthGridBorderWidth",
        "isMonthGridBorderWidthImmutable",
        "defaultMonthGridBorderWidthValue",
        "hourlyViewMode",
        "EnumHourlyViewMode",
        "isHourlyViewModeImmutable",
        "defaultHourlyViewModeValue",
        "weekViewAllDayHeaderHeight",
        "isWeekViewAllDayHeaderHeightImmutable",
        "defaultWeekViewAllDayHeaderHeightValue",
        "monthListMode",
        "EnumMonthListMode",
        "isMonthListModeImmutable",
        "defaultMonthListModeValue",
        "showWeekHeaders",
        "isShowWeekHeadersImmutable",
        "defaultShowWeekHeadersValue",
        "hideEmptyDays",
        "isHideEmptyDaysImmutable",
        "defaultHideEmptyDaysValue",
        "sort",
        "EnumSort",
        "isSortImmutable",
        "defaultSortValue",
        "ascendingOrder",
        "isAscendingOrderImmutable",
        "defaultAscendingOrderValue",
        "showCompletedSubtodos",
        "isShowCompletedSubtodosImmutable",
        "defaultShowCompletedSubtodosValue",
        "pastEventsTransparencyLevel",
        "isPastEventsTransparencyLevelImmutable",
        "defaultPastEventsTransparencyLevelValue",
        "Circle",
        "Pin",
        "MonthView",
        "ScheduleView",
        "TodoView",
        "WeekView",
        "WorkWeekView",
        "ThreeDayView",
        "DayView",
        "ContactView",
        "MailView",
        "SwipeableMonthGrid",
        "BasicMonthGrid",
        "Left",
        "Center",
        "Right",
        "Full",
        "Abbreviated",
        "Letter",
        "SwipeableInternalHourlyView",
        "BasicInternalHourlyView",
        "SwipeableMonthList",
        "BasicMonthList",
        "DueTime",
        "Alphabetically",
        "Priority"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showMenubarChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'forceCollapsedMainDrawerChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableMapsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableMailIntegrationChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'locationMarkerChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastOpenedViewChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceInfoDrawerDrawerWidthChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tagsSectionExpandedChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collectionsSectionExpandedChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastUsedEventCollectionChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastUsedTodoCollectionChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useIncidenceInfoPopupChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showHolidaysInCalendarViewsChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'holidayRegionsChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTodosInCalendarViewsChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSubtodosInCalendarViewsChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monthGridModeChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weekdayLabelAlignmentChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weekdayLabelLengthChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showWeekNumbersChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monthGridBorderWidthChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hourlyViewModeChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weekViewAllDayHeaderHeightChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monthListModeChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showWeekHeadersChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideEmptyDaysChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortChanged'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ascendingOrderChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showCompletedSubtodosChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pastEventsTransparencyLevelChanged'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'showMenubar'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isShowMenubarImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowMenubarValue'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'forceCollapsedMainDrawer'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isForceCollapsedMainDrawerImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultForceCollapsedMainDrawerValue'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableMaps'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isEnableMapsImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableMapsValue'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableMailIntegration'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isEnableMailIntegrationImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableMailIntegrationValue'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'locationMarker'
        QtMocHelpers::PropertyData<enum EnumLocationMarker>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'isLocationMarkerImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLocationMarkerValue'
        QtMocHelpers::PropertyData<enum EnumLocationMarker>(47, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'lastOpenedView'
        QtMocHelpers::PropertyData<enum EnumLastOpenedView>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'isLastOpenedViewImmutable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastOpenedViewValue'
        QtMocHelpers::PropertyData<enum EnumLastOpenedView>(51, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'incidenceInfoDrawerDrawerWidth'
        QtMocHelpers::PropertyData<int>(52, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isIncidenceInfoDrawerDrawerWidthImmutable'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIncidenceInfoDrawerDrawerWidthValue'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tagsSectionExpanded'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isTagsSectionExpandedImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTagsSectionExpandedValue'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'collectionsSectionExpanded'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isCollectionsSectionExpandedImmutable'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCollectionsSectionExpandedValue'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastUsedEventCollection'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isLastUsedEventCollectionImmutable'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastUsedEventCollectionValue'
        QtMocHelpers::PropertyData<int>(63, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastUsedTodoCollection'
        QtMocHelpers::PropertyData<int>(64, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isLastUsedTodoCollectionImmutable'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastUsedTodoCollectionValue'
        QtMocHelpers::PropertyData<int>(66, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useIncidenceInfoPopup'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isUseIncidenceInfoPopupImmutable'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUseIncidenceInfoPopupValue'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showHolidaysInCalendarViews'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isShowHolidaysInCalendarViewsImmutable'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowHolidaysInCalendarViewsValue'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'holidayRegions'
        QtMocHelpers::PropertyData<QStringList>(73, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isHolidayRegionsImmutable'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showTodosInCalendarViews'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isShowTodosInCalendarViewsImmutable'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowTodosInCalendarViewsValue'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSubtodosInCalendarViews'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isShowSubtodosInCalendarViewsImmutable'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowSubtodosInCalendarViewsValue'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monthGridMode'
        QtMocHelpers::PropertyData<enum EnumMonthGridMode>(81, 0x80000000 | 82, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 16),
        // property 'isMonthGridModeImmutable'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonthGridModeValue'
        QtMocHelpers::PropertyData<enum EnumMonthGridMode>(84, 0x80000000 | 82, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'weekdayLabelAlignment'
        QtMocHelpers::PropertyData<enum EnumWeekdayLabelAlignment>(85, 0x80000000 | 86, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'isWeekdayLabelAlignmentImmutable'
        QtMocHelpers::PropertyData<bool>(87, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWeekdayLabelAlignmentValue'
        QtMocHelpers::PropertyData<enum EnumWeekdayLabelAlignment>(88, 0x80000000 | 86, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'weekdayLabelLength'
        QtMocHelpers::PropertyData<enum EnumWeekdayLabelLength>(89, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 18),
        // property 'isWeekdayLabelLengthImmutable'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWeekdayLabelLengthValue'
        QtMocHelpers::PropertyData<enum EnumWeekdayLabelLength>(92, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'showWeekNumbers'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isShowWeekNumbersImmutable'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowWeekNumbersValue'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monthGridBorderWidth'
        QtMocHelpers::PropertyData<int>(96, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isMonthGridBorderWidthImmutable'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonthGridBorderWidthValue'
        QtMocHelpers::PropertyData<int>(98, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hourlyViewMode'
        QtMocHelpers::PropertyData<enum EnumHourlyViewMode>(99, 0x80000000 | 100, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 21),
        // property 'isHourlyViewModeImmutable'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHourlyViewModeValue'
        QtMocHelpers::PropertyData<enum EnumHourlyViewMode>(102, 0x80000000 | 100, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'weekViewAllDayHeaderHeight'
        QtMocHelpers::PropertyData<int>(103, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isWeekViewAllDayHeaderHeightImmutable'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWeekViewAllDayHeaderHeightValue'
        QtMocHelpers::PropertyData<int>(105, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monthListMode'
        QtMocHelpers::PropertyData<enum EnumMonthListMode>(106, 0x80000000 | 107, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 23),
        // property 'isMonthListModeImmutable'
        QtMocHelpers::PropertyData<bool>(108, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonthListModeValue'
        QtMocHelpers::PropertyData<enum EnumMonthListMode>(109, 0x80000000 | 107, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'showWeekHeaders'
        QtMocHelpers::PropertyData<bool>(110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isShowWeekHeadersImmutable'
        QtMocHelpers::PropertyData<bool>(111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowWeekHeadersValue'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideEmptyDays'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isHideEmptyDaysImmutable'
        QtMocHelpers::PropertyData<bool>(114, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHideEmptyDaysValue'
        QtMocHelpers::PropertyData<bool>(115, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sort'
        QtMocHelpers::PropertyData<enum EnumSort>(116, 0x80000000 | 117, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 26),
        // property 'isSortImmutable'
        QtMocHelpers::PropertyData<bool>(118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSortValue'
        QtMocHelpers::PropertyData<enum EnumSort>(119, 0x80000000 | 117, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'ascendingOrder'
        QtMocHelpers::PropertyData<bool>(120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isAscendingOrderImmutable'
        QtMocHelpers::PropertyData<bool>(121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAscendingOrderValue'
        QtMocHelpers::PropertyData<bool>(122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showCompletedSubtodos'
        QtMocHelpers::PropertyData<bool>(123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isShowCompletedSubtodosImmutable'
        QtMocHelpers::PropertyData<bool>(124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowCompletedSubtodosValue'
        QtMocHelpers::PropertyData<bool>(125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pastEventsTransparencyLevel'
        QtMocHelpers::PropertyData<double>(126, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isPastEventsTransparencyLevelImmutable'
        QtMocHelpers::PropertyData<bool>(127, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPastEventsTransparencyLevelValue'
        QtMocHelpers::PropertyData<double>(128, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EnumLocationMarker'
        QtMocHelpers::EnumData<enum EnumLocationMarker>(45, 45, QMC::EnumFlags{}).add({
            {  129, EnumLocationMarker::Circle },
            {  130, EnumLocationMarker::Pin },
        }),
        // enum 'EnumLastOpenedView'
        QtMocHelpers::EnumData<enum EnumLastOpenedView>(49, 49, QMC::EnumFlags{}).add({
            {  131, EnumLastOpenedView::MonthView },
            {  132, EnumLastOpenedView::ScheduleView },
            {  133, EnumLastOpenedView::TodoView },
            {  134, EnumLastOpenedView::WeekView },
            {  135, EnumLastOpenedView::WorkWeekView },
            {  136, EnumLastOpenedView::ThreeDayView },
            {  137, EnumLastOpenedView::DayView },
            {  138, EnumLastOpenedView::ContactView },
            {  139, EnumLastOpenedView::MailView },
        }),
        // enum 'EnumMonthGridMode'
        QtMocHelpers::EnumData<enum EnumMonthGridMode>(82, 82, QMC::EnumFlags{}).add({
            {  140, EnumMonthGridMode::SwipeableMonthGrid },
            {  141, EnumMonthGridMode::BasicMonthGrid },
        }),
        // enum 'EnumWeekdayLabelAlignment'
        QtMocHelpers::EnumData<enum EnumWeekdayLabelAlignment>(86, 86, QMC::EnumFlags{}).add({
            {  142, EnumWeekdayLabelAlignment::Left },
            {  143, EnumWeekdayLabelAlignment::Center },
            {  144, EnumWeekdayLabelAlignment::Right },
        }),
        // enum 'EnumWeekdayLabelLength'
        QtMocHelpers::EnumData<enum EnumWeekdayLabelLength>(90, 90, QMC::EnumFlags{}).add({
            {  145, EnumWeekdayLabelLength::Full },
            {  146, EnumWeekdayLabelLength::Abbreviated },
            {  147, EnumWeekdayLabelLength::Letter },
        }),
        // enum 'EnumHourlyViewMode'
        QtMocHelpers::EnumData<enum EnumHourlyViewMode>(100, 100, QMC::EnumFlags{}).add({
            {  148, EnumHourlyViewMode::SwipeableInternalHourlyView },
            {  149, EnumHourlyViewMode::BasicInternalHourlyView },
        }),
        // enum 'EnumMonthListMode'
        QtMocHelpers::EnumData<enum EnumMonthListMode>(107, 107, QMC::EnumFlags{}).add({
            {  150, EnumMonthListMode::SwipeableMonthList },
            {  151, EnumMonthListMode::BasicMonthList },
        }),
        // enum 'EnumSort'
        QtMocHelpers::EnumData<enum EnumSort>(117, 117, QMC::EnumFlags{}).add({
            {  152, EnumSort::DueTime },
            {  153, EnumSort::Alphabetically },
            {  154, EnumSort::Priority },
        }),
    };
    return QtMocHelpers::metaObjectData<CalendarConfig, qt_meta_tag_ZN14CalendarConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CalendarConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CalendarConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14CalendarConfigE_t>.metaTypes,
    nullptr
} };

void CalendarConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalendarConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showMenubarChanged(); break;
        case 1: _t->forceCollapsedMainDrawerChanged(); break;
        case 2: _t->enableMapsChanged(); break;
        case 3: _t->enableMailIntegrationChanged(); break;
        case 4: _t->locationMarkerChanged(); break;
        case 5: _t->lastOpenedViewChanged(); break;
        case 6: _t->incidenceInfoDrawerDrawerWidthChanged(); break;
        case 7: _t->tagsSectionExpandedChanged(); break;
        case 8: _t->collectionsSectionExpandedChanged(); break;
        case 9: _t->lastUsedEventCollectionChanged(); break;
        case 10: _t->lastUsedTodoCollectionChanged(); break;
        case 11: _t->useIncidenceInfoPopupChanged(); break;
        case 12: _t->showHolidaysInCalendarViewsChanged(); break;
        case 13: _t->holidayRegionsChanged(); break;
        case 14: _t->showTodosInCalendarViewsChanged(); break;
        case 15: _t->showSubtodosInCalendarViewsChanged(); break;
        case 16: _t->monthGridModeChanged(); break;
        case 17: _t->weekdayLabelAlignmentChanged(); break;
        case 18: _t->weekdayLabelLengthChanged(); break;
        case 19: _t->showWeekNumbersChanged(); break;
        case 20: _t->monthGridBorderWidthChanged(); break;
        case 21: _t->hourlyViewModeChanged(); break;
        case 22: _t->weekViewAllDayHeaderHeightChanged(); break;
        case 23: _t->monthListModeChanged(); break;
        case 24: _t->showWeekHeadersChanged(); break;
        case 25: _t->hideEmptyDaysChanged(); break;
        case 26: _t->sortChanged(); break;
        case 27: _t->ascendingOrderChanged(); break;
        case 28: _t->showCompletedSubtodosChanged(); break;
        case 29: _t->pastEventsTransparencyLevelChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::showMenubarChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::forceCollapsedMainDrawerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::enableMapsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::enableMailIntegrationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::locationMarkerChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::lastOpenedViewChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::incidenceInfoDrawerDrawerWidthChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::tagsSectionExpandedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::collectionsSectionExpandedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::lastUsedEventCollectionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::lastUsedTodoCollectionChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::useIncidenceInfoPopupChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::showHolidaysInCalendarViewsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::holidayRegionsChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::showTodosInCalendarViewsChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::showSubtodosInCalendarViewsChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::monthGridModeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::weekdayLabelAlignmentChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::weekdayLabelLengthChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::showWeekNumbersChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::monthGridBorderWidthChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::hourlyViewModeChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::weekViewAllDayHeaderHeightChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::monthListModeChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::showWeekHeadersChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::hideEmptyDaysChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::sortChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::ascendingOrderChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::showCompletedSubtodosChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarConfig::*)()>(_a, &CalendarConfig::pastEventsTransparencyLevelChanged, 29))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->showMenubar(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isShowMenubarImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultShowMenubarValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->forceCollapsedMainDrawer(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isForceCollapsedMainDrawerImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultForceCollapsedMainDrawerValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->enableMaps(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isEnableMapsImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultEnableMapsValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->enableMailIntegration(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isEnableMailIntegrationImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultEnableMailIntegrationValue(); break;
        case 12: *reinterpret_cast<enum EnumLocationMarker*>(_v) = _t->locationMarker(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isLocationMarkerImmutable(); break;
        case 14: *reinterpret_cast<enum EnumLocationMarker*>(_v) = _t->defaultLocationMarkerValue(); break;
        case 15: *reinterpret_cast<enum EnumLastOpenedView*>(_v) = _t->lastOpenedView(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isLastOpenedViewImmutable(); break;
        case 17: *reinterpret_cast<enum EnumLastOpenedView*>(_v) = _t->defaultLastOpenedViewValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->incidenceInfoDrawerDrawerWidth(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isIncidenceInfoDrawerDrawerWidthImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultIncidenceInfoDrawerDrawerWidthValue(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->tagsSectionExpanded(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isTagsSectionExpandedImmutable(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->defaultTagsSectionExpandedValue(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->collectionsSectionExpanded(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isCollectionsSectionExpandedImmutable(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->defaultCollectionsSectionExpandedValue(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->lastUsedEventCollection(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isLastUsedEventCollectionImmutable(); break;
        case 29: *reinterpret_cast<int*>(_v) = _t->defaultLastUsedEventCollectionValue(); break;
        case 30: *reinterpret_cast<int*>(_v) = _t->lastUsedTodoCollection(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isLastUsedTodoCollectionImmutable(); break;
        case 32: *reinterpret_cast<int*>(_v) = _t->defaultLastUsedTodoCollectionValue(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->useIncidenceInfoPopup(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isUseIncidenceInfoPopupImmutable(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->defaultUseIncidenceInfoPopupValue(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->showHolidaysInCalendarViews(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isShowHolidaysInCalendarViewsImmutable(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->defaultShowHolidaysInCalendarViewsValue(); break;
        case 39: *reinterpret_cast<QStringList*>(_v) = _t->holidayRegions(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isHolidayRegionsImmutable(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->showTodosInCalendarViews(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->isShowTodosInCalendarViewsImmutable(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->defaultShowTodosInCalendarViewsValue(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->showSubtodosInCalendarViews(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->isShowSubtodosInCalendarViewsImmutable(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->defaultShowSubtodosInCalendarViewsValue(); break;
        case 47: *reinterpret_cast<enum EnumMonthGridMode*>(_v) = _t->monthGridMode(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->isMonthGridModeImmutable(); break;
        case 49: *reinterpret_cast<enum EnumMonthGridMode*>(_v) = _t->defaultMonthGridModeValue(); break;
        case 50: *reinterpret_cast<enum EnumWeekdayLabelAlignment*>(_v) = _t->weekdayLabelAlignment(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->isWeekdayLabelAlignmentImmutable(); break;
        case 52: *reinterpret_cast<enum EnumWeekdayLabelAlignment*>(_v) = _t->defaultWeekdayLabelAlignmentValue(); break;
        case 53: *reinterpret_cast<enum EnumWeekdayLabelLength*>(_v) = _t->weekdayLabelLength(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->isWeekdayLabelLengthImmutable(); break;
        case 55: *reinterpret_cast<enum EnumWeekdayLabelLength*>(_v) = _t->defaultWeekdayLabelLengthValue(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->showWeekNumbers(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->isShowWeekNumbersImmutable(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->defaultShowWeekNumbersValue(); break;
        case 59: *reinterpret_cast<int*>(_v) = _t->monthGridBorderWidth(); break;
        case 60: *reinterpret_cast<bool*>(_v) = _t->isMonthGridBorderWidthImmutable(); break;
        case 61: *reinterpret_cast<int*>(_v) = _t->defaultMonthGridBorderWidthValue(); break;
        case 62: *reinterpret_cast<enum EnumHourlyViewMode*>(_v) = _t->hourlyViewMode(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->isHourlyViewModeImmutable(); break;
        case 64: *reinterpret_cast<enum EnumHourlyViewMode*>(_v) = _t->defaultHourlyViewModeValue(); break;
        case 65: *reinterpret_cast<int*>(_v) = _t->weekViewAllDayHeaderHeight(); break;
        case 66: *reinterpret_cast<bool*>(_v) = _t->isWeekViewAllDayHeaderHeightImmutable(); break;
        case 67: *reinterpret_cast<int*>(_v) = _t->defaultWeekViewAllDayHeaderHeightValue(); break;
        case 68: *reinterpret_cast<enum EnumMonthListMode*>(_v) = _t->monthListMode(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->isMonthListModeImmutable(); break;
        case 70: *reinterpret_cast<enum EnumMonthListMode*>(_v) = _t->defaultMonthListModeValue(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->showWeekHeaders(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->isShowWeekHeadersImmutable(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->defaultShowWeekHeadersValue(); break;
        case 74: *reinterpret_cast<bool*>(_v) = _t->hideEmptyDays(); break;
        case 75: *reinterpret_cast<bool*>(_v) = _t->isHideEmptyDaysImmutable(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->defaultHideEmptyDaysValue(); break;
        case 77: *reinterpret_cast<enum EnumSort*>(_v) = _t->sort(); break;
        case 78: *reinterpret_cast<bool*>(_v) = _t->isSortImmutable(); break;
        case 79: *reinterpret_cast<enum EnumSort*>(_v) = _t->defaultSortValue(); break;
        case 80: *reinterpret_cast<bool*>(_v) = _t->ascendingOrder(); break;
        case 81: *reinterpret_cast<bool*>(_v) = _t->isAscendingOrderImmutable(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->defaultAscendingOrderValue(); break;
        case 83: *reinterpret_cast<bool*>(_v) = _t->showCompletedSubtodos(); break;
        case 84: *reinterpret_cast<bool*>(_v) = _t->isShowCompletedSubtodosImmutable(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->defaultShowCompletedSubtodosValue(); break;
        case 86: *reinterpret_cast<double*>(_v) = _t->pastEventsTransparencyLevel(); break;
        case 87: *reinterpret_cast<bool*>(_v) = _t->isPastEventsTransparencyLevelImmutable(); break;
        case 88: *reinterpret_cast<double*>(_v) = _t->defaultPastEventsTransparencyLevelValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShowMenubar(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setForceCollapsedMainDrawer(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setEnableMaps(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setEnableMailIntegration(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setLocationMarker(*reinterpret_cast<enum EnumLocationMarker*>(_v)); break;
        case 15: _t->setLastOpenedView(*reinterpret_cast<enum EnumLastOpenedView*>(_v)); break;
        case 18: _t->setIncidenceInfoDrawerDrawerWidth(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setTagsSectionExpanded(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setCollectionsSectionExpanded(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setLastUsedEventCollection(*reinterpret_cast<int*>(_v)); break;
        case 30: _t->setLastUsedTodoCollection(*reinterpret_cast<int*>(_v)); break;
        case 33: _t->setUseIncidenceInfoPopup(*reinterpret_cast<bool*>(_v)); break;
        case 36: _t->setShowHolidaysInCalendarViews(*reinterpret_cast<bool*>(_v)); break;
        case 39: _t->setHolidayRegions(*reinterpret_cast<QStringList*>(_v)); break;
        case 41: _t->setShowTodosInCalendarViews(*reinterpret_cast<bool*>(_v)); break;
        case 44: _t->setShowSubtodosInCalendarViews(*reinterpret_cast<bool*>(_v)); break;
        case 47: _t->setMonthGridMode(*reinterpret_cast<enum EnumMonthGridMode*>(_v)); break;
        case 50: _t->setWeekdayLabelAlignment(*reinterpret_cast<enum EnumWeekdayLabelAlignment*>(_v)); break;
        case 53: _t->setWeekdayLabelLength(*reinterpret_cast<enum EnumWeekdayLabelLength*>(_v)); break;
        case 56: _t->setShowWeekNumbers(*reinterpret_cast<bool*>(_v)); break;
        case 59: _t->setMonthGridBorderWidth(*reinterpret_cast<int*>(_v)); break;
        case 62: _t->setHourlyViewMode(*reinterpret_cast<enum EnumHourlyViewMode*>(_v)); break;
        case 65: _t->setWeekViewAllDayHeaderHeight(*reinterpret_cast<int*>(_v)); break;
        case 68: _t->setMonthListMode(*reinterpret_cast<enum EnumMonthListMode*>(_v)); break;
        case 71: _t->setShowWeekHeaders(*reinterpret_cast<bool*>(_v)); break;
        case 74: _t->setHideEmptyDays(*reinterpret_cast<bool*>(_v)); break;
        case 77: _t->setSort(*reinterpret_cast<enum EnumSort*>(_v)); break;
        case 80: _t->setAscendingOrder(*reinterpret_cast<bool*>(_v)); break;
        case 83: _t->setShowCompletedSubtodos(*reinterpret_cast<bool*>(_v)); break;
        case 86: _t->setPastEventsTransparencyLevel(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *CalendarConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CalendarConfigE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int CalendarConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 89;
    }
    return _id;
}

// SIGNAL 0
void CalendarConfig::showMenubarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CalendarConfig::forceCollapsedMainDrawerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CalendarConfig::enableMapsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CalendarConfig::enableMailIntegrationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CalendarConfig::locationMarkerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CalendarConfig::lastOpenedViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CalendarConfig::incidenceInfoDrawerDrawerWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void CalendarConfig::tagsSectionExpandedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void CalendarConfig::collectionsSectionExpandedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void CalendarConfig::lastUsedEventCollectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void CalendarConfig::lastUsedTodoCollectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void CalendarConfig::useIncidenceInfoPopupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void CalendarConfig::showHolidaysInCalendarViewsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void CalendarConfig::holidayRegionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void CalendarConfig::showTodosInCalendarViewsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void CalendarConfig::showSubtodosInCalendarViewsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void CalendarConfig::monthGridModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void CalendarConfig::weekdayLabelAlignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void CalendarConfig::weekdayLabelLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void CalendarConfig::showWeekNumbersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void CalendarConfig::monthGridBorderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void CalendarConfig::hourlyViewModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void CalendarConfig::weekViewAllDayHeaderHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void CalendarConfig::monthListModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void CalendarConfig::showWeekHeadersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void CalendarConfig::hideEmptyDaysChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void CalendarConfig::sortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void CalendarConfig::ascendingOrderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void CalendarConfig::showCompletedSubtodosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void CalendarConfig::pastEventsTransparencyLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}
QT_WARNING_POP
