/****************************************************************************
** Meta object code from reading C++ file 'calendarmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/calendarmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendarmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12UndoRedoDataE_t {};
} // unnamed namespace

template <> constexpr inline auto UndoRedoData::qt_create_metaobjectdata<qt_meta_tag_ZN12UndoRedoDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UndoRedoData",
        "QML.Element",
        "undoRedoData",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "undoAvailable",
        "redoAvailable",
        "nextUndoDescription",
        "nextRedoDescription"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'undoAvailable'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'redoAvailable'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'nextUndoDescription'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'nextRedoDescription'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<UndoRedoData, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject UndoRedoData::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12UndoRedoDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12UndoRedoDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12UndoRedoDataE_t>.metaTypes,
    nullptr
} };

void UndoRedoData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<UndoRedoData *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->undoAvailable; break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->redoAvailable; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->nextUndoDescription; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->nextRedoDescription; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->undoAvailable, *reinterpret_cast<bool*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->redoAvailable, *reinterpret_cast<bool*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->nextUndoDescription, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->nextRedoDescription, *reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN15CalendarManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarManager::qt_create_metaobjectdata<qt_meta_tag_ZN15CalendarManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "loadingChanged",
        "",
        "calendarChanged",
        "undoRedoDataChanged",
        "enabledTodoCollectionsChanged",
        "updateIncidenceDatesCompleted",
        "collectionColorsChanged",
        "incidenceAdded",
        "errorOccurred",
        "delayedInit",
        "createIncidenceWrapper",
        "IncidenceWrapper*",
        "save",
        "defaultCalendarId",
        "incidenceWrapper",
        "incidenceItem",
        "Akonadi::Item",
        "KCalendarCore::Incidence::Ptr",
        "incidence",
        "addIncidence",
        "editIncidence",
        "updateIncidenceDates",
        "startOffset",
        "endOffset",
        "occurrences",
        "occurrenceDate",
        "hasChildren",
        "deleteIncidence",
        "deleteChildren",
        "changeIncidenceCollection",
        "collectionId",
        "getCollectionDetails",
        "QVariantMap",
        "QVariant",
        "setCollectionColor",
        "QColor",
        "color",
        "getIncidenceSubclassed",
        "incidencePtr",
        "undoAction",
        "redoAction",
        "getCollection",
        "Akonadi::Collection",
        "updateAllCollections",
        "updateCollection",
        "deleteCollection",
        "toggleCollection",
        "loading",
        "collections",
        "QAbstractProxyModel*",
        "todoCollections",
        "QAbstractItemModel*",
        "viewCollections",
        "enabledTodoCollections",
        "QList<qint64>",
        "allCalendars",
        "Akonadi::CollectionFilterProxyModel*",
        "calendar",
        "Akonadi::ETMCalendar::Ptr",
        "incidenceChanger",
        "Akonadi::IncidenceChanger*",
        "undoRedoData",
        "UndoRedoData"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undoRedoDataChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledTodoCollectionsChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateIncidenceDatesCompleted'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collectionColorsChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceAdded'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'delayedInit'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'createIncidenceWrapper'
        QtMocHelpers::MethodData<IncidenceWrapper *()>(15, 6, QMC::AccessPublic, 0x80000000 | 16),
        // Method 'save'
        QtMocHelpers::MethodData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'defaultCalendarId'
        QtMocHelpers::MethodData<qint64(IncidenceWrapper *)>(18, 6, QMC::AccessPublic, QMetaType::LongLong, {{
            { 0x80000000 | 16, 19 },
        }}),
        // Method 'incidenceItem'
        QtMocHelpers::MethodData<Akonadi::Item(KCalendarCore::Incidence::Ptr) const>(20, 6, QMC::AccessPublic, 0x80000000 | 21, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'addIncidence'
        QtMocHelpers::MethodData<void(IncidenceWrapper *)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 19 },
        }}),
        // Method 'editIncidence'
        QtMocHelpers::MethodData<void(IncidenceWrapper *)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 19 },
        }}),
        // Method 'updateIncidenceDates'
        QtMocHelpers::MethodData<void(IncidenceWrapper *, int, int, int, const QDateTime &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 19 }, { QMetaType::Int, 27 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 },
            { QMetaType::QDateTime, 30 },
        }}),
        // Method 'updateIncidenceDates'
        QtMocHelpers::MethodData<void(IncidenceWrapper *, int, int, int)>(26, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 19 }, { QMetaType::Int, 27 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 },
        }}),
        // Method 'updateIncidenceDates'
        QtMocHelpers::MethodData<void(IncidenceWrapper *, int, int)>(26, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 19 }, { QMetaType::Int, 27 }, { QMetaType::Int, 28 },
        }}),
        // Method 'hasChildren'
        QtMocHelpers::MethodData<bool(KCalendarCore::Incidence::Ptr)>(31, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'deleteIncidence'
        QtMocHelpers::MethodData<void(KCalendarCore::Incidence::Ptr, bool)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Bool, 33 },
        }}),
        // Method 'deleteIncidence'
        QtMocHelpers::MethodData<void(KCalendarCore::Incidence::Ptr)>(32, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'changeIncidenceCollection'
        QtMocHelpers::MethodData<void(KCalendarCore::Incidence::Ptr, qint64)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::LongLong, 35 },
        }}),
        // Method 'getCollectionDetails'
        QtMocHelpers::MethodData<QVariantMap(QVariant)>(36, 6, QMC::AccessPublic, 0x80000000 | 37, {{
            { 0x80000000 | 38, 35 },
        }}),
        // Method 'setCollectionColor'
        QtMocHelpers::MethodData<void(qint64, const QColor &)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 35 }, { 0x80000000 | 40, 41 },
        }}),
        // Method 'getIncidenceSubclassed'
        QtMocHelpers::MethodData<QVariant(KCalendarCore::Incidence::Ptr)>(42, 6, QMC::AccessPublic, 0x80000000 | 38, {{
            { 0x80000000 | 22, 43 },
        }}),
        // Method 'undoAction'
        QtMocHelpers::MethodData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'redoAction'
        QtMocHelpers::MethodData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'getCollection'
        QtMocHelpers::MethodData<Akonadi::Collection(qint64)>(46, 6, QMC::AccessPublic, 0x80000000 | 47, {{
            { QMetaType::LongLong, 35 },
        }}),
        // Method 'updateAllCollections'
        QtMocHelpers::MethodData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'updateCollection'
        QtMocHelpers::MethodData<void(qint64)>(49, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 35 },
        }}),
        // Method 'deleteCollection'
        QtMocHelpers::MethodData<void(qint64)>(50, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 35 },
        }}),
        // Method 'toggleCollection'
        QtMocHelpers::MethodData<void(qint64)>(51, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'collections'
        QtMocHelpers::PropertyData<QAbstractProxyModel*>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'todoCollections'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(55, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'viewCollections'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(57, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'enabledTodoCollections'
        QtMocHelpers::PropertyData<QList<qint64>>(58, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'allCalendars'
        QtMocHelpers::PropertyData<Akonadi::CollectionFilterProxyModel*>(60, 0x80000000 | 61, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'calendar'
        QtMocHelpers::PropertyData<Akonadi::ETMCalendar::Ptr>(62, 0x80000000 | 63, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'incidenceChanger'
        QtMocHelpers::PropertyData<Akonadi::IncidenceChanger*>(64, 0x80000000 | 65, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'undoRedoData'
        QtMocHelpers::PropertyData<UndoRedoData>(66, 0x80000000 | 67, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CalendarManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN15CalendarManagerE[] = {
    QMetaObject::SuperData::link<Akonadi::ETMCalendar::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject CalendarManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarManagerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN15CalendarManagerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CalendarManagerE_t>.metaTypes,
    nullptr
} };

void CalendarManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalendarManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loadingChanged(); break;
        case 1: _t->calendarChanged(); break;
        case 2: _t->undoRedoDataChanged(); break;
        case 3: _t->enabledTodoCollectionsChanged(); break;
        case 4: _t->updateIncidenceDatesCompleted(); break;
        case 5: _t->collectionColorsChanged(); break;
        case 6: _t->incidenceAdded(); break;
        case 7: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->delayedInit(); break;
        case 9: { IncidenceWrapper* _r = _t->createIncidenceWrapper();
            if (_a[0]) *reinterpret_cast<IncidenceWrapper**>(_a[0]) = std::move(_r); }  break;
        case 10: _t->save(); break;
        case 11: { qint64 _r = _t->defaultCalendarId((*reinterpret_cast<std::add_pointer_t<IncidenceWrapper*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 12: { Akonadi::Item _r = _t->incidenceItem((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Akonadi::Item*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->addIncidence((*reinterpret_cast<std::add_pointer_t<IncidenceWrapper*>>(_a[1]))); break;
        case 14: _t->editIncidence((*reinterpret_cast<std::add_pointer_t<IncidenceWrapper*>>(_a[1]))); break;
        case 15: _t->updateIncidenceDates((*reinterpret_cast<std::add_pointer_t<IncidenceWrapper*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[5]))); break;
        case 16: _t->updateIncidenceDates((*reinterpret_cast<std::add_pointer_t<IncidenceWrapper*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 17: _t->updateIncidenceDates((*reinterpret_cast<std::add_pointer_t<IncidenceWrapper*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 18: { bool _r = _t->hasChildren((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1]))); break;
        case 21: _t->changeIncidenceCollection((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 22: { QVariantMap _r = _t->getCollectionDetails((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->setCollectionColor((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        case 24: { QVariant _r = _t->getIncidenceSubclassed((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->undoAction(); break;
        case 26: _t->redoAction(); break;
        case 27: { Akonadi::Collection _r = _t->getCollection((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Akonadi::Collection*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->updateAllCollections(); break;
        case 29: _t->updateCollection((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 30: _t->deleteCollection((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 31: _t->toggleCollection((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalendarManager::*)()>(_a, &CalendarManager::loadingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarManager::*)()>(_a, &CalendarManager::calendarChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarManager::*)()>(_a, &CalendarManager::undoRedoDataChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarManager::*)()>(_a, &CalendarManager::enabledTodoCollectionsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarManager::*)()>(_a, &CalendarManager::updateIncidenceDatesCompleted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarManager::*)()>(_a, &CalendarManager::collectionColorsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarManager::*)()>(_a, &CalendarManager::incidenceAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarManager::*)(const QString & )>(_a, &CalendarManager::errorOccurred, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::CollectionFilterProxyModel* >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::ETMCalendar::Ptr >(); break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger* >(); break;
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractProxyModel* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<qint64> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 1: *reinterpret_cast<QAbstractProxyModel**>(_v) = _t->collections(); break;
        case 2: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->todoCollections(); break;
        case 3: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->viewCollections(); break;
        case 4: *reinterpret_cast<QList<qint64>*>(_v) = _t->enabledTodoCollections(); break;
        case 5: *reinterpret_cast<Akonadi::CollectionFilterProxyModel**>(_v) = _t->allCalendars(); break;
        case 6: *reinterpret_cast<Akonadi::ETMCalendar::Ptr*>(_v) = _t->calendar(); break;
        case 7: *reinterpret_cast<Akonadi::IncidenceChanger**>(_v) = _t->incidenceChanger(); break;
        case 8: *reinterpret_cast<UndoRedoData*>(_v) = _t->undoRedoData(); break;
        default: break;
        }
    }
}

const QMetaObject *CalendarManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CalendarManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void CalendarManager::loadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CalendarManager::calendarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CalendarManager::undoRedoDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CalendarManager::enabledTodoCollectionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CalendarManager::updateIncidenceDatesCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CalendarManager::collectionColorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CalendarManager::incidenceAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void CalendarManager::errorOccurred(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
