/****************************************************************************
** Meta object code from reading C++ file 'contacteditorbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/contacts/contacteditorbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'contacteditorbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20ContactEditorBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto ContactEditorBackend::qt_create_metaobjectdata<qt_meta_tag_ZN20ContactEditorBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ContactEditorBackend",
        "QML.Element",
        "ContactEditor",
        "contactStored",
        "",
        "Akonadi::Item",
        "contact",
        "errorOccured",
        "errorMsg",
        "finished",
        "contactChanged",
        "modeChanged",
        "isReadOnlyChanged",
        "itemChanged",
        "collectionChanged",
        "itemChangedExternally",
        "setDefaultAddressBook",
        "Akonadi::Collection",
        "addressbook",
        "setItem",
        "saveContactInAddressBook",
        "fetchItem",
        "mode",
        "Mode",
        "AddresseeWrapper*",
        "item",
        "collectionId",
        "isReadOnly",
        "CreateMode",
        "EditMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'contactStored'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'errorOccured'
        QtMocHelpers::SignalData<void(const QString &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contactChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isReadOnlyChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collectionChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemChangedExternally'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'setDefaultAddressBook'
        QtMocHelpers::MethodData<void(const Akonadi::Collection &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'setItem'
        QtMocHelpers::MethodData<void(const Akonadi::Item &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'saveContactInAddressBook'
        QtMocHelpers::MethodData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'fetchItem'
        QtMocHelpers::MethodData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mode'
        QtMocHelpers::PropertyData<enum Mode>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'contact'
        QtMocHelpers::PropertyData<AddresseeWrapper*>(6, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'item'
        QtMocHelpers::PropertyData<Akonadi::Item>(25, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'collectionId'
        QtMocHelpers::PropertyData<qint64>(26, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isReadOnly'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<enum Mode>(23, 23, QMC::EnumFlags{}).add({
            {   28, Mode::CreateMode },
            {   29, Mode::EditMode },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ContactEditorBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ContactEditorBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ContactEditorBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ContactEditorBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ContactEditorBackendE_t>.metaTypes,
    nullptr
} };

void ContactEditorBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ContactEditorBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->contactStored((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 1: _t->errorOccured((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->finished(); break;
        case 3: _t->contactChanged(); break;
        case 4: _t->modeChanged(); break;
        case 5: _t->isReadOnlyChanged(); break;
        case 6: _t->itemChanged(); break;
        case 7: _t->collectionChanged(); break;
        case 8: _t->itemChangedExternally(); break;
        case 9: _t->setDefaultAddressBook((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 10: _t->setItem((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 11: _t->saveContactInAddressBook(); break;
        case 12: _t->fetchItem(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ContactEditorBackend::*)(const Akonadi::Item & )>(_a, &ContactEditorBackend::contactStored, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContactEditorBackend::*)(const QString & )>(_a, &ContactEditorBackend::errorOccured, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContactEditorBackend::*)()>(_a, &ContactEditorBackend::finished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContactEditorBackend::*)()>(_a, &ContactEditorBackend::contactChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContactEditorBackend::*)()>(_a, &ContactEditorBackend::modeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContactEditorBackend::*)()>(_a, &ContactEditorBackend::isReadOnlyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContactEditorBackend::*)()>(_a, &ContactEditorBackend::itemChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContactEditorBackend::*)()>(_a, &ContactEditorBackend::collectionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContactEditorBackend::*)()>(_a, &ContactEditorBackend::itemChangedExternally, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Mode*>(_v) = _t->mode(); break;
        case 1: *reinterpret_cast<AddresseeWrapper**>(_v) = _t->contact(); break;
        case 2: *reinterpret_cast<Akonadi::Item*>(_v) = _t->item(); break;
        case 3: *reinterpret_cast<qint64*>(_v) = _t->collectionId(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isReadOnly(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMode(*reinterpret_cast<enum Mode*>(_v)); break;
        case 2: _t->setItem(*reinterpret_cast<Akonadi::Item*>(_v)); break;
        case 3: _t->setCollectionId(*reinterpret_cast<qint64*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ContactEditorBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ContactEditorBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ContactEditorBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ContactEditorBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ContactEditorBackend::contactStored(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ContactEditorBackend::errorOccured(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ContactEditorBackend::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ContactEditorBackend::contactChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ContactEditorBackend::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ContactEditorBackend::isReadOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ContactEditorBackend::itemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ContactEditorBackend::collectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ContactEditorBackend::itemChangedExternally()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
