/****************************************************************************
** Meta object code from reading C++ file 'mailheadermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/mail/mailheadermodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mailheadermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15MailHeaderModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MailHeaderModel::qt_create_metaobjectdata<qt_meta_tag_ZN15MailHeaderModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailHeaderModel",
        "QML.Element",
        "auto",
        "rowCount",
        "",
        "QModelIndex",
        "parent",
        "setValue",
        "row",
        "value",
        "setType",
        "MailHeaderModel::Header",
        "type",
        "Roles",
        "ValueRole",
        "TypeRole",
        "Header",
        "To",
        "From",
        "BCC",
        "CC",
        "ReplyTo"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'rowCount'
        QtMocHelpers::MethodData<int(const QModelIndex &) const>(3, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'rowCount'
        QtMocHelpers::MethodData<int() const>(3, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'setValue'
        QtMocHelpers::MethodData<void(int, const QString &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::QString, 9 },
        }}),
        // Method 'setType'
        QtMocHelpers::MethodData<void(int, const MailHeaderModel::Header)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { 0x80000000 | 11, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(13, 13, QMC::EnumFlags{}).add({
            {   14, Roles::ValueRole },
            {   15, Roles::TypeRole },
        }),
        // enum 'Header'
        QtMocHelpers::EnumData<enum Header>(16, 16, QMC::EnumFlags{}).add({
            {   17, Header::To },
            {   18, Header::From },
            {   19, Header::BCC },
            {   20, Header::CC },
            {   21, Header::ReplyTo },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MailHeaderModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MailHeaderModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MailHeaderModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MailHeaderModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15MailHeaderModelE_t>.metaTypes,
    nullptr
} };

void MailHeaderModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MailHeaderModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { int _r = _t->rowCount((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 1: { int _r = _t->rowCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->setValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->setType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MailHeaderModel::Header>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *MailHeaderModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailHeaderModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MailHeaderModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int MailHeaderModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
