/****************************************************************************
** Meta object code from reading C++ file 'mailmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/mail/mailmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mailmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MailManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto MailManager::qt_create_metaobjectdata<qt_meta_tag_ZN11MailManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "loadingChanged",
        "",
        "entityTreeModelChanged",
        "collectionSelectionModelChanged",
        "errorOccurred",
        "error",
        "loadMailCollection",
        "QModelIndex",
        "index",
        "moveToTrash",
        "Akonadi::Item",
        "item",
        "updateCollection",
        "addCollection",
        "QVariant",
        "name",
        "deleteCollection",
        "resourceIdentifier",
        "saveMail",
        "QUrl",
        "fileUrl",
        "checkMail",
        "getCollection",
        "Akonadi::Collection",
        "loading",
        "foldersModel",
        "MailCommon::EntityCollectionOrderProxyModel*",
        "collectionSelectionModel",
        "QItemSelectionModel*",
        "entryTreeModel",
        "QAbstractItemModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'entityTreeModelChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collectionSelectionModelChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'loadMailCollection'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'moveToTrash'
        QtMocHelpers::MethodData<void(const Akonadi::Item &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'updateCollection'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'addCollection'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QVariant &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 19, 20 },
        }}),
        // Method 'deleteCollection'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'resourceIdentifier'
        QtMocHelpers::MethodData<QString(const QModelIndex &)>(22, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'saveMail'
        QtMocHelpers::MethodData<void(const QUrl &, const Akonadi::Item &)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 15, 16 },
        }}),
        // Method 'checkMail'
        QtMocHelpers::MethodData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'getCollection'
        QtMocHelpers::MethodData<Akonadi::Collection(const QModelIndex &)>(27, 6, QMC::AccessPublic, 0x80000000 | 28, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'foldersModel'
        QtMocHelpers::PropertyData<MailCommon::EntityCollectionOrderProxyModel*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'collectionSelectionModel'
        QtMocHelpers::PropertyData<QItemSelectionModel*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'entryTreeModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MailManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MailManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MailManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MailManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MailManagerE_t>.metaTypes,
    nullptr
} };

void MailManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MailManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loadingChanged(); break;
        case 1: _t->entityTreeModelChanged(); break;
        case 2: _t->collectionSelectionModelChanged(); break;
        case 3: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->loadMailCollection((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 5: _t->moveToTrash((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 6: _t->updateCollection((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 7: _t->addCollection((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 8: _t->deleteCollection((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: { QString _r = _t->resourceIdentifier((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->saveMail((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[2]))); break;
        case 11: _t->checkMail(); break;
        case 12: { Akonadi::Collection _r = _t->getCollection((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Akonadi::Collection*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MailManager::*)()>(_a, &MailManager::loadingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MailManager::*)()>(_a, &MailManager::entityTreeModelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MailManager::*)()>(_a, &MailManager::collectionSelectionModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MailManager::*)(const QString & )>(_a, &MailManager::errorOccurred, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MailCommon::EntityCollectionOrderProxyModel* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelectionModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 1: *reinterpret_cast<MailCommon::EntityCollectionOrderProxyModel**>(_v) = _t->foldersModel(); break;
        case 2: *reinterpret_cast<QItemSelectionModel**>(_v) = _t->collectionSelectionModel(); break;
        case 3: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->entryTreeModel(); break;
        default: break;
        }
    }
}

const QMetaObject *MailManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MailManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MailManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void MailManager::loadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MailManager::entityTreeModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MailManager::collectionSelectionModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MailManager::errorOccurred(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
