/****************************************************************************
** Meta object code from reading C++ file 'multidayincidencemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/models/multidayincidencemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multidayincidencemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22MultiDayIncidenceModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MultiDayIncidenceModel::qt_create_metaobjectdata<qt_meta_tag_ZN22MultiDayIncidenceModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MultiDayIncidenceModel",
        "QML.Element",
        "auto",
        "periodLengthChanged",
        "",
        "filtersChanged",
        "incidenceCountChanged",
        "modelChanged",
        "showTodosChanged",
        "showSubTodosChanged",
        "activeChanged",
        "setModel",
        "IncidenceOccurrenceModel*",
        "model",
        "setPeriodLength",
        "periodLength",
        "setFilters",
        "MultiDayIncidenceModel::Filters",
        "filters",
        "setShowTodos",
        "showTodos",
        "setShowSubTodos",
        "showSubTodos",
        "slotSourceDataChanged",
        "QModelIndex",
        "upperLeft",
        "bottomRight",
        "incidenceCount",
        "active",
        "Filters",
        "Filter",
        "AllDayOnly",
        "NoStartDateOnly",
        "MultiDayOnly"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'periodLengthChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filtersChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceCountChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTodosChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSubTodosChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setModel'
        QtMocHelpers::SlotData<void(IncidenceOccurrenceModel *)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setPeriodLength'
        QtMocHelpers::SlotData<void(int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setFilters'
        QtMocHelpers::SlotData<void(MultiDayIncidenceModel::Filters)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setShowTodos'
        QtMocHelpers::SlotData<void(const bool)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'setShowSubTodos'
        QtMocHelpers::SlotData<void(const bool)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'slotSourceDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 24, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'periodLength'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'filters'
        QtMocHelpers::PropertyData<MultiDayIncidenceModel::Filters>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'incidenceCount'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'model'
        QtMocHelpers::PropertyData<IncidenceOccurrenceModel*>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'showTodos'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'showSubTodos'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'Filters'
        QtMocHelpers::EnumData<Filters>(29, 30, QMC::EnumIsFlag).add({
            {   31, Filter::AllDayOnly },
            {   32, Filter::NoStartDateOnly },
            {   33, Filter::MultiDayOnly },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MultiDayIncidenceModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MultiDayIncidenceModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22MultiDayIncidenceModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22MultiDayIncidenceModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22MultiDayIncidenceModelE_t>.metaTypes,
    nullptr
} };

void MultiDayIncidenceModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MultiDayIncidenceModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->periodLengthChanged(); break;
        case 1: _t->filtersChanged(); break;
        case 2: _t->incidenceCountChanged(); break;
        case 3: _t->modelChanged(); break;
        case 4: _t->showTodosChanged(); break;
        case 5: _t->showSubTodosChanged(); break;
        case 6: _t->activeChanged(); break;
        case 7: _t->setModel((*reinterpret_cast<std::add_pointer_t<IncidenceOccurrenceModel*>>(_a[1]))); break;
        case 8: _t->setPeriodLength((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->setFilters((*reinterpret_cast<std::add_pointer_t<MultiDayIncidenceModel::Filters>>(_a[1]))); break;
        case 10: _t->setShowTodos((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->setShowSubTodos((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slotSourceDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< IncidenceOccurrenceModel* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MultiDayIncidenceModel::*)()>(_a, &MultiDayIncidenceModel::periodLengthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiDayIncidenceModel::*)()>(_a, &MultiDayIncidenceModel::filtersChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiDayIncidenceModel::*)()>(_a, &MultiDayIncidenceModel::incidenceCountChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiDayIncidenceModel::*)()>(_a, &MultiDayIncidenceModel::modelChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiDayIncidenceModel::*)()>(_a, &MultiDayIncidenceModel::showTodosChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiDayIncidenceModel::*)()>(_a, &MultiDayIncidenceModel::showSubTodosChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiDayIncidenceModel::*)()>(_a, &MultiDayIncidenceModel::activeChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IncidenceOccurrenceModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->periodLength(); break;
        case 1: *reinterpret_cast<MultiDayIncidenceModel::Filters*>(_v) = _t->filters(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->incidenceCount(); break;
        case 3: *reinterpret_cast<IncidenceOccurrenceModel**>(_v) = _t->model(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->showTodos(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showSubTodos(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPeriodLength(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setFilters(*reinterpret_cast<MultiDayIncidenceModel::Filters*>(_v)); break;
        case 3: _t->setModel(*reinterpret_cast<IncidenceOccurrenceModel**>(_v)); break;
        case 4: _t->setShowTodos(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setShowSubTodos(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MultiDayIncidenceModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MultiDayIncidenceModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22MultiDayIncidenceModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int MultiDayIncidenceModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void MultiDayIncidenceModel::periodLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MultiDayIncidenceModel::filtersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MultiDayIncidenceModel::incidenceCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MultiDayIncidenceModel::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MultiDayIncidenceModel::showTodosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MultiDayIncidenceModel::showSubTodosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MultiDayIncidenceModel::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
