/****************************************************************************
** Meta object code from reading C++ file 'progressmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/mail/progressmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'progressmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi5Quick13ProgressModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::Quick::ProgressModel::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi5Quick13ProgressModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::Quick::ProgressModel",
        "QML.Element",
        "auto",
        "showProgressView",
        "",
        "workingChanged",
        "indeterminateChanged",
        "progressChanged",
        "slotProgressItemAdded",
        "KPIM::ProgressItem*",
        "item",
        "slotProgressItemCompleted",
        "slotProgressItemProgress",
        "progress",
        "slotProgressItemStatus",
        "status",
        "slotProgressItemLabel",
        "label",
        "slotProgressItemCryptoStatus",
        "KPIM::ProgressItem::CryptoStatus",
        "cryptoStatus",
        "slotProgressItemUsesBusyIndicator",
        "usesBusyIndicator",
        "slotItemProgressDataChanged",
        "QList<int>",
        "roles",
        "cancelItem",
        "itemId",
        "working",
        "indeterminate",
        "Roles",
        "ProgressRole",
        "StatusRole",
        "CanBeCancelledRole",
        "UsesBusyIndicatorRole",
        "CryptoStatusRole",
        "IdRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showProgressView'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'workingChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indeterminateChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotProgressItemAdded'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem * const)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotProgressItemCompleted'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem * const)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotProgressItemProgress'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem * const, const unsigned int)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::UInt, 13 },
        }}),
        // Slot 'slotProgressItemStatus'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem * const, const QString &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'slotProgressItemLabel'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem * const, const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'slotProgressItemCryptoStatus'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem * const, const KPIM::ProgressItem::CryptoStatus)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'slotProgressItemUsesBusyIndicator'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem * const, const bool)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'slotItemProgressDataChanged'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem * const, const QList<int> &)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 24, 25 },
        }}),
        // Method 'cancelItem'
        QtMocHelpers::MethodData<void(const QString &)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'working'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'indeterminate'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'progress'
        QtMocHelpers::PropertyData<uint>(13, QMetaType::UInt, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(30, 30, QMC::EnumFlags{}).add({
            {   31, Roles::ProgressRole },
            {   32, Roles::StatusRole },
            {   33, Roles::CanBeCancelledRole },
            {   34, Roles::UsesBusyIndicatorRole },
            {   35, Roles::CryptoStatusRole },
            {   36, Roles::IdRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ProgressModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Akonadi::Quick::ProgressModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi5Quick13ProgressModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi5Quick13ProgressModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi5Quick13ProgressModelE_t>.metaTypes,
    nullptr
} };

void Akonadi::Quick::ProgressModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProgressModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showProgressView(); break;
        case 1: _t->workingChanged(); break;
        case 2: _t->indeterminateChanged(); break;
        case 3: _t->progressChanged(); break;
        case 4: _t->slotProgressItemAdded((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        case 5: _t->slotProgressItemCompleted((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        case 6: _t->slotProgressItemProgress((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 7: _t->slotProgressItemStatus((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->slotProgressItemLabel((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->slotProgressItemCryptoStatus((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem::CryptoStatus>>(_a[2]))); break;
        case 10: _t->slotProgressItemUsesBusyIndicator((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->slotItemProgressDataChanged((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 12: _t->cancelItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProgressModel::*)()>(_a, &ProgressModel::showProgressView, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressModel::*)()>(_a, &ProgressModel::workingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressModel::*)()>(_a, &ProgressModel::indeterminateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressModel::*)()>(_a, &ProgressModel::progressChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->working(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->indeterminate(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->progress(); break;
        default: break;
        }
    }
}

const QMetaObject *Akonadi::Quick::ProgressModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::Quick::ProgressModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi5Quick13ProgressModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int Akonadi::Quick::ProgressModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::Quick::ProgressModel::showProgressView()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Akonadi::Quick::ProgressModel::workingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Akonadi::Quick::ProgressModel::indeterminateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Akonadi::Quick::ProgressModel::progressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
