/****************************************************************************
** Meta object code from reading C++ file 'mailtransportconfiguration.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/mail/mailtransportconfiguration.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mailtransportconfiguration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26MailTransportConfigurationE_t {};
} // unnamed namespace

template <> constexpr inline auto MailTransportConfiguration::qt_create_metaobjectdata<qt_meta_tag_ZN26MailTransportConfigurationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailTransportConfiguration",
        "QML.Element",
        "auto",
        "createNew",
        "",
        "index",
        "name",
        "makeDefault",
        "edit",
        "transportId",
        "remove",
        "rename",
        "newName",
        "setDefault",
        "isRemovable",
        "isDefault",
        "transportModel",
        "MailTransport::TransportModel*",
        "availableTransportTypes",
        "MailTransport::TransportType::List"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createNew'
        QtMocHelpers::SlotData<void(const int, const QString &, const bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'edit'
        QtMocHelpers::SlotData<void(const int)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(const int)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'rename'
        QtMocHelpers::SlotData<void(const int, const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'setDefault'
        QtMocHelpers::SlotData<void(const int)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Method 'isRemovable'
        QtMocHelpers::MethodData<bool(const int)>(14, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 9 },
        }}),
        // Method 'isDefault'
        QtMocHelpers::MethodData<bool(const int)>(15, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'transportModel'
        QtMocHelpers::PropertyData<MailTransport::TransportModel*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'availableTransportTypes'
        QtMocHelpers::PropertyData<MailTransport::TransportType::List>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MailTransportConfiguration, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN26MailTransportConfigurationE[] = {
    QMetaObject::SuperData::link<MailTransport::TransportType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject MailTransportConfiguration::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26MailTransportConfigurationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26MailTransportConfigurationE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN26MailTransportConfigurationE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26MailTransportConfigurationE_t>.metaTypes,
    nullptr
} };

void MailTransportConfiguration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MailTransportConfiguration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createNew((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->edit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->remove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->rename((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->setDefault((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: { bool _r = _t->isRemovable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isDefault((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MailTransport::TransportModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<MailTransport::TransportModel**>(_v) = _t->transportModel(); break;
        case 1: *reinterpret_cast<MailTransport::TransportType::List*>(_v) = _t->availableTransportTypes(); break;
        default: break;
        }
    }
}

const QMetaObject *MailTransportConfiguration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailTransportConfiguration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26MailTransportConfigurationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MailTransportConfiguration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
