/****************************************************************************
** Meta object code from reading C++ file 'incidencewrapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/incidencewrapper.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'incidencewrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13MonthPositionE_t {};
} // unnamed namespace

template <> constexpr inline auto MonthPosition::qt_create_metaobjectdata<qt_meta_tag_ZN13MonthPositionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MonthPosition",
        "day",
        "pos"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'day'
        QtMocHelpers::PropertyData<int>(1, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'pos'
        QtMocHelpers::PropertyData<int>(2, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MonthPosition, qt_meta_tag_ZN13MonthPositionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MonthPosition::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MonthPositionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MonthPositionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MonthPositionE_t>.metaTypes,
    nullptr
} };

void MonthPosition::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<MonthPosition *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->day; break;
        case 1: *reinterpret_cast<int*>(_v) = _t->pos; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->day, *reinterpret_cast<int*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->pos, *reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN14RecurrenceDataE_t {};
} // unnamed namespace

template <> constexpr inline auto RecurrenceData::qt_create_metaobjectdata<qt_meta_tag_ZN14RecurrenceDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RecurrenceData",
        "weekdays",
        "QList<bool>",
        "duration",
        "frequency",
        "startDateTime",
        "startDateTimeDisplay",
        "endDateTime",
        "endDateTimeDisplay",
        "endDateDisplay",
        "allDay",
        "type",
        "monthDays",
        "QList<int>",
        "monthPositions",
        "QList<MonthPosition>",
        "yearDays",
        "yearDates",
        "yearMonths"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'weekdays'
        QtMocHelpers::PropertyData<QList<bool>>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'duration'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'frequency'
        QtMocHelpers::PropertyData<int>(4, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'startDateTime'
        QtMocHelpers::PropertyData<QDateTime>(5, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'startDateTimeDisplay'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'endDateTime'
        QtMocHelpers::PropertyData<QDateTime>(7, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'endDateTimeDisplay'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'endDateDisplay'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'allDay'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'type'
        QtMocHelpers::PropertyData<ushort>(11, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'monthDays'
        QtMocHelpers::PropertyData<QList<int>>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'monthPositions'
        QtMocHelpers::PropertyData<QList<MonthPosition>>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'yearDays'
        QtMocHelpers::PropertyData<QList<int>>(16, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'yearDates'
        QtMocHelpers::PropertyData<QList<int>>(17, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'yearMonths'
        QtMocHelpers::PropertyData<QList<int>>(18, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RecurrenceData, qt_meta_tag_ZN14RecurrenceDataE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RecurrenceData::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14RecurrenceDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14RecurrenceDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14RecurrenceDataE_t>.metaTypes,
    nullptr
} };

void RecurrenceData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<RecurrenceData *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<bool> >(); break;
        case 14:
        case 13:
        case 12:
        case 10:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<bool>*>(_v) = _t->weekdays; break;
        case 1: *reinterpret_cast<int*>(_v) = _t->duration; break;
        case 2: *reinterpret_cast<int*>(_v) = _t->frequency; break;
        case 3: *reinterpret_cast<QDateTime*>(_v) = _t->startDateTime; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->startDateTimeDisplay; break;
        case 5: *reinterpret_cast<QDateTime*>(_v) = _t->endDateTime; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->endDateTimeDisplay; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->endDateDisplay; break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->allDay; break;
        case 9: *reinterpret_cast<ushort*>(_v) = _t->type; break;
        case 10: *reinterpret_cast<QList<int>*>(_v) = _t->monthDays; break;
        case 11: *reinterpret_cast<QList<MonthPosition>*>(_v) = _t->monthPositions; break;
        case 12: *reinterpret_cast<QList<int>*>(_v) = _t->yearDays; break;
        case 13: *reinterpret_cast<QList<int>*>(_v) = _t->yearDates; break;
        case 14: *reinterpret_cast<QList<int>*>(_v) = _t->yearMonths; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->weekdays, *reinterpret_cast<QList<bool>*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->duration, *reinterpret_cast<int*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->frequency, *reinterpret_cast<int*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->startDateTime, *reinterpret_cast<QDateTime*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->startDateTimeDisplay, *reinterpret_cast<QString*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->endDateTime, *reinterpret_cast<QDateTime*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->endDateTimeDisplay, *reinterpret_cast<QString*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->endDateDisplay, *reinterpret_cast<QString*>(_v)); break;
        case 8: QtMocHelpers::setProperty(_t->allDay, *reinterpret_cast<bool*>(_v)); break;
        case 9: QtMocHelpers::setProperty(_t->type, *reinterpret_cast<ushort*>(_v)); break;
        case 10: QtMocHelpers::setProperty(_t->monthDays, *reinterpret_cast<QList<int>*>(_v)); break;
        case 11: QtMocHelpers::setProperty(_t->monthPositions, *reinterpret_cast<QList<MonthPosition>*>(_v)); break;
        case 12: QtMocHelpers::setProperty(_t->yearDays, *reinterpret_cast<QList<int>*>(_v)); break;
        case 13: QtMocHelpers::setProperty(_t->yearDates, *reinterpret_cast<QList<int>*>(_v)); break;
        case 14: QtMocHelpers::setProperty(_t->yearMonths, *reinterpret_cast<QList<int>*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16IncidenceWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN16IncidenceWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceWrapper",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "incidenceItemChanged",
        "incidencePtrChanged",
        "KCalendarCore::Incidence::Ptr",
        "incidencePtr",
        "originalIncidencePtrChanged",
        "incidenceTypeChanged",
        "incidenceTypeStrChanged",
        "incidenceIconNameChanged",
        "collectionIdChanged",
        "parentChanged",
        "parentIncidenceChanged",
        "childIncidencesChanged",
        "summaryChanged",
        "categoriesChanged",
        "descriptionChanged",
        "locationChanged",
        "incidenceStartChanged",
        "incidenceStartDateDisplayChanged",
        "incidenceStartTimeDisplayChanged",
        "incidenceEndChanged",
        "incidenceEndDateDisplayChanged",
        "incidenceEndTimeDisplayChanged",
        "timeZoneChanged",
        "startTimeZoneUTCOffsetMinsChanged",
        "endTimeZoneUTCOffsetMinsChanged",
        "durationChanged",
        "durationDisplayStringChanged",
        "allDayChanged",
        "priorityChanged",
        "recurrenceDataChanged",
        "organizerChanged",
        "attendeesModelChanged",
        "recurrenceExceptionsModelChanged",
        "attachmentsModelChanged",
        "todoCompletedChanged",
        "todoCompletionDtChanged",
        "todoPercentCompleteChanged",
        "attendeesChanged",
        "googleConferenceUrlChanged",
        "setIncidenceStart",
        "incidenceStart",
        "respectTimeZone",
        "setIncidenceStartDate",
        "day",
        "month",
        "year",
        "setIncidenceStartTime",
        "hours",
        "minutes",
        "setIncidenceEnd",
        "incidenceEnd",
        "setIncidenceEndDate",
        "setIncidenceEndTime",
        "setIncidenceTimeToNearestQuarterHour",
        "setStartTime",
        "setEndTime",
        "setRecurrenceDataItem",
        "key",
        "QVariant",
        "value",
        "triggerEditMode",
        "setNewEvent",
        "setNewTodo",
        "addAlarms",
        "KCalendarCore::Alarm::List",
        "alarms",
        "hasReminders",
        "setRegularRecurrence",
        "IncidenceWrapper::RecurrenceIntervals",
        "interval",
        "freq",
        "setMonthlyPosRecurrence",
        "pos",
        "setRecurrenceOccurrences",
        "occurrences",
        "clearRecurrences",
        "setCollection",
        "Akonadi::Collection",
        "collection",
        "incidenceItem",
        "Akonadi::Item",
        "collectionId",
        "originalIncidencePtr",
        "incidenceType",
        "incidenceTypeStr",
        "incidenceIconName",
        "uid",
        "parent",
        "parentIncidence",
        "IncidenceWrapper*",
        "childIncidences",
        "QVariantList",
        "summary",
        "categories",
        "description",
        "location",
        "hasGeo",
        "geoLatitude",
        "geoLongitude",
        "incidenceStartDateDisplay",
        "incidenceStartTimeDisplay",
        "incidenceEndDateDisplay",
        "incidenceEndTimeDisplay",
        "timeZone",
        "startTimeZoneUTCOffsetMins",
        "endTimeZoneUTCOffsetMins",
        "duration",
        "KCalendarCore::Duration",
        "durationDisplayString",
        "allDay",
        "priority",
        "recurrence",
        "KCalendarCore::Recurrence*",
        "recurrenceData",
        "RecurrenceData",
        "recurrenceExceptionsModel",
        "RecurrenceExceptionsModel*",
        "attendeesModel",
        "AttendeesModel*",
        "organizer",
        "QVariantMap",
        "attendees",
        "KCalendarCore::Attendee::List",
        "attachmentsModel",
        "AttachmentsModel*",
        "todoCompleted",
        "todoCompletionDt",
        "todoPercentComplete",
        "googleConferenceUrl",
        "RecurrenceIntervals",
        "Daily",
        "Weekly",
        "Monthly",
        "Yearly",
        "IncidenceTypes",
        "TypeEvent",
        "TypeTodo",
        "TypeJournal",
        "RecurrenceActions",
        "AllOccurrences",
        "SelectedOccurrence",
        "FutureOccurrences"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'incidenceItemChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidencePtrChanged'
        QtMocHelpers::SignalData<void(KCalendarCore::Incidence::Ptr)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'originalIncidencePtrChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceTypeChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceTypeStrChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceIconNameChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collectionIdChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'parentChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'parentIncidenceChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'childIncidencesChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'summaryChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'categoriesChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'locationChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceStartChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceStartDateDisplayChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceStartTimeDisplayChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceEndChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceEndDateDisplayChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceEndTimeDisplayChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeZoneChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startTimeZoneUTCOffsetMinsChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endTimeZoneUTCOffsetMinsChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationDisplayStringChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allDayChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'priorityChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recurrenceDataChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'organizerChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attendeesModelChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recurrenceExceptionsModelChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attachmentsModelChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoCompletedChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoCompletionDtChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoPercentCompleteChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attendeesChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'googleConferenceUrlChanged'
        QtMocHelpers::SignalData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'setIncidenceStart'
        QtMocHelpers::MethodData<void(const QDateTime &, bool)>(46, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 47 }, { QMetaType::Bool, 48 },
        }}),
        // Method 'setIncidenceStart'
        QtMocHelpers::MethodData<void(const QDateTime &)>(46, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDateTime, 47 },
        }}),
        // Method 'setIncidenceStartDate'
        QtMocHelpers::MethodData<void(int, int, int)>(49, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 50 }, { QMetaType::Int, 51 }, { QMetaType::Int, 52 },
        }}),
        // Method 'setIncidenceStartTime'
        QtMocHelpers::MethodData<void(int, int)>(53, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 54 }, { QMetaType::Int, 55 },
        }}),
        // Method 'setIncidenceEnd'
        QtMocHelpers::MethodData<void(const QDateTime &, bool)>(56, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 57 }, { QMetaType::Bool, 48 },
        }}),
        // Method 'setIncidenceEnd'
        QtMocHelpers::MethodData<void(const QDateTime &)>(56, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDateTime, 57 },
        }}),
        // Method 'setIncidenceEndDate'
        QtMocHelpers::MethodData<void(int, int, int)>(58, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 50 }, { QMetaType::Int, 51 }, { QMetaType::Int, 52 },
        }}),
        // Method 'setIncidenceEndTime'
        QtMocHelpers::MethodData<void(int, int)>(59, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 54 }, { QMetaType::Int, 55 },
        }}),
        // Method 'setIncidenceTimeToNearestQuarterHour'
        QtMocHelpers::MethodData<void(bool, bool)>(60, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 61 }, { QMetaType::Bool, 62 },
        }}),
        // Method 'setIncidenceTimeToNearestQuarterHour'
        QtMocHelpers::MethodData<void(bool)>(60, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 61 },
        }}),
        // Method 'setIncidenceTimeToNearestQuarterHour'
        QtMocHelpers::MethodData<void()>(60, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'setRecurrenceDataItem'
        QtMocHelpers::MethodData<void(const QString &, const QVariant &)>(63, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 64 }, { 0x80000000 | 65, 66 },
        }}),
        // Method 'triggerEditMode'
        QtMocHelpers::MethodData<void()>(67, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'setNewEvent'
        QtMocHelpers::MethodData<void()>(68, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'setNewTodo'
        QtMocHelpers::MethodData<void()>(69, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'addAlarms'
        QtMocHelpers::MethodData<void(const KCalendarCore::Alarm::List &)>(70, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 71, 72 },
        }}),
        // Method 'hasReminders'
        QtMocHelpers::MethodData<bool() const>(73, 6, QMC::AccessPublic, QMetaType::Bool),
        // Method 'setRegularRecurrence'
        QtMocHelpers::MethodData<void(IncidenceWrapper::RecurrenceIntervals, int)>(74, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 75, 76 }, { QMetaType::Int, 77 },
        }}),
        // Method 'setRegularRecurrence'
        QtMocHelpers::MethodData<void(IncidenceWrapper::RecurrenceIntervals)>(74, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 75, 76 },
        }}),
        // Method 'setMonthlyPosRecurrence'
        QtMocHelpers::MethodData<void(short, int)>(78, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Short, 79 }, { QMetaType::Int, 50 },
        }}),
        // Method 'setRecurrenceOccurrences'
        QtMocHelpers::MethodData<void(int)>(80, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 81 },
        }}),
        // Method 'clearRecurrences'
        QtMocHelpers::MethodData<void()>(82, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'setCollection'
        QtMocHelpers::MethodData<void(const Akonadi::Collection &)>(83, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 84, 85 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'incidenceItem'
        QtMocHelpers::PropertyData<Akonadi::Item>(86, 0x80000000 | 87, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'collectionId'
        QtMocHelpers::PropertyData<qint64>(88, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'incidencePtr'
        QtMocHelpers::PropertyData<KCalendarCore::Incidence::Ptr>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'originalIncidencePtr'
        QtMocHelpers::PropertyData<KCalendarCore::Incidence::Ptr>(89, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'incidenceType'
        QtMocHelpers::PropertyData<int>(90, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'incidenceTypeStr'
        QtMocHelpers::PropertyData<QString>(91, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'incidenceIconName'
        QtMocHelpers::PropertyData<QString>(92, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'uid'
        QtMocHelpers::PropertyData<QString>(93, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'parent'
        QtMocHelpers::PropertyData<QString>(94, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'parentIncidence'
        QtMocHelpers::PropertyData<IncidenceWrapper*>(95, 0x80000000 | 96, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'childIncidences'
        QtMocHelpers::PropertyData<QVariantList>(97, 0x80000000 | 98, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'summary'
        QtMocHelpers::PropertyData<QString>(99, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'categories'
        QtMocHelpers::PropertyData<QStringList>(100, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(101, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'location'
        QtMocHelpers::PropertyData<QString>(102, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'hasGeo'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'geoLatitude'
        QtMocHelpers::PropertyData<float>(104, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'geoLongitude'
        QtMocHelpers::PropertyData<float>(105, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'incidenceStart'
        QtMocHelpers::PropertyData<QDateTime>(47, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'incidenceStartDateDisplay'
        QtMocHelpers::PropertyData<QString>(106, QMetaType::QString, QMC::DefaultPropertyFlags, 15),
        // property 'incidenceStartTimeDisplay'
        QtMocHelpers::PropertyData<QString>(107, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
        // property 'incidenceEnd'
        QtMocHelpers::PropertyData<QDateTime>(57, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'incidenceEndDateDisplay'
        QtMocHelpers::PropertyData<QString>(108, QMetaType::QString, QMC::DefaultPropertyFlags, 18),
        // property 'incidenceEndTimeDisplay'
        QtMocHelpers::PropertyData<QString>(109, QMetaType::QString, QMC::DefaultPropertyFlags, 19),
        // property 'timeZone'
        QtMocHelpers::PropertyData<QByteArray>(110, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'startTimeZoneUTCOffsetMins'
        QtMocHelpers::PropertyData<int>(111, QMetaType::Int, QMC::DefaultPropertyFlags, 21),
        // property 'endTimeZoneUTCOffsetMins'
        QtMocHelpers::PropertyData<int>(112, QMetaType::Int, QMC::DefaultPropertyFlags, 22),
        // property 'duration'
        QtMocHelpers::PropertyData<KCalendarCore::Duration>(113, 0x80000000 | 114, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 23),
        // property 'durationDisplayString'
        QtMocHelpers::PropertyData<QString>(115, QMetaType::QString, QMC::DefaultPropertyFlags, 24),
        // property 'allDay'
        QtMocHelpers::PropertyData<bool>(116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'priority'
        QtMocHelpers::PropertyData<int>(117, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'recurrence'
        QtMocHelpers::PropertyData<KCalendarCore::Recurrence*>(118, 0x80000000 | 119, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'recurrenceData'
        QtMocHelpers::PropertyData<RecurrenceData>(120, 0x80000000 | 121, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 27),
        // property 'recurrenceExceptionsModel'
        QtMocHelpers::PropertyData<RecurrenceExceptionsModel*>(122, 0x80000000 | 123, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 30),
        // property 'attendeesModel'
        QtMocHelpers::PropertyData<AttendeesModel*>(124, 0x80000000 | 125, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 29),
        // property 'organizer'
        QtMocHelpers::PropertyData<QVariantMap>(126, 0x80000000 | 127, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 28),
        // property 'attendees'
        QtMocHelpers::PropertyData<KCalendarCore::Attendee::List>(128, 0x80000000 | 129, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 35),
        // property 'attachmentsModel'
        QtMocHelpers::PropertyData<AttachmentsModel*>(130, 0x80000000 | 131, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 31),
        // property 'todoCompleted'
        QtMocHelpers::PropertyData<bool>(132, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'todoCompletionDt'
        QtMocHelpers::PropertyData<QDateTime>(133, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 33),
        // property 'todoPercentComplete'
        QtMocHelpers::PropertyData<int>(134, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'googleConferenceUrl'
        QtMocHelpers::PropertyData<QString>(135, QMetaType::QString, QMC::DefaultPropertyFlags, 36),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'RecurrenceIntervals'
        QtMocHelpers::EnumData<enum RecurrenceIntervals>(136, 136, QMC::EnumFlags{}).add({
            {  137, RecurrenceIntervals::Daily },
            {  138, RecurrenceIntervals::Weekly },
            {  139, RecurrenceIntervals::Monthly },
            {  140, RecurrenceIntervals::Yearly },
        }),
        // enum 'IncidenceTypes'
        QtMocHelpers::EnumData<enum IncidenceTypes>(141, 141, QMC::EnumFlags{}).add({
            {  142, IncidenceTypes::TypeEvent },
            {  143, IncidenceTypes::TypeTodo },
            {  144, IncidenceTypes::TypeJournal },
        }),
        // enum 'RecurrenceActions'
        QtMocHelpers::EnumData<enum RecurrenceActions>(145, 145, QMC::EnumFlags{}).add({
            {  146, RecurrenceActions::AllOccurrences },
            {  147, RecurrenceActions::SelectedOccurrence },
            {  148, RecurrenceActions::FutureOccurrences },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<IncidenceWrapper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16IncidenceWrapperE[] = {
    QMetaObject::SuperData::link<KCalendarCore::Incidence::staticMetaObject>(),
    QMetaObject::SuperData::link<KCalendarCore::staticMetaObject>(),
    QMetaObject::SuperData::link<KCalendarCore::Attendee::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject IncidenceWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16IncidenceWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16IncidenceWrapperE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16IncidenceWrapperE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16IncidenceWrapperE_t>.metaTypes,
    nullptr
} };

void IncidenceWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IncidenceWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->incidenceItemChanged(); break;
        case 1: _t->incidencePtrChanged((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1]))); break;
        case 2: _t->originalIncidencePtrChanged(); break;
        case 3: _t->incidenceTypeChanged(); break;
        case 4: _t->incidenceTypeStrChanged(); break;
        case 5: _t->incidenceIconNameChanged(); break;
        case 6: _t->collectionIdChanged(); break;
        case 7: _t->parentChanged(); break;
        case 8: _t->parentIncidenceChanged(); break;
        case 9: _t->childIncidencesChanged(); break;
        case 10: _t->summaryChanged(); break;
        case 11: _t->categoriesChanged(); break;
        case 12: _t->descriptionChanged(); break;
        case 13: _t->locationChanged(); break;
        case 14: _t->incidenceStartChanged(); break;
        case 15: _t->incidenceStartDateDisplayChanged(); break;
        case 16: _t->incidenceStartTimeDisplayChanged(); break;
        case 17: _t->incidenceEndChanged(); break;
        case 18: _t->incidenceEndDateDisplayChanged(); break;
        case 19: _t->incidenceEndTimeDisplayChanged(); break;
        case 20: _t->timeZoneChanged(); break;
        case 21: _t->startTimeZoneUTCOffsetMinsChanged(); break;
        case 22: _t->endTimeZoneUTCOffsetMinsChanged(); break;
        case 23: _t->durationChanged(); break;
        case 24: _t->durationDisplayStringChanged(); break;
        case 25: _t->allDayChanged(); break;
        case 26: _t->priorityChanged(); break;
        case 27: _t->recurrenceDataChanged(); break;
        case 28: _t->organizerChanged(); break;
        case 29: _t->attendeesModelChanged(); break;
        case 30: _t->recurrenceExceptionsModelChanged(); break;
        case 31: _t->attachmentsModelChanged(); break;
        case 32: _t->todoCompletedChanged(); break;
        case 33: _t->todoCompletionDtChanged(); break;
        case 34: _t->todoPercentCompleteChanged(); break;
        case 35: _t->attendeesChanged(); break;
        case 36: _t->googleConferenceUrlChanged(); break;
        case 37: _t->setIncidenceStart((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 38: _t->setIncidenceStart((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 39: _t->setIncidenceStartDate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 40: _t->setIncidenceStartTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 41: _t->setIncidenceEnd((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 42: _t->setIncidenceEnd((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 43: _t->setIncidenceEndDate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 44: _t->setIncidenceEndTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 45: _t->setIncidenceTimeToNearestQuarterHour((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 46: _t->setIncidenceTimeToNearestQuarterHour((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->setIncidenceTimeToNearestQuarterHour(); break;
        case 48: _t->setRecurrenceDataItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 49: _t->triggerEditMode(); break;
        case 50: _t->setNewEvent(); break;
        case 51: _t->setNewTodo(); break;
        case 52: _t->addAlarms((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Alarm::List>>(_a[1]))); break;
        case 53: { bool _r = _t->hasReminders();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->setRegularRecurrence((*reinterpret_cast<std::add_pointer_t<IncidenceWrapper::RecurrenceIntervals>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 55: _t->setRegularRecurrence((*reinterpret_cast<std::add_pointer_t<IncidenceWrapper::RecurrenceIntervals>>(_a[1]))); break;
        case 56: _t->setMonthlyPosRecurrence((*reinterpret_cast<std::add_pointer_t<short>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 57: _t->setRecurrenceOccurrences((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 58: _t->clearRecurrences(); break;
        case 59: _t->setCollection((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)(KCalendarCore::Incidence::Ptr )>(_a, &IncidenceWrapper::incidencePtrChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::originalIncidencePtrChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceTypeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceTypeStrChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceIconNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::collectionIdChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::parentChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::parentIncidenceChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::childIncidencesChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::summaryChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::categoriesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::descriptionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::locationChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceStartChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceStartDateDisplayChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceStartTimeDisplayChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceEndChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceEndDateDisplayChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::incidenceEndTimeDisplayChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::timeZoneChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::startTimeZoneUTCOffsetMinsChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::endTimeZoneUTCOffsetMinsChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::durationChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::durationDisplayStringChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::allDayChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::priorityChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::recurrenceDataChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::organizerChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::attendeesModelChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::recurrenceExceptionsModelChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::attachmentsModelChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::todoCompletedChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::todoCompletionDtChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::todoPercentCompleteChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::attendeesChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceWrapper::*)()>(_a, &IncidenceWrapper::googleConferenceUrlChanged, 36))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
        case 37:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AttachmentsModel* >(); break;
        case 34:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AttendeesModel* >(); break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IncidenceWrapper* >(); break;
        case 27:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KCalendarCore::Duration >(); break;
        case 33:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RecurrenceExceptionsModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Akonadi::Item*>(_v) = _t->incidenceItem(); break;
        case 1: *reinterpret_cast<qint64*>(_v) = _t->collectionId(); break;
        case 2: *reinterpret_cast<KCalendarCore::Incidence::Ptr*>(_v) = _t->incidencePtr(); break;
        case 3: *reinterpret_cast<KCalendarCore::Incidence::Ptr*>(_v) = _t->originalIncidencePtr(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->incidenceType(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->incidenceTypeStr(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->incidenceIconName(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->uid(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->parent(); break;
        case 9: *reinterpret_cast<IncidenceWrapper**>(_v) = _t->parentIncidence(); break;
        case 10: *reinterpret_cast<QVariantList*>(_v) = _t->childIncidences(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->summary(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->categories(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->location(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->hasGeo(); break;
        case 16: *reinterpret_cast<float*>(_v) = _t->geoLatitude(); break;
        case 17: *reinterpret_cast<float*>(_v) = _t->geoLongitude(); break;
        case 18: *reinterpret_cast<QDateTime*>(_v) = _t->incidenceStart(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->incidenceStartDateDisplay(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->incidenceStartTimeDisplay(); break;
        case 21: *reinterpret_cast<QDateTime*>(_v) = _t->incidenceEnd(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->incidenceEndDateDisplay(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->incidenceEndTimeDisplay(); break;
        case 24: *reinterpret_cast<QByteArray*>(_v) = _t->timeZone(); break;
        case 25: *reinterpret_cast<int*>(_v) = _t->startTimeZoneUTCOffsetMins(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->endTimeZoneUTCOffsetMins(); break;
        case 27: *reinterpret_cast<KCalendarCore::Duration*>(_v) = _t->duration(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->durationDisplayString(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->allDay(); break;
        case 30: *reinterpret_cast<int*>(_v) = _t->priority(); break;
        case 31: *reinterpret_cast<KCalendarCore::Recurrence**>(_v) = _t->recurrence(); break;
        case 32: *reinterpret_cast<RecurrenceData*>(_v) = _t->recurrenceData(); break;
        case 33: *reinterpret_cast<RecurrenceExceptionsModel**>(_v) = _t->recurrenceExceptionsModel(); break;
        case 34: *reinterpret_cast<AttendeesModel**>(_v) = _t->attendeesModel(); break;
        case 35: *reinterpret_cast<QVariantMap*>(_v) = _t->organizer(); break;
        case 36: *reinterpret_cast<KCalendarCore::Attendee::List*>(_v) = _t->attendees(); break;
        case 37: *reinterpret_cast<AttachmentsModel**>(_v) = _t->attachmentsModel(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->todoCompleted(); break;
        case 39: *reinterpret_cast<QDateTime*>(_v) = _t->todoCompletionDt(); break;
        case 40: *reinterpret_cast<int*>(_v) = _t->todoPercentComplete(); break;
        case 41: *reinterpret_cast<QString*>(_v) = _t->googleConferenceUrl(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIncidenceItem(*reinterpret_cast<Akonadi::Item*>(_v)); break;
        case 1: _t->setCollectionId(*reinterpret_cast<qint64*>(_v)); break;
        case 2: _t->setIncidencePtr(*reinterpret_cast<KCalendarCore::Incidence::Ptr*>(_v)); break;
        case 8: _t->setParent(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setSummary(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setCategories(*reinterpret_cast<QStringList*>(_v)); break;
        case 13: _t->setDescription(*reinterpret_cast<QString*>(_v)); break;
        case 14: _t->setLocation(*reinterpret_cast<QString*>(_v)); break;
        case 18: _t->setIncidenceStart(*reinterpret_cast<QDateTime*>(_v)); break;
        case 21: _t->setIncidenceEnd(*reinterpret_cast<QDateTime*>(_v)); break;
        case 24: _t->setTimeZone(*reinterpret_cast<QByteArray*>(_v)); break;
        case 29: _t->setAllDay(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setPriority(*reinterpret_cast<int*>(_v)); break;
        case 38: _t->setTodoCompleted(*reinterpret_cast<bool*>(_v)); break;
        case 40: _t->setTodoPercentComplete(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *IncidenceWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16IncidenceWrapperE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Akonadi::ItemMonitor"))
        return static_cast< Akonadi::ItemMonitor*>(this);
    return QObject::qt_metacast(_clname);
}

int IncidenceWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 60)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 60;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 60)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 60;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    return _id;
}

// SIGNAL 0
void IncidenceWrapper::incidenceItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IncidenceWrapper::incidencePtrChanged(KCalendarCore::Incidence::Ptr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void IncidenceWrapper::originalIncidencePtrChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IncidenceWrapper::incidenceTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void IncidenceWrapper::incidenceTypeStrChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void IncidenceWrapper::incidenceIconNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void IncidenceWrapper::collectionIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void IncidenceWrapper::parentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void IncidenceWrapper::parentIncidenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void IncidenceWrapper::childIncidencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void IncidenceWrapper::summaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void IncidenceWrapper::categoriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void IncidenceWrapper::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void IncidenceWrapper::locationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void IncidenceWrapper::incidenceStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void IncidenceWrapper::incidenceStartDateDisplayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void IncidenceWrapper::incidenceStartTimeDisplayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void IncidenceWrapper::incidenceEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void IncidenceWrapper::incidenceEndDateDisplayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void IncidenceWrapper::incidenceEndTimeDisplayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void IncidenceWrapper::timeZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void IncidenceWrapper::startTimeZoneUTCOffsetMinsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void IncidenceWrapper::endTimeZoneUTCOffsetMinsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void IncidenceWrapper::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void IncidenceWrapper::durationDisplayStringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void IncidenceWrapper::allDayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void IncidenceWrapper::priorityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void IncidenceWrapper::recurrenceDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void IncidenceWrapper::organizerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void IncidenceWrapper::attendeesModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void IncidenceWrapper::recurrenceExceptionsModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void IncidenceWrapper::attachmentsModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void IncidenceWrapper::todoCompletedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void IncidenceWrapper::todoCompletionDtChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void IncidenceWrapper::todoPercentCompleteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void IncidenceWrapper::attendeesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void IncidenceWrapper::googleConferenceUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}
QT_WARNING_POP
