/****************************************************************************
** Meta object code from reading C++ file 'calendarapplication.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/calendarapplication.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendarapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19CalendarApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarApplication::qt_create_metaobjectdata<qt_meta_tag_ZN19CalendarApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarApplication",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "openMonthView",
        "",
        "openWeekView",
        "openWorkWeekView",
        "openThreeDayView",
        "openDayView",
        "openScheduleView",
        "openTodoView",
        "moveViewForwards",
        "moveViewBackwards",
        "moveViewToToday",
        "openDateChanger",
        "createNewEvent",
        "createNewTodo",
        "windowChanged",
        "importCalendar",
        "openLanguageSwitcher",
        "undo",
        "redo",
        "todoViewSortAlphabetically",
        "todoViewSortByDueDate",
        "todoViewSortByPriority",
        "todoViewOrderAscending",
        "todoViewOrderDescending",
        "todoViewShowCompleted",
        "todoViewShowCurrentDayOnly",
        "refreshAll",
        "openIncidence",
        "IncidenceData",
        "incidenceData",
        "occurrence",
        "calendarChanged",
        "showMenubarChanged",
        "state",
        "handleMouseViewNavButtons",
        "Qt::MouseButton",
        "pressedButton",
        "saveWindowGeometry",
        "QQuickWindow*",
        "window",
        "QWindow*",
        "calendar",
        "Akonadi::ETMCalendar::Ptr",
        "Mode",
        "Month",
        "Week",
        "ThreeDay",
        "Day",
        "Schedule",
        "Todo",
        "WorkWeek",
        "Event"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openMonthView'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openWeekView'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openWorkWeekView'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openThreeDayView'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openDayView'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openScheduleView'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openTodoView'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'moveViewForwards'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'moveViewBackwards'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'moveViewToToday'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openDateChanger'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'createNewEvent'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'createNewTodo'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'importCalendar'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openLanguageSwitcher'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undo'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'redo'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoViewSortAlphabetically'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoViewSortByDueDate'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoViewSortByPriority'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoViewOrderAscending'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoViewOrderDescending'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoViewShowCompleted'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todoViewShowCurrentDayOnly'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshAll'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openIncidence'
        QtMocHelpers::SignalData<void(const IncidenceData, const QDateTime)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { QMetaType::QDateTime, 35 },
        }}),
        // Signal 'calendarChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showMenubarChanged'
        QtMocHelpers::SignalData<void(bool)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'handleMouseViewNavButtons'
        QtMocHelpers::SlotData<void(const Qt::MouseButton)>(39, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Method 'saveWindowGeometry'
        QtMocHelpers::MethodData<void(QQuickWindow *)>(42, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'window'
        QtMocHelpers::PropertyData<QWindow*>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'calendar'
        QtMocHelpers::PropertyData<Akonadi::ETMCalendar::Ptr>(46, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 27),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<enum Mode>(48, 48, QMC::EnumFlags{}).add({
            {   49, Mode::Month },
            {   50, Mode::Week },
            {   51, Mode::ThreeDay },
            {   52, Mode::Day },
            {   53, Mode::Schedule },
            {   54, Mode::Todo },
            {   55, Mode::WorkWeek },
            {   56, Mode::Event },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CalendarApplication, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN19CalendarApplicationE[] = {
    QMetaObject::SuperData::link<Akonadi::ETMCalendar::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject CalendarApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractMerkuroApplication::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CalendarApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CalendarApplicationE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN19CalendarApplicationE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CalendarApplicationE_t>.metaTypes,
    nullptr
} };

void CalendarApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalendarApplication *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openMonthView(); break;
        case 1: _t->openWeekView(); break;
        case 2: _t->openWorkWeekView(); break;
        case 3: _t->openThreeDayView(); break;
        case 4: _t->openDayView(); break;
        case 5: _t->openScheduleView(); break;
        case 6: _t->openTodoView(); break;
        case 7: _t->moveViewForwards(); break;
        case 8: _t->moveViewBackwards(); break;
        case 9: _t->moveViewToToday(); break;
        case 10: _t->openDateChanger(); break;
        case 11: _t->createNewEvent(); break;
        case 12: _t->createNewTodo(); break;
        case 13: _t->windowChanged(); break;
        case 14: _t->importCalendar(); break;
        case 15: _t->openLanguageSwitcher(); break;
        case 16: _t->undo(); break;
        case 17: _t->redo(); break;
        case 18: _t->todoViewSortAlphabetically(); break;
        case 19: _t->todoViewSortByDueDate(); break;
        case 20: _t->todoViewSortByPriority(); break;
        case 21: _t->todoViewOrderAscending(); break;
        case 22: _t->todoViewOrderDescending(); break;
        case 23: _t->todoViewShowCompleted(); break;
        case 24: _t->todoViewShowCurrentDayOnly(); break;
        case 25: _t->refreshAll(); break;
        case 26: _t->openIncidence((*reinterpret_cast<std::add_pointer_t<IncidenceData>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2]))); break;
        case 27: _t->calendarChanged(); break;
        case 28: _t->showMenubarChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->handleMouseViewNavButtons((*reinterpret_cast<std::add_pointer_t<Qt::MouseButton>>(_a[1]))); break;
        case 30: _t->saveWindowGeometry((*reinterpret_cast<std::add_pointer_t<QQuickWindow*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::openMonthView, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::openWeekView, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::openWorkWeekView, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::openThreeDayView, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::openDayView, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::openScheduleView, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::openTodoView, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::moveViewForwards, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::moveViewBackwards, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::moveViewToToday, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::openDateChanger, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::createNewEvent, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::createNewTodo, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::windowChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::importCalendar, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::openLanguageSwitcher, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::undo, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::redo, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::todoViewSortAlphabetically, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::todoViewSortByDueDate, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::todoViewSortByPriority, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::todoViewOrderAscending, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::todoViewOrderDescending, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::todoViewShowCompleted, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::todoViewShowCurrentDayOnly, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::refreshAll, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)(const IncidenceData , const QDateTime )>(_a, &CalendarApplication::openIncidence, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)()>(_a, &CalendarApplication::calendarChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarApplication::*)(bool )>(_a, &CalendarApplication::showMenubarChanged, 28))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QWindow**>(_v) = _t->window(); break;
        case 1: *reinterpret_cast<Akonadi::ETMCalendar::Ptr*>(_v) = _t->m_calendar; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWindow(*reinterpret_cast<QWindow**>(_v)); break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_calendar, *reinterpret_cast<Akonadi::ETMCalendar::Ptr*>(_v)))
                Q_EMIT _t->calendarChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *CalendarApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CalendarApplicationE_t>.strings))
        return static_cast<void*>(this);
    return AbstractMerkuroApplication::qt_metacast(_clname);
}

int CalendarApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractMerkuroApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void CalendarApplication::openMonthView()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CalendarApplication::openWeekView()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CalendarApplication::openWorkWeekView()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CalendarApplication::openThreeDayView()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CalendarApplication::openDayView()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CalendarApplication::openScheduleView()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CalendarApplication::openTodoView()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void CalendarApplication::moveViewForwards()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void CalendarApplication::moveViewBackwards()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void CalendarApplication::moveViewToToday()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void CalendarApplication::openDateChanger()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void CalendarApplication::createNewEvent()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void CalendarApplication::createNewTodo()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void CalendarApplication::windowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void CalendarApplication::importCalendar()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void CalendarApplication::openLanguageSwitcher()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void CalendarApplication::undo()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void CalendarApplication::redo()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void CalendarApplication::todoViewSortAlphabetically()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void CalendarApplication::todoViewSortByDueDate()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void CalendarApplication::todoViewSortByPriority()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void CalendarApplication::todoViewOrderAscending()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void CalendarApplication::todoViewOrderDescending()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void CalendarApplication::todoViewShowCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void CalendarApplication::todoViewShowCurrentDayOnly()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void CalendarApplication::refreshAll()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void CalendarApplication::openIncidence(const IncidenceData _t1, const QDateTime _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2);
}

// SIGNAL 27
void CalendarApplication::calendarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void CalendarApplication::showMenubarChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}
QT_WARNING_POP
