/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<attachmentmodel.h>)
#  include <attachmentmodel.h>
#endif
#if __has_include(<identitycryptographyeditorbackendfactory.h>)
#  include <identitycryptographyeditorbackendfactory.h>
#endif
#if __has_include(<mailactions.h>)
#  include <mailactions.h>
#endif
#if __has_include(<mailapplication.h>)
#  include <mailapplication.h>
#endif
#if __has_include(<mailclient.h>)
#  include <mailclient.h>
#endif
#if __has_include(<mailconfig.h>)
#  include <mailconfig.h>
#endif
#if __has_include(<mailheadermodel.h>)
#  include <mailheadermodel.h>
#endif
#if __has_include(<mailmanager.h>)
#  include <mailmanager.h>
#endif
#if __has_include(<mailmodel.h>)
#  include <mailmodel.h>
#endif
#if __has_include(<mailtransportconfiguration.h>)
#  include <mailtransportconfiguration.h>
#endif
#if __has_include(<messagehandler.h>)
#  include <messagehandler.h>
#endif
#if __has_include(<messageloader.h>)
#  include <messageloader.h>
#endif
#if __has_include(<progressmodel.h>)
#  include <progressmodel.h>
#endif
#if __has_include(<searchmodel.h>)
#  include <searchmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_merkuro_mail()
{
    qmlRegisterModule("org.kde.merkuro.mail", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Akonadi::MailClient>("org.kde.merkuro.mail", 254);
    qmlRegisterTypesAndRevisions<Akonadi::Quick::ProgressModel>("org.kde.merkuro.mail", 254);
    qmlRegisterEnum<Akonadi::Quick::ProgressModel::Roles>("Akonadi::Quick::ProgressModel::Roles");
    qmlRegisterTypesAndRevisions<AttachmentModel>("org.kde.merkuro.mail", 254);
    qmlRegisterEnum<AttachmentModel::RoleNames>("AttachmentModel::RoleNames");
    qmlRegisterTypesAndRevisions<Config>("org.kde.merkuro.mail", 254);
    qmlRegisterTypesAndRevisions<IdentityCryptographyEditorBackendFactory>("org.kde.merkuro.mail", 254);
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    qmlRegisterTypesAndRevisions<MailActions>("org.kde.merkuro.mail", 254);
    qmlRegisterTypesAndRevisions<MailApplication>("org.kde.merkuro.mail", 254);
    qmlRegisterTypesAndRevisions<MailHeaderModel>("org.kde.merkuro.mail", 254);
    qmlRegisterEnum<MailHeaderModel::Roles>("MailHeaderModel::Roles");
    qmlRegisterEnum<MailHeaderModel::Header>("MailHeaderModel::Header");
    qmlRegisterTypesAndRevisions<MailManager>("org.kde.merkuro.mail", 254);
    qmlRegisterTypesAndRevisions<MailModel>("org.kde.merkuro.mail", 254);
    qmlRegisterTypesAndRevisions<MailTransportConfiguration>("org.kde.merkuro.mail", 254);
    qmlRegisterTypesAndRevisions<MessageHandler>("org.kde.merkuro.mail", 254);
    qmlRegisterTypesAndRevisions<MessageLoader>("org.kde.merkuro.mail", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<SearchModel>("org.kde.merkuro.mail", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.merkuro.mail", 254, 254);
}

static const QQmlModuleRegistration orgkdemerkuromailRegistration("org.kde.merkuro.mail", qml_register_types_org_kde_merkuro_mail);
