/****************************************************************************
** Meta object code from reading C++ file 'recurrenceexceptionsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/models/recurrenceexceptionsmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recurrenceexceptionsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25RecurrenceExceptionsModelE_t {};
} // unnamed namespace

template <> constexpr inline auto RecurrenceExceptionsModel::qt_create_metaobjectdata<qt_meta_tag_ZN25RecurrenceExceptionsModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RecurrenceExceptionsModel",
        "incidencePtrChanged",
        "",
        "exceptionsChanged",
        "addExceptionDateTime",
        "date",
        "deleteExceptionDateTime",
        "incidencePtr",
        "KCalendarCore::Incidence::Ptr",
        "exceptions",
        "QList<QDate>",
        "dataroles",
        "QVariantMap",
        "Roles",
        "DateRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'incidencePtrChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exceptionsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'addExceptionDateTime'
        QtMocHelpers::MethodData<void(QDateTime)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 5 },
        }}),
        // Method 'deleteExceptionDateTime'
        QtMocHelpers::MethodData<void(QDateTime)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'incidencePtr'
        QtMocHelpers::PropertyData<KCalendarCore::Incidence::Ptr>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'exceptions'
        QtMocHelpers::PropertyData<QList<QDate>>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'dataroles'
        QtMocHelpers::PropertyData<QVariantMap>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(13, 13, QMC::EnumFlags{}).add({
            {   14, Roles::DateRole },
        }),
    };
    return QtMocHelpers::metaObjectData<RecurrenceExceptionsModel, qt_meta_tag_ZN25RecurrenceExceptionsModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN25RecurrenceExceptionsModelE[] = {
    QMetaObject::SuperData::link<KCalendarCore::Incidence::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject RecurrenceExceptionsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25RecurrenceExceptionsModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25RecurrenceExceptionsModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN25RecurrenceExceptionsModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25RecurrenceExceptionsModelE_t>.metaTypes,
    nullptr
} };

void RecurrenceExceptionsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RecurrenceExceptionsModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->incidencePtrChanged(); break;
        case 1: _t->exceptionsChanged(); break;
        case 2: _t->addExceptionDateTime((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 3: _t->deleteExceptionDateTime((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RecurrenceExceptionsModel::*)()>(_a, &RecurrenceExceptionsModel::incidencePtrChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecurrenceExceptionsModel::*)()>(_a, &RecurrenceExceptionsModel::exceptionsChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDate> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KCalendarCore::Incidence::Ptr*>(_v) = _t->incidencePtr(); break;
        case 1: *reinterpret_cast<QList<QDate>*>(_v) = _t->exceptions(); break;
        case 2: *reinterpret_cast<QVariantMap*>(_v) = _t->dataroles(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIncidencePtr(*reinterpret_cast<KCalendarCore::Incidence::Ptr*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *RecurrenceExceptionsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RecurrenceExceptionsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25RecurrenceExceptionsModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int RecurrenceExceptionsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void RecurrenceExceptionsModel::incidencePtrChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RecurrenceExceptionsModel::exceptionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
