/****************************************************************************
** Meta object code from reading C++ file 'importer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/importer.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'importer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8ImporterE_t {};
} // unnamed namespace

template <> constexpr inline auto Importer::qt_create_metaobjectdata<qt_meta_tag_ZN8ImporterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Importer",
        "QML.Element",
        "auto",
        "importActionChanged",
        "",
        "importStarted",
        "importFinished",
        "importCalendar",
        "importCalendarFromFile",
        "QUrl",
        "url",
        "importIntoExistingFinished",
        "success",
        "total",
        "importIntoNewFinished",
        "importErrorMessageChanged",
        "calendarImportInProgressChanged",
        "calendarFilesToImport",
        "currentFileChanged",
        "calendarChanged",
        "calendarFilesToImportChanged",
        "importCalendarFromUrl",
        "merge",
        "collectionId",
        "calendarImportInProgress",
        "QList<QUrl>",
        "currentFile",
        "importAction",
        "QAction*",
        "calendar",
        "Akonadi::ETMCalendar::Ptr",
        "importErrorMessage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'importActionChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'importStarted'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'importFinished'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'importCalendar'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'importCalendarFromFile'
        QtMocHelpers::SignalData<void(const QUrl &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'importIntoExistingFinished'
        QtMocHelpers::SignalData<void(bool, int)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'importIntoNewFinished'
        QtMocHelpers::SignalData<void(bool)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'importErrorMessageChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarImportInProgressChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarFilesToImport'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentFileChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarFilesToImportChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'importCalendarFromUrl'
        QtMocHelpers::MethodData<void(const QUrl &, bool, qint64)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Bool, 22 }, { QMetaType::LongLong, 23 },
        }}),
        // Method 'importCalendarFromUrl'
        QtMocHelpers::MethodData<void(const QUrl &, bool)>(21, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Bool, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'calendarImportInProgress'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 8),
        // property 'calendarFilesToImport'
        QtMocHelpers::PropertyData<QList<QUrl>>(17, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 12),
        // property 'currentFile'
        QtMocHelpers::PropertyData<QUrl>(26, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 10),
        // property 'importAction'
        QtMocHelpers::PropertyData<QAction*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'calendar'
        QtMocHelpers::PropertyData<Akonadi::ETMCalendar::Ptr>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 11),
        // property 'importErrorMessage'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Importer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN8ImporterE[] = {
    QMetaObject::SuperData::link<Akonadi::ETMCalendar::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Importer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ImporterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ImporterE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN8ImporterE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8ImporterE_t>.metaTypes,
    nullptr
} };

void Importer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Importer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->importActionChanged(); break;
        case 1: _t->importStarted(); break;
        case 2: _t->importFinished(); break;
        case 3: _t->importCalendar(); break;
        case 4: _t->importCalendarFromFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->importIntoExistingFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->importIntoNewFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->importErrorMessageChanged(); break;
        case 8: _t->calendarImportInProgressChanged(); break;
        case 9: _t->calendarFilesToImport(); break;
        case 10: _t->currentFileChanged(); break;
        case 11: _t->calendarChanged(); break;
        case 12: _t->calendarFilesToImportChanged(); break;
        case 13: _t->importCalendarFromUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 14: _t->importCalendarFromUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::importActionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::importStarted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::importFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::importCalendar, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)(const QUrl & )>(_a, &Importer::importCalendarFromFile, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)(bool , int )>(_a, &Importer::importIntoExistingFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)(bool )>(_a, &Importer::importIntoNewFinished, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::importErrorMessageChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::calendarImportInProgressChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::calendarFilesToImport, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::currentFileChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::calendarChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Importer::*)()>(_a, &Importer::calendarFilesToImportChanged, 12))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_calendarImportInProgress; break;
        case 1: *reinterpret_cast<QList<QUrl>*>(_v) = _t->m_calendarFilesToImport; break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->m_currentFile; break;
        case 3: *reinterpret_cast<QAction**>(_v) = _t->importAction(); break;
        case 4: *reinterpret_cast<Akonadi::ETMCalendar::Ptr*>(_v) = _t->m_calendar; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->importErrorMessage(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_calendarImportInProgress, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->calendarImportInProgressChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_calendarFilesToImport, *reinterpret_cast<QList<QUrl>*>(_v)))
                Q_EMIT _t->calendarFilesToImportChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_currentFile, *reinterpret_cast<QUrl*>(_v)))
                Q_EMIT _t->currentFileChanged();
            break;
        case 3: _t->setImportAction(*reinterpret_cast<QAction**>(_v)); break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_calendar, *reinterpret_cast<Akonadi::ETMCalendar::Ptr*>(_v)))
                Q_EMIT _t->calendarChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *Importer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Importer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ImporterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Importer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Importer::importActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Importer::importStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Importer::importFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Importer::importCalendar()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Importer::importCalendarFromFile(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Importer::importIntoExistingFinished(bool _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Importer::importIntoNewFinished(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Importer::importErrorMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Importer::calendarImportInProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Importer::calendarFilesToImport()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Importer::currentFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Importer::calendarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Importer::calendarFilesToImportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
