/****************************************************************************
** Meta object code from reading C++ file 'datetimestate.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/datetimestate.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datetimestate.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DateTimeStateE_t {};
} // unnamed namespace

template <> constexpr inline auto DateTimeState::qt_create_metaobjectdata<qt_meta_tag_ZN13DateTimeStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DateTimeState",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "selectedDateChanged",
        "",
        "currentDateChanged",
        "setSelectedYearMonthDay",
        "year",
        "month",
        "day",
        "setSelectedDay",
        "setSelectedMonth",
        "setSelectedYear",
        "selectPreviousMonth",
        "selectNextMonth",
        "addDays",
        "days",
        "isToday",
        "date",
        "resetTime",
        "selectedDate",
        "firstDayOfMonth",
        "firstDayOfWeek",
        "currentDate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectedDateChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentDateChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'setSelectedYearMonthDay'
        QtMocHelpers::MethodData<void(const int, const int, const int)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Method 'setSelectedDay'
        QtMocHelpers::MethodData<void(const int)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'setSelectedMonth'
        QtMocHelpers::MethodData<void(const int)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'setSelectedYear'
        QtMocHelpers::MethodData<void(const int)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Method 'selectPreviousMonth'
        QtMocHelpers::MethodData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'selectNextMonth'
        QtMocHelpers::MethodData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'addDays'
        QtMocHelpers::MethodData<void(const int)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'isToday'
        QtMocHelpers::MethodData<bool(const QDate &) const>(19, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QDate, 20 },
        }}),
        // Method 'resetTime'
        QtMocHelpers::MethodData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'selectedDate'
        QtMocHelpers::PropertyData<QDateTime>(22, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'firstDayOfMonth'
        QtMocHelpers::PropertyData<QDateTime>(23, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 0),
        // property 'firstDayOfWeek'
        QtMocHelpers::PropertyData<QDateTime>(24, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 0),
        // property 'currentDate'
        QtMocHelpers::PropertyData<QDateTime>(25, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DateTimeState, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DateTimeState::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DateTimeStateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DateTimeStateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DateTimeStateE_t>.metaTypes,
    nullptr
} };

void DateTimeState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DateTimeState *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectedDateChanged(); break;
        case 1: _t->currentDateChanged(); break;
        case 2: _t->setSelectedYearMonthDay((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 3: _t->setSelectedDay((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->setSelectedMonth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setSelectedYear((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->selectPreviousMonth(); break;
        case 7: _t->selectNextMonth(); break;
        case 8: _t->addDays((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: { bool _r = _t->isToday((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->resetTime(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DateTimeState::*)()>(_a, &DateTimeState::selectedDateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateTimeState::*)()>(_a, &DateTimeState::currentDateChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDateTime*>(_v) = _t->m_selectedDate; break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->firstDayOfMonth(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->firstDayOfWeek(); break;
        case 3: *reinterpret_cast<QDateTime*>(_v) = _t->m_currentDate; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_selectedDate, *reinterpret_cast<QDateTime*>(_v)))
                Q_EMIT _t->selectedDateChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_currentDate, *reinterpret_cast<QDateTime*>(_v)))
                Q_EMIT _t->currentDateChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *DateTimeState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DateTimeState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DateTimeStateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DateTimeState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DateTimeState::selectedDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DateTimeState::currentDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
