/****************************************************************************
** Meta object code from reading C++ file 'hourlyincidencemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/models/hourlyincidencemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hourlyincidencemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13IncidenceDataE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceData::qt_create_metaobjectdata<qt_meta_tag_ZN13IncidenceDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceData",
        "QML.Element",
        "incidenceData",
        "text",
        "description",
        "location",
        "startTime",
        "endTime",
        "allDay",
        "todoCompleted",
        "priority",
        "starts",
        "duration",
        "durationString",
        "recurs",
        "hasReminders",
        "isOverdue",
        "isReadOnly",
        "color",
        "QColor",
        "collectionId",
        "Akonadi::Collection::Id",
        "incidenceId",
        "incidenceType",
        "KCalendarCore::IncidenceBase::IncidenceType",
        "incidenceTypeStr",
        "incidenceTypeIcon",
        "incidencePtr",
        "KCalendarCore::Incidence::Ptr",
        "incidenceOccurrence",
        "QVariant",
        "maxConcurrentIncidences",
        "widthShare",
        "priorTakenWidthShare",
        "resizeable"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'text'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'location'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'startTime'
        QtMocHelpers::PropertyData<QDateTime>(6, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'endTime'
        QtMocHelpers::PropertyData<QDateTime>(7, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'allDay'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'todoCompleted'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'priority'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'starts'
        QtMocHelpers::PropertyData<double>(11, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'duration'
        QtMocHelpers::PropertyData<double>(12, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'durationString'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'recurs'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hasReminders'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isOverdue'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isReadOnly'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'collectionId'
        QtMocHelpers::PropertyData<Akonadi::Collection::Id>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'incidenceId'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'incidenceType'
        QtMocHelpers::PropertyData<KCalendarCore::IncidenceBase::IncidenceType>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'incidenceTypeStr'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'incidenceTypeIcon'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'incidencePtr'
        QtMocHelpers::PropertyData<KCalendarCore::Incidence::Ptr>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'incidenceOccurrence'
        QtMocHelpers::PropertyData<QVariant>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'maxConcurrentIncidences'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'widthShare'
        QtMocHelpers::PropertyData<double>(32, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'priorTakenWidthShare'
        QtMocHelpers::PropertyData<double>(33, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'resizeable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<IncidenceData, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN13IncidenceDataE[] = {
    QMetaObject::SuperData::link<Akonadi::Collection::staticMetaObject>(),
    QMetaObject::SuperData::link<KCalendarCore::IncidenceBase::staticMetaObject>(),
    QMetaObject::SuperData::link<KCalendarCore::Incidence::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject IncidenceData::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13IncidenceDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13IncidenceDataE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN13IncidenceDataE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13IncidenceDataE_t>.metaTypes,
    nullptr
} };

void IncidenceData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<IncidenceData *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->text; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->description; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->location; break;
        case 3: *reinterpret_cast<QDateTime*>(_v) = _t->startTime; break;
        case 4: *reinterpret_cast<QDateTime*>(_v) = _t->endTime; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->allDay; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->todoCompleted; break;
        case 7: *reinterpret_cast<int*>(_v) = _t->priority; break;
        case 8: *reinterpret_cast<double*>(_v) = _t->starts; break;
        case 9: *reinterpret_cast<double*>(_v) = _t->duration; break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->durationString; break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->recurs; break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->hasReminders; break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isOverdue; break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->isReadOnly; break;
        case 15: *reinterpret_cast<QColor*>(_v) = _t->color; break;
        case 16: *reinterpret_cast<Akonadi::Collection::Id*>(_v) = _t->collectionId; break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->incidenceId; break;
        case 18: *reinterpret_cast<KCalendarCore::IncidenceBase::IncidenceType*>(_v) = _t->incidenceType; break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->incidenceTypeStr; break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->incidenceTypeIcon; break;
        case 21: *reinterpret_cast<KCalendarCore::Incidence::Ptr*>(_v) = _t->incidencePtr; break;
        case 22: *reinterpret_cast<QVariant*>(_v) = _t->incidenceOccurrence; break;
        case 23: *reinterpret_cast<int*>(_v) = _t->maxConcurrentIncidences; break;
        case 24: *reinterpret_cast<double*>(_v) = _t->widthShare; break;
        case 25: *reinterpret_cast<double*>(_v) = _t->priorTakenWidthShare; break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->resizeable; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->text, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->description, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->location, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->startTime, *reinterpret_cast<QDateTime*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->endTime, *reinterpret_cast<QDateTime*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->allDay, *reinterpret_cast<bool*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->todoCompleted, *reinterpret_cast<bool*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->priority, *reinterpret_cast<int*>(_v)); break;
        case 8: QtMocHelpers::setProperty(_t->starts, *reinterpret_cast<double*>(_v)); break;
        case 9: QtMocHelpers::setProperty(_t->duration, *reinterpret_cast<double*>(_v)); break;
        case 10: QtMocHelpers::setProperty(_t->durationString, *reinterpret_cast<QString*>(_v)); break;
        case 11: QtMocHelpers::setProperty(_t->recurs, *reinterpret_cast<bool*>(_v)); break;
        case 12: QtMocHelpers::setProperty(_t->hasReminders, *reinterpret_cast<bool*>(_v)); break;
        case 13: QtMocHelpers::setProperty(_t->isOverdue, *reinterpret_cast<bool*>(_v)); break;
        case 14: QtMocHelpers::setProperty(_t->isReadOnly, *reinterpret_cast<bool*>(_v)); break;
        case 15: QtMocHelpers::setProperty(_t->color, *reinterpret_cast<QColor*>(_v)); break;
        case 16: QtMocHelpers::setProperty(_t->collectionId, *reinterpret_cast<Akonadi::Collection::Id*>(_v)); break;
        case 17: QtMocHelpers::setProperty(_t->incidenceId, *reinterpret_cast<QString*>(_v)); break;
        case 18: QtMocHelpers::setProperty(_t->incidenceType, *reinterpret_cast<KCalendarCore::IncidenceBase::IncidenceType*>(_v)); break;
        case 19: QtMocHelpers::setProperty(_t->incidenceTypeStr, *reinterpret_cast<QString*>(_v)); break;
        case 20: QtMocHelpers::setProperty(_t->incidenceTypeIcon, *reinterpret_cast<QString*>(_v)); break;
        case 21: QtMocHelpers::setProperty(_t->incidencePtr, *reinterpret_cast<KCalendarCore::Incidence::Ptr*>(_v)); break;
        case 22: QtMocHelpers::setProperty(_t->incidenceOccurrence, *reinterpret_cast<QVariant*>(_v)); break;
        case 23: QtMocHelpers::setProperty(_t->maxConcurrentIncidences, *reinterpret_cast<int*>(_v)); break;
        case 24: QtMocHelpers::setProperty(_t->widthShare, *reinterpret_cast<double*>(_v)); break;
        case 25: QtMocHelpers::setProperty(_t->priorTakenWidthShare, *reinterpret_cast<double*>(_v)); break;
        case 26: QtMocHelpers::setProperty(_t->resizeable, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN20HourlyIncidenceModelE_t {};
} // unnamed namespace

template <> constexpr inline auto HourlyIncidenceModel::qt_create_metaobjectdata<qt_meta_tag_ZN20HourlyIncidenceModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HourlyIncidenceModel",
        "QML.Element",
        "auto",
        "periodLengthChanged",
        "",
        "filtersChanged",
        "modelChanged",
        "showTodosChanged",
        "showSubTodosChanged",
        "activeChanged",
        "setModel",
        "IncidenceOccurrenceModel*",
        "model",
        "setPeriodLength",
        "periodLength",
        "setFilters",
        "HourlyIncidenceModel::Filters",
        "filters",
        "setShowTodos",
        "showTodos",
        "setShowSubTodos",
        "showSubTodos",
        "scheduleReset",
        "active",
        "Filters",
        "Filter",
        "NoAllDay",
        "NoMultiDay"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'periodLengthChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filtersChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTodosChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSubTodosChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setModel'
        QtMocHelpers::SlotData<void(IncidenceOccurrenceModel *)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setPeriodLength'
        QtMocHelpers::SlotData<void(int)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'setFilters'
        QtMocHelpers::SlotData<void(HourlyIncidenceModel::Filters)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setShowTodos'
        QtMocHelpers::SlotData<void(const bool)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'setShowSubTodos'
        QtMocHelpers::SlotData<void(const bool)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'scheduleReset'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'periodLength'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'filters'
        QtMocHelpers::PropertyData<HourlyIncidenceModel::Filters>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'model'
        QtMocHelpers::PropertyData<IncidenceOccurrenceModel*>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'showTodos'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'showSubTodos'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'Filters'
        QtMocHelpers::EnumData<Filters>(24, 25, QMC::EnumIsFlag).add({
            {   26, Filter::NoAllDay },
            {   27, Filter::NoMultiDay },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<HourlyIncidenceModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject HourlyIncidenceModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20HourlyIncidenceModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20HourlyIncidenceModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20HourlyIncidenceModelE_t>.metaTypes,
    nullptr
} };

void HourlyIncidenceModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HourlyIncidenceModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->periodLengthChanged(); break;
        case 1: _t->filtersChanged(); break;
        case 2: _t->modelChanged(); break;
        case 3: _t->showTodosChanged(); break;
        case 4: _t->showSubTodosChanged(); break;
        case 5: _t->activeChanged(); break;
        case 6: _t->setModel((*reinterpret_cast<std::add_pointer_t<IncidenceOccurrenceModel*>>(_a[1]))); break;
        case 7: _t->setPeriodLength((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setFilters((*reinterpret_cast<std::add_pointer_t<HourlyIncidenceModel::Filters>>(_a[1]))); break;
        case 9: _t->setShowTodos((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setShowSubTodos((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->scheduleReset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< IncidenceOccurrenceModel* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HourlyIncidenceModel::*)()>(_a, &HourlyIncidenceModel::periodLengthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HourlyIncidenceModel::*)()>(_a, &HourlyIncidenceModel::filtersChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (HourlyIncidenceModel::*)()>(_a, &HourlyIncidenceModel::modelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (HourlyIncidenceModel::*)()>(_a, &HourlyIncidenceModel::showTodosChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (HourlyIncidenceModel::*)()>(_a, &HourlyIncidenceModel::showSubTodosChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (HourlyIncidenceModel::*)()>(_a, &HourlyIncidenceModel::activeChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IncidenceOccurrenceModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->periodLength(); break;
        case 1: *reinterpret_cast<HourlyIncidenceModel::Filters*>(_v) = _t->filters(); break;
        case 2: *reinterpret_cast<IncidenceOccurrenceModel**>(_v) = _t->model(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showTodos(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->showSubTodos(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPeriodLength(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setFilters(*reinterpret_cast<HourlyIncidenceModel::Filters*>(_v)); break;
        case 2: _t->setModel(*reinterpret_cast<IncidenceOccurrenceModel**>(_v)); break;
        case 3: _t->setShowTodos(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setShowSubTodos(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *HourlyIncidenceModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HourlyIncidenceModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20HourlyIncidenceModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int HourlyIncidenceModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void HourlyIncidenceModel::periodLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void HourlyIncidenceModel::filtersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void HourlyIncidenceModel::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void HourlyIncidenceModel::showTodosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void HourlyIncidenceModel::showSubTodosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void HourlyIncidenceModel::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
