/****************************************************************************
** Meta object code from reading C++ file 'todosortfilterproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/models/todosortfilterproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'todosortfilterproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24TodoSortFilterProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TodoSortFilterProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN24TodoSortFilterProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TodoSortFilterProxyModel",
        "QML.Element",
        "auto",
        "calendarChanged",
        "",
        "filterObjectAboutToChange",
        "filterObjectChanged",
        "showCompletedChanged",
        "sortByChanged",
        "sortAscendingChanged",
        "showCompletedSubtodosInIncompleteChanged",
        "incidenceChangerChanged",
        "setIncidenceChanger",
        "Akonadi::IncidenceChanger*",
        "changer",
        "setFilterObject",
        "Filter*",
        "filterObject",
        "setShowCompleted",
        "showCompleted",
        "setSortBy",
        "sortBy",
        "setSortAscending",
        "sortAscending",
        "setShowCompletedSubtodosInIncomplete",
        "showCompletedSubtodosInIncomplete",
        "sortTodoModel",
        "filterTodoName",
        "name",
        "incidenceChanger",
        "calendar",
        "Akonadi::ETMCalendar::Ptr",
        "Roles",
        "StartTimeRole",
        "EndTimeRole",
        "DisplayDueDateRole",
        "LocationRole",
        "AllDayRole",
        "CompletedRole",
        "PriorityRole",
        "ColorRole",
        "CollectionIdRole",
        "DurationStringRole",
        "RecursRole",
        "IsOverdueRole",
        "IsReadOnly",
        "IncidenceIdRole",
        "IncidenceTypeRole",
        "IncidenceTypeStrRole",
        "IncidenceTypeIconRole",
        "IncidencePtrRole",
        "TagsRole",
        "ItemRole",
        "CategoriesRole",
        "CategoriesDisplayRole",
        "TreeDepthRole",
        "TopMostParentSummaryRole",
        "TopMostParentDueDateRole",
        "TopMostParentPriorityRole",
        "BaseTodoModelColumns",
        "SummaryColumn",
        "PriorityColumn",
        "PercentColumn",
        "StartDateColumn",
        "DueDateColumn",
        "CategoriesColumn",
        "DescriptionColumn",
        "CalendarColumn",
        "ShowComplete",
        "ShowAll",
        "ShowCompleteOnly",
        "ShowIncompleteOnly",
        "DueDateDisplayFormat",
        "DisplayDateOnly",
        "DisplayDateTimeAndIfOverdue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'calendarChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterObjectAboutToChange'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterObjectChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showCompletedChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortByChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortAscendingChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showCompletedSubtodosInIncompleteChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceChangerChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setIncidenceChanger'
        QtMocHelpers::SlotData<void(Akonadi::IncidenceChanger *)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'setFilterObject'
        QtMocHelpers::SlotData<void(Filter *)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setShowCompleted'
        QtMocHelpers::SlotData<void(const int)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setSortBy'
        QtMocHelpers::SlotData<void(const int)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'setSortAscending'
        QtMocHelpers::SlotData<void(const bool)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setShowCompletedSubtodosInIncomplete'
        QtMocHelpers::SlotData<void(const bool)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'sortTodoModel'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'filterTodoName'
        QtMocHelpers::SlotData<void(const QString &, const int)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'filterTodoName'
        QtMocHelpers::SlotData<void(const QString &)>(27, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'incidenceChanger'
        QtMocHelpers::PropertyData<Akonadi::IncidenceChanger*>(29, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'calendar'
        QtMocHelpers::PropertyData<Akonadi::ETMCalendar::Ptr>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'filterObject'
        QtMocHelpers::PropertyData<Filter*>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'showCompleted'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'sortBy'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'sortAscending'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'showCompletedSubtodosInIncomplete'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(32, 32, QMC::EnumFlags{}).add({
            {   33, Roles::StartTimeRole },
            {   34, Roles::EndTimeRole },
            {   35, Roles::DisplayDueDateRole },
            {   36, Roles::LocationRole },
            {   37, Roles::AllDayRole },
            {   38, Roles::CompletedRole },
            {   39, Roles::PriorityRole },
            {   40, Roles::ColorRole },
            {   41, Roles::CollectionIdRole },
            {   42, Roles::DurationStringRole },
            {   43, Roles::RecursRole },
            {   44, Roles::IsOverdueRole },
            {   45, Roles::IsReadOnly },
            {   46, Roles::IncidenceIdRole },
            {   47, Roles::IncidenceTypeRole },
            {   48, Roles::IncidenceTypeStrRole },
            {   49, Roles::IncidenceTypeIconRole },
            {   50, Roles::IncidencePtrRole },
            {   51, Roles::TagsRole },
            {   52, Roles::ItemRole },
            {   53, Roles::CategoriesRole },
            {   54, Roles::CategoriesDisplayRole },
            {   55, Roles::TreeDepthRole },
            {   56, Roles::TopMostParentSummaryRole },
            {   57, Roles::TopMostParentDueDateRole },
            {   58, Roles::TopMostParentPriorityRole },
        }),
        // enum 'BaseTodoModelColumns'
        QtMocHelpers::EnumData<enum BaseTodoModelColumns>(59, 59, QMC::EnumFlags{}).add({
            {   60, BaseTodoModelColumns::SummaryColumn },
            {   61, BaseTodoModelColumns::PriorityColumn },
            {   62, BaseTodoModelColumns::PercentColumn },
            {   63, BaseTodoModelColumns::StartDateColumn },
            {   64, BaseTodoModelColumns::DueDateColumn },
            {   65, BaseTodoModelColumns::CategoriesColumn },
            {   66, BaseTodoModelColumns::DescriptionColumn },
            {   67, BaseTodoModelColumns::CalendarColumn },
        }),
        // enum 'ShowComplete'
        QtMocHelpers::EnumData<enum ShowComplete>(68, 68, QMC::EnumFlags{}).add({
            {   69, ShowComplete::ShowAll },
            {   70, ShowComplete::ShowCompleteOnly },
            {   71, ShowComplete::ShowIncompleteOnly },
        }),
        // enum 'DueDateDisplayFormat'
        QtMocHelpers::EnumData<enum DueDateDisplayFormat>(72, 72, QMC::EnumFlags{}).add({
            {   73, DueDateDisplayFormat::DisplayDateOnly },
            {   74, DueDateDisplayFormat::DisplayDateTimeAndIfOverdue },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TodoSortFilterProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN24TodoSortFilterProxyModelE[] = {
    QMetaObject::SuperData::link<Akonadi::ETMCalendar::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject TodoSortFilterProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24TodoSortFilterProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24TodoSortFilterProxyModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN24TodoSortFilterProxyModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24TodoSortFilterProxyModelE_t>.metaTypes,
    nullptr
} };

void TodoSortFilterProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TodoSortFilterProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->calendarChanged(); break;
        case 1: _t->filterObjectAboutToChange(); break;
        case 2: _t->filterObjectChanged(); break;
        case 3: _t->showCompletedChanged(); break;
        case 4: _t->sortByChanged(); break;
        case 5: _t->sortAscendingChanged(); break;
        case 6: _t->showCompletedSubtodosInIncompleteChanged(); break;
        case 7: _t->incidenceChangerChanged(); break;
        case 8: _t->setIncidenceChanger((*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger*>>(_a[1]))); break;
        case 9: _t->setFilterObject((*reinterpret_cast<std::add_pointer_t<Filter*>>(_a[1]))); break;
        case 10: _t->setShowCompleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setSortBy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->setSortAscending((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setShowCompletedSubtodosInIncomplete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->sortTodoModel(); break;
        case 15: _t->filterTodoName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->filterTodoName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TodoSortFilterProxyModel::*)()>(_a, &TodoSortFilterProxyModel::calendarChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoSortFilterProxyModel::*)()>(_a, &TodoSortFilterProxyModel::filterObjectAboutToChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoSortFilterProxyModel::*)()>(_a, &TodoSortFilterProxyModel::filterObjectChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoSortFilterProxyModel::*)()>(_a, &TodoSortFilterProxyModel::showCompletedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoSortFilterProxyModel::*)()>(_a, &TodoSortFilterProxyModel::sortByChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoSortFilterProxyModel::*)()>(_a, &TodoSortFilterProxyModel::sortAscendingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoSortFilterProxyModel::*)()>(_a, &TodoSortFilterProxyModel::showCompletedSubtodosInIncompleteChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoSortFilterProxyModel::*)()>(_a, &TodoSortFilterProxyModel::incidenceChangerChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Akonadi::IncidenceChanger**>(_v) = _t->incidenceChanger(); break;
        case 1: *reinterpret_cast<Akonadi::ETMCalendar::Ptr*>(_v) = _t->calendar(); break;
        case 2: *reinterpret_cast<Filter**>(_v) = _t->filterObject(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->showCompleted(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->sortBy(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->sortAscending(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showCompletedSubtodosInIncomplete(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIncidenceChanger(*reinterpret_cast<Akonadi::IncidenceChanger**>(_v)); break;
        case 1: _t->setCalendar(*reinterpret_cast<Akonadi::ETMCalendar::Ptr*>(_v)); break;
        case 2: _t->setFilterObject(*reinterpret_cast<Filter**>(_v)); break;
        case 3: _t->setShowCompleted(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setSortBy(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setSortAscending(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setShowCompletedSubtodosInIncomplete(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TodoSortFilterProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TodoSortFilterProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24TodoSortFilterProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int TodoSortFilterProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void TodoSortFilterProxyModel::calendarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TodoSortFilterProxyModel::filterObjectAboutToChange()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TodoSortFilterProxyModel::filterObjectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TodoSortFilterProxyModel::showCompletedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TodoSortFilterProxyModel::sortByChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TodoSortFilterProxyModel::sortAscendingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TodoSortFilterProxyModel::showCompletedSubtodosInIncompleteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TodoSortFilterProxyModel::incidenceChangerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
