/****************************************************************************
** Meta object code from reading C++ file 'incidenceoccurrencemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/calendar/models/incidenceoccurrencemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'incidenceoccurrencemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24IncidenceOccurrenceModelE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceOccurrenceModel::qt_create_metaobjectdata<qt_meta_tag_ZN24IncidenceOccurrenceModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceOccurrenceModel",
        "QML.Element",
        "auto",
        "startChanged",
        "",
        "lengthChanged",
        "filterChanged",
        "calendarChanged",
        "loadingChanged",
        "resetThrottleIntervalChanged",
        "setStart",
        "start",
        "setLength",
        "length",
        "setFilter",
        "Filter*",
        "filter",
        "setCalendar",
        "Akonadi::ETMCalendar::Ptr",
        "calendar",
        "setResetThrottleInterval",
        "resetThrottleInterval",
        "loadColors",
        "scheduleReset",
        "resetFromSource",
        "setLoading",
        "loading",
        "Roles",
        "Summary",
        "Description",
        "Location",
        "StartTime",
        "EndTime",
        "Duration",
        "DurationString",
        "Recurs",
        "HasReminders",
        "Priority",
        "Color",
        "CollectionId",
        "AllDay",
        "TodoCompleted",
        "IsOverdue",
        "IsReadOnly",
        "IncidenceId",
        "IncidenceType",
        "IncidenceTypeStr",
        "IncidenceTypeIcon",
        "IncidencePtr",
        "IncidenceOccurrence",
        "Resizeable",
        "LastRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetThrottleIntervalChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setStart'
        QtMocHelpers::SlotData<void(const QDate &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 11 },
        }}),
        // Slot 'setLength'
        QtMocHelpers::SlotData<void(int)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'setFilter'
        QtMocHelpers::SlotData<void(Filter *)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setCalendar'
        QtMocHelpers::SlotData<void(Akonadi::ETMCalendar::Ptr)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'setResetThrottleInterval'
        QtMocHelpers::SlotData<void(const int)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'loadColors'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scheduleReset'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetFromSource'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLoading'
        QtMocHelpers::SlotData<void(const bool)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'start'
        QtMocHelpers::PropertyData<QDate>(11, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'length'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'filter'
        QtMocHelpers::PropertyData<Filter*>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'calendar'
        QtMocHelpers::PropertyData<Akonadi::ETMCalendar::Ptr>(19, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'resetThrottleInterval'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(27, 27, QMC::EnumFlags{}).add({
            {   28, Roles::Summary },
            {   29, Roles::Description },
            {   30, Roles::Location },
            {   31, Roles::StartTime },
            {   32, Roles::EndTime },
            {   33, Roles::Duration },
            {   34, Roles::DurationString },
            {   35, Roles::Recurs },
            {   36, Roles::HasReminders },
            {   37, Roles::Priority },
            {   38, Roles::Color },
            {   39, Roles::CollectionId },
            {   40, Roles::AllDay },
            {   41, Roles::TodoCompleted },
            {   42, Roles::IsOverdue },
            {   43, Roles::IsReadOnly },
            {   44, Roles::IncidenceId },
            {   45, Roles::IncidenceType },
            {   46, Roles::IncidenceTypeStr },
            {   47, Roles::IncidenceTypeIcon },
            {   48, Roles::IncidencePtr },
            {   49, Roles::IncidenceOccurrence },
            {   50, Roles::Resizeable },
            {   51, Roles::LastRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<IncidenceOccurrenceModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN24IncidenceOccurrenceModelE[] = {
    QMetaObject::SuperData::link<Akonadi::ETMCalendar::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject IncidenceOccurrenceModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24IncidenceOccurrenceModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24IncidenceOccurrenceModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN24IncidenceOccurrenceModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24IncidenceOccurrenceModelE_t>.metaTypes,
    nullptr
} };

void IncidenceOccurrenceModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IncidenceOccurrenceModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startChanged(); break;
        case 1: _t->lengthChanged(); break;
        case 2: _t->filterChanged(); break;
        case 3: _t->calendarChanged(); break;
        case 4: _t->loadingChanged(); break;
        case 5: _t->resetThrottleIntervalChanged(); break;
        case 6: _t->setStart((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 7: _t->setLength((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setFilter((*reinterpret_cast<std::add_pointer_t<Filter*>>(_a[1]))); break;
        case 9: _t->setCalendar((*reinterpret_cast<std::add_pointer_t<Akonadi::ETMCalendar::Ptr>>(_a[1]))); break;
        case 10: _t->setResetThrottleInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->loadColors(); break;
        case 12: _t->scheduleReset(); break;
        case 13: _t->resetFromSource(); break;
        case 14: _t->setLoading((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IncidenceOccurrenceModel::*)()>(_a, &IncidenceOccurrenceModel::startChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceOccurrenceModel::*)()>(_a, &IncidenceOccurrenceModel::lengthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceOccurrenceModel::*)()>(_a, &IncidenceOccurrenceModel::filterChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceOccurrenceModel::*)()>(_a, &IncidenceOccurrenceModel::calendarChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceOccurrenceModel::*)()>(_a, &IncidenceOccurrenceModel::loadingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceOccurrenceModel::*)()>(_a, &IncidenceOccurrenceModel::resetThrottleIntervalChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDate*>(_v) = _t->start(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->length(); break;
        case 2: *reinterpret_cast<Filter**>(_v) = _t->filter(); break;
        case 3: *reinterpret_cast<Akonadi::ETMCalendar::Ptr*>(_v) = _t->calendar(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->resetThrottleInterval(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setStart(*reinterpret_cast<QDate*>(_v)); break;
        case 1: _t->setLength(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setFilter(*reinterpret_cast<Filter**>(_v)); break;
        case 3: _t->setCalendar(*reinterpret_cast<Akonadi::ETMCalendar::Ptr*>(_v)); break;
        case 5: _t->setResetThrottleInterval(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *IncidenceOccurrenceModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceOccurrenceModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24IncidenceOccurrenceModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int IncidenceOccurrenceModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void IncidenceOccurrenceModel::startChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IncidenceOccurrenceModel::lengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void IncidenceOccurrenceModel::filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IncidenceOccurrenceModel::calendarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void IncidenceOccurrenceModel::loadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void IncidenceOccurrenceModel::resetThrottleIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
