/****************************************************************************
** Meta object code from reading C++ file 'phonemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/contacts/phonemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'phonemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PhoneModelE_t {};
} // unnamed namespace

template <> constexpr inline auto PhoneModel::qt_create_metaobjectdata<qt_meta_tag_ZN10PhoneModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PhoneModel",
        "QML.Element",
        "auto",
        "changed",
        "",
        "KContacts::PhoneNumber::List",
        "phoneNumbers",
        "addPhoneNumber",
        "phoneNumber",
        "PhoneModel::Type",
        "type",
        "deletePhoneNumber",
        "row",
        "copyToClipboard",
        "index",
        "Type",
        "Home",
        "Work",
        "Msg",
        "Pref",
        "Voice",
        "Fax",
        "Cell",
        "Video",
        "Bbs",
        "Modem",
        "Car",
        "Isdn",
        "Pcs",
        "Pager",
        "Undefined"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void(const KContacts::PhoneNumber::List &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'addPhoneNumber'
        QtMocHelpers::MethodData<void(const QString &, PhoneModel::Type)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Method 'deletePhoneNumber'
        QtMocHelpers::MethodData<void(int)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'copyToClipboard'
        QtMocHelpers::MethodData<void(int) const>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(15, 15, QMC::EnumFlags{}).add({
            {   16, Type::Home },
            {   17, Type::Work },
            {   18, Type::Msg },
            {   19, Type::Pref },
            {   20, Type::Voice },
            {   21, Type::Fax },
            {   22, Type::Cell },
            {   23, Type::Video },
            {   24, Type::Bbs },
            {   25, Type::Modem },
            {   26, Type::Car },
            {   27, Type::Isdn },
            {   28, Type::Pcs },
            {   29, Type::Pager },
            {   30, Type::Undefined },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PhoneModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PhoneModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PhoneModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PhoneModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PhoneModelE_t>.metaTypes,
    nullptr
} };

void PhoneModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PhoneModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed((*reinterpret_cast<std::add_pointer_t<KContacts::PhoneNumber::List>>(_a[1]))); break;
        case 1: _t->addPhoneNumber((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<PhoneModel::Type>>(_a[2]))); break;
        case 2: _t->deletePhoneNumber((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->copyToClipboard((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PhoneModel::*)(const KContacts::PhoneNumber::List & )>(_a, &PhoneModel::changed, 0))
            return;
    }
}

const QMetaObject *PhoneModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PhoneModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PhoneModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int PhoneModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void PhoneModel::changed(const KContacts::PhoneNumber::List & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
