/****************************************************************************
** Meta object code from reading C++ file 'addresseewrapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../merkuro-26.08.0/src/contacts/addresseewrapper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'addresseewrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16AddresseeWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto AddresseeWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN16AddresseeWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AddresseeWrapper",
        "QML.Element",
        "auto",
        "addresseeItemChanged",
        "",
        "collectionChanged",
        "formattedNameChanged",
        "birthdayChanged",
        "photoChanged",
        "phoneNumbersChanged",
        "preferredEmailChanged",
        "uidChanged",
        "noteChanged",
        "nickNameChanged",
        "blogFeedChanged",
        "additionalNameChanged",
        "familyNameChanged",
        "givenNameChanged",
        "prefixChanged",
        "suffixChanged",
        "anniversaryChanged",
        "spousesNameChanged",
        "organizationChanged",
        "professionChanged",
        "titleChanged",
        "departmentChanged",
        "officeChanged",
        "managersNameChanged",
        "assistantsNameChanged",
        "displayTypeChanged",
        "qrCodeData",
        "updatePhoto",
        "KContacts::Picture",
        "loadedPhoto",
        "preparePhoto",
        "QUrl",
        "path",
        "addresseeItem",
        "Akonadi::Item",
        "collection",
        "Akonadi::Collection",
        "collectionId",
        "uid",
        "formattedName",
        "additionalName",
        "familyName",
        "givenName",
        "prefix",
        "suffix",
        "nickName",
        "blogFeed",
        "preferredEmail",
        "phoneNumbers",
        "KContacts::PhoneNumber::List",
        "emailModel",
        "EmailModel*",
        "phoneModel",
        "PhoneModel*",
        "addressesModel",
        "AddressModel*",
        "imppModel",
        "ImppModel*",
        "birthday",
        "anniversary",
        "spousesName",
        "organization",
        "profession",
        "title",
        "department",
        "office",
        "managersName",
        "assistantsName",
        "note",
        "photo",
        "photoUrl",
        "displayType",
        "DisplayType",
        "SimpleName",
        "FullName",
        "ReverseNameWithComma",
        "ReverseName",
        "Organization",
        "CustomName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addresseeItemChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collectionChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'formattedNameChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'birthdayChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'photoChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'phoneNumbersChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preferredEmailChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uidChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nickNameChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blogFeedChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'additionalNameChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'familyNameChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'givenNameChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'prefixChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'suffixChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'anniversaryChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spousesNameChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'organizationChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'professionChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'departmentChanged'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'officeChanged'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'managersNameChanged'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'assistantsNameChanged'
        QtMocHelpers::SignalData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayTypeChanged'
        QtMocHelpers::SignalData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'qrCodeData'
        QtMocHelpers::MethodData<QString() const>(30, 4, QMC::AccessPublic, QMetaType::QString),
        // Method 'updatePhoto'
        QtMocHelpers::MethodData<void(const KContacts::Picture &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Method 'preparePhoto'
        QtMocHelpers::MethodData<KContacts::Picture(const QUrl &) const>(34, 4, QMC::AccessPublic, 0x80000000 | 32, {{
            { 0x80000000 | 35, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'addresseeItem'
        QtMocHelpers::PropertyData<Akonadi::Item>(37, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'collection'
        QtMocHelpers::PropertyData<Akonadi::Collection>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'collectionId'
        QtMocHelpers::PropertyData<qint64>(41, QMetaType::LongLong, QMC::DefaultPropertyFlags, 1),
        // property 'uid'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'formattedName'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'additionalName'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'familyName'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'givenName'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'prefix'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'suffix'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'nickName'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'blogFeed'
        QtMocHelpers::PropertyData<QUrl>(50, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'preferredEmail'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'phoneNumbers'
        QtMocHelpers::PropertyData<KContacts::PhoneNumber::List>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'emailModel'
        QtMocHelpers::PropertyData<EmailModel*>(54, 0x80000000 | 55, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'phoneModel'
        QtMocHelpers::PropertyData<PhoneModel*>(56, 0x80000000 | 57, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'addressesModel'
        QtMocHelpers::PropertyData<AddressModel*>(58, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'imppModel'
        QtMocHelpers::PropertyData<ImppModel*>(60, 0x80000000 | 61, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'birthday'
        QtMocHelpers::PropertyData<QDateTime>(62, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'anniversary'
        QtMocHelpers::PropertyData<QDateTime>(63, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'spousesName'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'organization'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'profession'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'department'
        QtMocHelpers::PropertyData<QString>(68, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'office'
        QtMocHelpers::PropertyData<QString>(69, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'managersName'
        QtMocHelpers::PropertyData<QString>(70, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'assistantsName'
        QtMocHelpers::PropertyData<QString>(71, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'note'
        QtMocHelpers::PropertyData<QString>(72, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'photo'
        QtMocHelpers::PropertyData<KContacts::Picture>(73, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'photoUrl'
        QtMocHelpers::PropertyData<QString>(74, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'displayType'
        QtMocHelpers::PropertyData<enum DisplayType>(75, 0x80000000 | 76, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 25),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DisplayType'
        QtMocHelpers::EnumData<enum DisplayType>(76, 76, QMC::EnumFlags{}).add({
            {   77, DisplayType::SimpleName },
            {   78, DisplayType::FullName },
            {   79, DisplayType::ReverseNameWithComma },
            {   80, DisplayType::ReverseName },
            {   81, DisplayType::Organization },
            {   82, DisplayType::CustomName },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AddresseeWrapper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16AddresseeWrapperE[] = {
    QMetaObject::SuperData::link<KContacts::PhoneNumber::staticMetaObject>(),
    QMetaObject::SuperData::link<KContacts::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject AddresseeWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AddresseeWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AddresseeWrapperE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16AddresseeWrapperE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16AddresseeWrapperE_t>.metaTypes,
    nullptr
} };

void AddresseeWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AddresseeWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addresseeItemChanged(); break;
        case 1: _t->collectionChanged(); break;
        case 2: _t->formattedNameChanged(); break;
        case 3: _t->birthdayChanged(); break;
        case 4: _t->photoChanged(); break;
        case 5: _t->phoneNumbersChanged(); break;
        case 6: _t->preferredEmailChanged(); break;
        case 7: _t->uidChanged(); break;
        case 8: _t->noteChanged(); break;
        case 9: _t->nickNameChanged(); break;
        case 10: _t->blogFeedChanged(); break;
        case 11: _t->additionalNameChanged(); break;
        case 12: _t->familyNameChanged(); break;
        case 13: _t->givenNameChanged(); break;
        case 14: _t->prefixChanged(); break;
        case 15: _t->suffixChanged(); break;
        case 16: _t->anniversaryChanged(); break;
        case 17: _t->spousesNameChanged(); break;
        case 18: _t->organizationChanged(); break;
        case 19: _t->professionChanged(); break;
        case 20: _t->titleChanged(); break;
        case 21: _t->departmentChanged(); break;
        case 22: _t->officeChanged(); break;
        case 23: _t->managersNameChanged(); break;
        case 24: _t->assistantsNameChanged(); break;
        case 25: _t->displayTypeChanged(); break;
        case 26: { QString _r = _t->qrCodeData();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->updatePhoto((*reinterpret_cast<std::add_pointer_t<KContacts::Picture>>(_a[1]))); break;
        case 28: { KContacts::Picture _r = _t->preparePhoto((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KContacts::Picture*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::addresseeItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::collectionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::formattedNameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::birthdayChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::photoChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::phoneNumbersChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::preferredEmailChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::uidChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::noteChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::nickNameChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::blogFeedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::additionalNameChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::familyNameChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::givenNameChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::prefixChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::suffixChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::anniversaryChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::spousesNameChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::organizationChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::professionChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::titleChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::departmentChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::officeChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::managersNameChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::assistantsNameChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddresseeWrapper::*)()>(_a, &AddresseeWrapper::displayTypeChanged, 25))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 16:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AddressModel* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
        case 14:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< EmailModel* >(); break;
        case 17:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ImppModel* >(); break;
        case 15:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PhoneModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Akonadi::Item*>(_v) = _t->addresseeItem(); break;
        case 1: *reinterpret_cast<Akonadi::Collection*>(_v) = _t->collection(); break;
        case 2: *reinterpret_cast<qint64*>(_v) = _t->collectionId(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->uid(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->formattedName(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->additionalName(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->familyName(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->givenName(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->prefix(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->suffix(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->nickName(); break;
        case 11: *reinterpret_cast<QUrl*>(_v) = _t->blogFeed(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->preferredEmail(); break;
        case 13: *reinterpret_cast<KContacts::PhoneNumber::List*>(_v) = _t->phoneNumbers(); break;
        case 14: *reinterpret_cast<EmailModel**>(_v) = _t->emailModel(); break;
        case 15: *reinterpret_cast<PhoneModel**>(_v) = _t->phoneModel(); break;
        case 16: *reinterpret_cast<AddressModel**>(_v) = _t->addressesModel(); break;
        case 17: *reinterpret_cast<ImppModel**>(_v) = _t->imppModel(); break;
        case 18: *reinterpret_cast<QDateTime*>(_v) = _t->birthday(); break;
        case 19: *reinterpret_cast<QDateTime*>(_v) = _t->anniversary(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->spousesName(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->organization(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->profession(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->department(); break;
        case 25: *reinterpret_cast<QString*>(_v) = _t->office(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->managersName(); break;
        case 27: *reinterpret_cast<QString*>(_v) = _t->assistantsName(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->note(); break;
        case 29: *reinterpret_cast<KContacts::Picture*>(_v) = _t->photo(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->photoUrl(); break;
        case 31: *reinterpret_cast<enum DisplayType*>(_v) = _t->displayType(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAddresseeItem(*reinterpret_cast<Akonadi::Item*>(_v)); break;
        case 1: _t->setCollection(*reinterpret_cast<Akonadi::Collection*>(_v)); break;
        case 4: _t->setFormattedName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setAdditionalName(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setFamilyName(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setGivenName(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setPrefix(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setSuffix(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setNickName(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setBlogFeed(*reinterpret_cast<QUrl*>(_v)); break;
        case 18: _t->setBirthday(*reinterpret_cast<QDateTime*>(_v)); break;
        case 19: _t->setAnniversary(*reinterpret_cast<QDateTime*>(_v)); break;
        case 20: _t->setSpousesName(*reinterpret_cast<QString*>(_v)); break;
        case 21: _t->setOrganization(*reinterpret_cast<QString*>(_v)); break;
        case 22: _t->setProfession(*reinterpret_cast<QString*>(_v)); break;
        case 23: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 24: _t->setDepartment(*reinterpret_cast<QString*>(_v)); break;
        case 25: _t->setOffice(*reinterpret_cast<QString*>(_v)); break;
        case 26: _t->setManagersName(*reinterpret_cast<QString*>(_v)); break;
        case 27: _t->setAssistantsName(*reinterpret_cast<QString*>(_v)); break;
        case 28: _t->setNote(*reinterpret_cast<QString*>(_v)); break;
        case 31: _t->setDisplayType(*reinterpret_cast<enum DisplayType*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AddresseeWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AddresseeWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AddresseeWrapperE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Akonadi::ItemMonitor"))
        return static_cast< Akonadi::ItemMonitor*>(this);
    return QObject::qt_metacast(_clname);
}

int AddresseeWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void AddresseeWrapper::addresseeItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AddresseeWrapper::collectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AddresseeWrapper::formattedNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AddresseeWrapper::birthdayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AddresseeWrapper::photoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AddresseeWrapper::phoneNumbersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AddresseeWrapper::preferredEmailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AddresseeWrapper::uidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AddresseeWrapper::noteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AddresseeWrapper::nickNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AddresseeWrapper::blogFeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AddresseeWrapper::additionalNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void AddresseeWrapper::familyNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void AddresseeWrapper::givenNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void AddresseeWrapper::prefixChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void AddresseeWrapper::suffixChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void AddresseeWrapper::anniversaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void AddresseeWrapper::spousesNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void AddresseeWrapper::organizationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void AddresseeWrapper::professionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void AddresseeWrapper::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void AddresseeWrapper::departmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void AddresseeWrapper::officeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void AddresseeWrapper::managersNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void AddresseeWrapper::assistantsNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void AddresseeWrapper::displayTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}
QT_WARNING_POP
